/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
#include <string.h>
#include <assert.h>

#ifdef _MSC_VER
#define CDECL __cdecl
#else
#define CDECL
#endif

/************ Begin %include sections from the grammar ************************/
#line 40 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"

// Allocates a new AST node off the parse state's arena.
#define NEW_AST_NODE(type,name,tok) \
	ZCC_##type *name = static_cast<ZCC_##type *>(stat->InitNode(sizeof(ZCC_##type), AST_##type)); \
	SetNodeLine(name, tok)

static void SetNodeLine(ZCC_TreeNode *name, ZCCToken &tok)
{
	name->SourceLoc = tok.SourceLoc;
}

static void SetNodeLine(ZCC_TreeNode *name, ZCC_TreeNode *node)
{
	if (name == nullptr || node == nullptr)
	{
		I_Error("Fatal parse error");
	}
	name->SourceLoc = node->SourceLoc;
}

static void SetNodeLine(ZCC_TreeNode *name, int line)
{
	name->SourceLoc = line;
}

// If a is non-null, appends b to a. Otherwise, sets a to b.
#define SAFE_APPEND(a,b) \
	if (a == NULL) a = b; else AppendTreeNodeSibling(a, b);

#define UNARY_EXPR(X,T) NEW_AST_NODE(ExprUnary, expr1, X); expr1->Operation = T; expr1->Operand = X; expr1->Type = NULL
#define BINARY_EXPR(X,Y,T) NEW_AST_NODE(ExprBinary, expr2, X); expr2->Operation = T; expr2->Type = NULL; expr2->Left = X; expr2->Right = Y

#define NEW_INTCONST_NODE(name,type,val,tok) \
	NEW_AST_NODE(ExprConstant, name, tok); \
	name->Operation = PEX_ConstValue; \
	name->Type = type; \
	name->IntVal = val

	struct ClassFlagsBlock {
		VM_UWORD Flags;
		ZCC_Identifier *Replaces;
		ZCC_Identifier *Sealed;
		VersionInfo Version;
	};

	struct StateOpts {
		ZCC_Expression *Offset;
		ZCC_ExprConstant *Lights;
		bool Bright;
		bool Fast;
		bool Slow;
		bool NoDelay;
		bool CanRaise;

		void Zero() {
			Offset = nullptr;
			Lights = nullptr;
			Bright = false;
			Fast = false;
			Slow = false;
			NoDelay = false;
			CanRaise = false;
		}
	};

	struct VarOrFun
	{
		ZCC_VarName *VarNames;
		ZCC_FuncParamDecl *FuncParams;
		ZCC_CompoundStmt *FuncBody;
		ENamedName FuncName;
		int FuncFlags;
		int SourceLoc;
	};
#line 112 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next section is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    ZCCParseTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is ZCCParseTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    ZCCParseARG_SDECL     A static variable declaration for the %extra_argument
**    ZCCParseARG_PDECL     A parameter declaration for the %extra_argument
**    ZCCParseARG_STORE     Code to store %extra_argument into yypParser
**    ZCCParseARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_MIN_REDUCE      Maximum value for reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned short int
#define YYNOCODE 281
#define YYACTIONTYPE unsigned short int
#define ZCCParseTOKENTYPE  ZCCToken 
typedef union {
  int yyinit;
  ZCCParseTOKENTYPE yy0;
  ZCC_Declarator * yy15;
  ZCC_VarInit * yy27;
  ZCC_BasicType * yy46;
  ZCC_ExprConstant * yy47;
  ZCC_Struct * yy59;
  ZCC_ExprFuncCall * yy61;
  StateOpts yy68;
  ZCC_DeclFlags * yy127;
  ZCC_AssignStmt * yy128;
  ZCC_States * yy134;
  ZCC_ExpressionStmt * yy135;
  ZCC_FuncParamDecl * yy147;
  ZCC_Default * yy167;
  ZCC_Type * yy168;
  ZCC_FlagStmt * yy180;
  ZCC_PropertyStmt * yy195;
  ZCC_MixinStmt * yy199;
  ZCC_Class * yy228;
  ZCC_VarName * yy244;
  ZCC_IfStmt * yy257;
  ZCC_CompoundStmt * yy271;
  ZCC_CaseStmt * yy274;
  ZCC_MixinDef * yy290;
  ClassFlagsBlock yy335;
  ZCC_LocalVarStmt * yy362;
  ZCC_FuncParm * yy370;
  ZCC_Expression * yy374;
  ZCC_Property * yy387;
  ZCC_FuncPtrType * yy422;
  ZCC_Enum * yy443;
  ZCC_FuncPtrParamDecl * yy453;
  ZCC_StatePart * yy458;
  ZCC_AssignDeclStmt * yy459;
  ZCC_FlagDef * yy491;
  VarOrFun yy520;
  ZCC_Statement * yy523;
  ZCC_Identifier * yy533;
  ZCC_TreeNode * yy536;
  ZCC_StaticArrayStatement * yy546;
  ZCC_ConstantDef * yy547;
  int yy561;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 0
#endif
#define ZCCParseARG_SDECL  ZCCParseState *stat ;
#define ZCCParseARG_PDECL , ZCCParseState *stat 
#define ZCCParseARG_FETCH  ZCCParseState *stat  = yypParser->stat 
#define ZCCParseARG_STORE yypParser->stat  = stat 
#define YYERRORSYMBOL 162
#define YYERRSYMDT yy561
#define YYFALLBACK 1
#define YYNSTATE             449
#define YYNRULE              405
#define YY_MAX_SHIFT         448
#define YY_MIN_SHIFTREDUCE   742
#define YY_MAX_SHIFTREDUCE   1146
#define YY_MIN_REDUCE        1147
#define YY_MAX_REDUCE        1551
#define YY_ERROR_ACTION      1552
#define YY_ACCEPT_ACTION     1553
#define YY_NO_ACTION         1554
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if:
**    (1)  The yy_shift_ofst[S]+X value is out of range, or
**    (2)  yy_lookahead[yy_shift_ofst[S]+X] is not equal to X, or
**    (3)  yy_shift_ofst[S] equal YY_SHIFT_USE_DFLT.
** (Implementation note: YY_SHIFT_USE_DFLT is chosen so that
** YY_SHIFT_USE_DFLT+X will be out of range for all possible lookaheads X.
** Hence only tests (1) and (2) need to be evaluated.)
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (3666)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */   127,  126,  744,  746,  747,  748,  749,  750,  751,  124,
 /*    10 */   125,  162,   36,   45,  163,  408, 1058,  745,  225,  408,
 /*    20 */   411,  380, 1553,   23,  225,  408,  402,  401,  401, 1049,
 /*    30 */    34,  936,  936,  353,  900,    2, 1073,  136,  819, 1375,
 /*    40 */  1051,   94,   95,  108,  107,  106,  116,  117,  114,  113,
 /*    50 */   112,  110,  109,  111,  983,  386,  225,  408,  853,  192,
 /*    60 */    78,  269,  885,  886,  887,  888,  889,  890,  891,  892,
 /*    70 */   893,  894,  895,  896,  897,  898,  899,  383,  422,  421,
 /*    80 */   310,  416,  414,  412,  994,  995,  406,   32,   75,  423,
 /*    90 */   263, 1003,  984,  971,  263,  225,  984,  269,  269,  285,
 /*   100 */   263,  225,  984, 1045, 1045,   41,  123,  122,  121,  120,
 /*   110 */  1052, 1053, 1054, 1055, 1056, 1057,   35,  365,  364,   42,
 /*   120 */    13,  360,  357, 1086, 1087,  355,  936,  354,   62,  159,
 /*   130 */   159,  111,  263,  225,  984,  285,  285,  777,   78,  814,
 /*   140 */   127,  126,  876,  879,  880,  972,  780,  779,  783,  124,
 /*   150 */   125,  162,   36,   45,  225,  408, 1058,  776,  770,  340,
 /*   160 */   411,  380,  135,  778,  784,  785,  781,  782,  786, 1049,
 /*   170 */   771,  772,  767,  353,  900,    2, 1074,  182,  387,  182,
 /*   180 */  1051,   95,  108,  107,  106,  116,  117,  114,  113,  112,
 /*   190 */   110,  109,  111,   68,  983,  129,   49,  288,  350,   78,
 /*   200 */   180,  180,  885,  886,  887,  888,  889,  890,  891,  892,
 /*   210 */   893,  894,  895,  896,  897,  898,  899,  383,  422,  421,
 /*   220 */    18,  416,  414,  412, 1147,  840,  841,  842,  191,  423,
 /*   230 */   263,  225,  984,  288,  288,  408,  760,  761,  762,  763,
 /*   240 */   764,  151,  304,   49,  267,  301,  123,  122,  121,  120,
 /*   250 */  1052, 1053, 1054, 1055, 1056, 1057,   35,  365,  364,   42,
 /*   260 */    13,  360,  357, 1086, 1087,  355,  352,  354,   62,   41,
 /*   270 */   442,  313, 1109,   49,   51,  187,  266,  306, 1328,  969,
 /*   280 */   127,  126,  769,  114,  113,  112,  110,  109,  111,  124,
 /*   290 */   125,  162,   36,   45,  299,   78, 1058,   65,    2,  427,
 /*   300 */   411,  380,  425,  389,  312,  119,  875,  879,  880, 1049,
 /*   310 */   263, 1002,  984,  353,  900,    2,  185,  185,  349,   49,
 /*   320 */  1051,  108,  107,  106,  116,  117,  114,  113,  112,  110,
 /*   330 */   109,  111,  924,  176,  983,  221,  408,  139,   78,  925,
 /*   340 */   902,   34,  885,  886,  887,  888,  889,  890,  891,  892,
 /*   350 */   893,  894,  895,  896,  897,  898,  899,  383,  422,  421,
 /*   360 */   398,  416,  414,  412,  928,  902,  929,  404,  274,  423,
 /*   370 */   134, 1207,   33,   60,  296,  911,  839,  198,  408,  813,
 /*   380 */   425,  389,  973,  276,  351,  351,  123,  122,  121,  120,
 /*   390 */  1052, 1053, 1054, 1055, 1056, 1057,   35,  365,  364,   42,
 /*   400 */    13,  360,  357, 1086, 1087,  355,  162,  354,   62,  175,
 /*   410 */   166,  263,  221,  984,  768,  411,  903,  961,  954,  949,
 /*   420 */   963,  964,  128,  335,    1,  769,   20,  173,  156,  900,
 /*   430 */   885,  886,  887,  888,  889,  890,  958,  392,  965,  408,
 /*   440 */  1086, 1087,  441,   39,  855,  856,  857,  858,  859,  321,
 /*   450 */   320,   35,  382,  263,  198,  984,  871,  885,  886,  887,
 /*   460 */   888,  889,  890,  891,  892,  893,  894,  895,  896,  897,
 /*   470 */   898,  899,  901,  422,  385,  441,  416,  414,  412,  932,
 /*   480 */   195,  307,  883,   68,  423,  443,  339,  950,  951,  952,
 /*   490 */   953,  955,  956,  959,  960,  962,  966,  127,  126,  190,
 /*   500 */   347,  803,  805,  325,  937,  174,  124,  125,  162,   36,
 /*   510 */   805,  300,  806,  807,  263, 1001,  984,  411,  380,  878,
 /*   520 */   806,  807,   52,  358,  239,  408, 1049,  305,  308,  326,
 /*   530 */   809,  900,  264,  808,  323,   40,   40, 1051,  809,  874,
 /*   540 */   319,  808,  370,  311,  804,  340,  774,  447,  445,  296,
 /*   550 */   375,  983,  427,  861,  309,  425,  389,  169,  834,  885,
 /*   560 */   886,  887,  888,  889,  890,  891,  892,  893,  894,  895,
 /*   570 */   896,  897,  898,  899,  901,  422,  421,  913,  416,  414,
 /*   580 */   412,  850,  832, 1072,   68,   18,  423,  914,  154,  843,
 /*   590 */   222,  408,  848,   18,  271,  844,  845,  846,  847,  148,
 /*   600 */   263,  239,  984,  123,  122,  121,  120, 1052, 1053, 1054,
 /*   610 */  1055, 1056, 1057,   90,   87,   86,   85,   89,   88,   84,
 /*   620 */    83,   81,   80,   79,   82,   77,   35,   91,   92,   98,
 /*   630 */    97,   96,  104,  103,  102,  101,  100,   99,  105,   93,
 /*   640 */    94,   95,  108,  107,  106,  116,  117,  114,  113,  112,
 /*   650 */   110,  109,  111,  799,  796,  797,   55,  329,  408,   78,
 /*   660 */  1520,  913,   72,  296,   22,  343,  263,  222,  984,  425,
 /*   670 */   389,  915,  798,  332, 1092,  986,  849,   90,   87,   86,
 /*   680 */    85,   89,   88,   84,   83,   81,   80,   79,   82,   77,
 /*   690 */   344,   91,   92,   98,   97,   96,  104,  103,  102,  101,
 /*   700 */   100,   99,  105,   93,   94,   95,  108,  107,  106,  116,
 /*   710 */   117,  114,  113,  112,  110,  109,  111,  405,  239,  408,
 /*   720 */   913,  218,  408,   78,  215,  408,   73,  157,  361,  420,
 /*   730 */   916,  934,  754,  263, 1000,  984,  410,  417,  835,  987,
 /*   740 */    35,   90,   87,   86,   85,   89,   88,   84,   83,   81,
 /*   750 */    80,   79,   82,   77,  265,   91,   92,   98,   97,   96,
 /*   760 */   104,  103,  102,  101,  100,   99,  105,   93,   94,   95,
 /*   770 */   108,  107,  106,  116,  117,  114,  113,  112,  110,  109,
 /*   780 */   111,  150,   33,  189, 1065,  384,  419,   78,  199,  408,
 /*   790 */    74,  345,  345,   30,  263,  239,  984,  263,  218,  984,
 /*   800 */   263,  215,  984,  988, 1075,   90,   87,   86,   85,   89,
 /*   810 */    88,   84,   83,   81,   80,   79,   82,   77,  869,   91,
 /*   820 */    92,   98,   97,   96,  104,  103,  102,  101,  100,   99,
 /*   830 */   105,   93,   94,   95,  108,  107,  106,  116,  117,  114,
 /*   840 */   113,  112,  110,  109,  111, 1065,  316,  862,  270,   43,
 /*   850 */    39,   78,  172,  193,  116,  117,  114,  113,  112,  110,
 /*   860 */   109,  111,   12,  990,  263,  199,  984,  860,   78,   90,
 /*   870 */    87,   86,   85,   89,   88,   84,   83,   81,   80,   79,
 /*   880 */    82,   77,  341,   91,   92,   98,   97,   96,  104,  103,
 /*   890 */   102,  101,  100,   99,  105,   93,   94,   95,  108,  107,
 /*   900 */   106,  116,  117,  114,  113,  112,  110,  109,  111, 1111,
 /*   910 */   794,  337,  336,  438,  272,   78,  944,  139,   53,  941,
 /*   920 */    90,   87,   86,   85,   89,   88,   84,   83,   81,   80,
 /*   930 */    79,   82,   77,  433,   91,   92,   98,   97,   96,  104,
 /*   940 */   103,  102,  101,  100,   99,  105,   93,   94,   95,  108,
 /*   950 */   107,  106,  116,  117,  114,  113,  112,  110,  109,  111,
 /*   960 */   200,  408,  348,  275, 1108,  935,   78,  145,  408,  273,
 /*   970 */   273,  149,  968,  133,  815,  181,  146,  811,   68, 1118,
 /*   980 */   388,  793,    5, 1049,   90,   87,   86,   85,   89,   88,
 /*   990 */    84,   83,   81,   80,   79,   82,   77, 1105,   91,   92,
 /*  1000 */    98,   97,   96,  104,  103,  102,  101,  100,   99,  105,
 /*  1010 */    93,   94,   95,  108,  107,  106,  116,  117,  114,  113,
 /*  1020 */   112,  110,  109,  111,  216,  408,  448,  259,   19,   16,
 /*  1030 */    78,  217,  408,  314,  315,  322,  263,  200,  984,  262,
 /*  1040 */    17,  188,   68,  263,  145,  984,    6,  297,   90,   87,
 /*  1050 */    86,   85,   89,   88,   84,   83,   81,   80,   79,   82,
 /*  1060 */    77, 1106,   91,   92,   98,   97,   96,  104,  103,  102,
 /*  1070 */   101,  100,   99,  105,   93,   94,   95,  108,  107,  106,
 /*  1080 */   116,  117,  114,  113,  112,  110,  109,  111,  298,  264,
 /*  1090 */   766,  164,  302,   39,   78,  303,  165,  878,  755,   50,
 /*  1100 */   263,  216,  984,  155,  158,  866,  989,  263,  217,  984,
 /*  1110 */     7, 1119,   90,   87,   86,   85,   89,   88,   84,   83,
 /*  1120 */    81,   80,   79,   82,   77, 1097,   91,   92,   98,   97,
 /*  1130 */    96,  104,  103,  102,  101,  100,   99,  105,   93,   94,
 /*  1140 */    95,  108,  107,  106,  116,  117,  114,  113,  112,  110,
 /*  1150 */   109,  111,  867,  865,  863,  864,  170,  168,   78,   54,
 /*  1160 */    90,   87,   86,   85,   89,   88,   84,   83,   81,   80,
 /*  1170 */    79,   82,   77,  143,   91,   92,   98,   97,   96,  104,
 /*  1180 */   103,  102,  101,  100,   99,  105,   93,   94,   95,  108,
 /*  1190 */   107,  106,  116,  117,  114,  113,  112,  110,  109,  111,
 /*  1200 */   201,  408,   21,  202,  408,  324,   78,  325,  801,  327,
 /*  1210 */   328,  800,  330,  948,  331,  333,  334,  947,   68,  946,
 /*  1220 */   171,  338,    8,  938,   90,   87,   86,   85,   89,   88,
 /*  1230 */    84,   83,   81,   80,   79,   82,   77,  366,   91,   92,
 /*  1240 */    98,   97,   96,  104,  103,  102,  101,  100,   99,  105,
 /*  1250 */    93,   94,   95,  108,  107,  106,  116,  117,  114,  113,
 /*  1260 */   112,  110,  109,  111,  203,  408,  836,  219,  408,   56,
 /*  1270 */    78,  342,   57,   58,  137,   43,  263,  201,  984,  263,
 /*  1280 */   202,  984,   68,   59, 1107,  177,    9,   44,   90,   87,
 /*  1290 */    86,   85,   89,   88,   84,   83,   81,   80,   79,   82,
 /*  1300 */    77,  371,   91,   92,   98,   97,   96,  104,  103,  102,
 /*  1310 */   101,  100,   99,  105,   93,   94,   95,  108,  107,  106,
 /*  1320 */   116,  117,  114,  113,  112,  110,  109,  111,  204,  408,
 /*  1330 */    61,  205,  408, 1098,   78,   63,   64,   10,  178,   15,
 /*  1340 */   263,  203,  984,  263,  219,  984,   38,   46,   66,   67,
 /*  1350 */    11, 1070,   90,   87,   86,   85,   89,   88,   84,   83,
 /*  1360 */    81,   80,   79,   82,   77, 1069,   91,   92,   98,   97,
 /*  1370 */    96,  104,  103,  102,  101,  100,   99,  105,   93,   94,
 /*  1380 */    95,  108,  107,  106,  116,  117,  114,  113,  112,  110,
 /*  1390 */   109,  111, 1068,   47,  367,  369,  368, 1067,   78,   48,
 /*  1400 */   372,  373,  374, 1064,  263,  204,  984,  263,  205,  984,
 /*  1410 */  1063,  918,  919, 1062, 1080, 1061,   90,   87,   86,   85,
 /*  1420 */    89,   88,   84,   83,   81,   80,   79,   82,   77,  920,
 /*  1430 */    91,   92,   98,   97,   96,  104,  103,  102,  101,  100,
 /*  1440 */    99,  105,   93,   94,   95,  108,  107,  106,  116,  117,
 /*  1450 */   114,  113,  112,  110,  109,  111,  206,  408, 1308,  207,
 /*  1460 */   408,   69,   78,  381,  140,  179,  295,   70,  184,  183,
 /*  1470 */   922,  132,   71,  390,  391,   31,  393,  394,   14,  395,
 /*  1480 */    90,   87,   86,   85,   89,   88,   84,   83,   81,   80,
 /*  1490 */    79,   82,   77,  396,   91,   92,   98,   97,   96,  104,
 /*  1500 */   103,  102,  101,  100,   99,  105,   93,   94,   95,  108,
 /*  1510 */   107,  106,  116,  117,  114,  113,  112,  110,  109,  111,
 /*  1520 */   208,  408, 1131,  209,  408,   24,   78,  927,  144,  130,
 /*  1530 */   921,  913,  263,  206,  984,  263,  207,  984,   78,  933,
 /*  1540 */   993,  115,  991, 1050,   90,   87,   86,   85,   89,   88,
 /*  1550 */    84,   83,   81,   80,   79,   82,   77,  161,   91,   92,
 /*  1560 */    98,   97,   96,  104,  103,  102,  101,  100,   99,  105,
 /*  1570 */    93,   94,   95,  108,  107,  106,  116,  117,  114,  113,
 /*  1580 */   112,  110,  109,  111,   25,   26,   27,   29,   28,  906,
 /*  1590 */    78,  905,  147,  418,  904,  118,  263,  208,  984,  263,
 /*  1600 */   209,  984,  424,  186,  194,  790,  985,  429,   90,   87,
 /*  1610 */    86,   85,   89,   88,   84,   83,   81,   80,   79,   82,
 /*  1620 */    77,  435,   91,   92,   98,   97,   96,  104,  103,  102,
 /*  1630 */   101,  100,   99,  105,   93,   94,   95,  108,  107,  106,
 /*  1640 */   116,  117,  114,  113,  112,  110,  109,  111,  428,  430,
 /*  1650 */   431,  432,  789,  434,   78,  436,   90,   87,   86,   85,
 /*  1660 */    89,   88,   84,   83,   81,   80,   79,   82,   77,   76,
 /*  1670 */    91,   92,   98,   97,   96,  104,  103,  102,  101,  100,
 /*  1680 */    99,  105,   93,   94,   95,  108,  107,  106,  116,  117,
 /*  1690 */   114,  113,  112,  110,  109,  111,  437,  221,  408, 1241,
 /*  1700 */   439,  440,   78, 1240,  104,  103,  102,  101,  100,   99,
 /*  1710 */   105,   93,   94,   95,  108,  107,  106,  116,  117,  114,
 /*  1720 */   113,  112,  110,  109,  111,  788,  142,  444,  787,  446,
 /*  1730 */   992,   78,   90,   87,   86,   85,   89,   88,   84,   83,
 /*  1740 */    81,   80,   79,   82,   77,  268,   91,   92,   98,   97,
 /*  1750 */    96,  104,  103,  102,  101,  100,   99,  105,   93,   94,
 /*  1760 */    95,  108,  107,  106,  116,  117,  114,  113,  112,  110,
 /*  1770 */   109,  111, 1149,  263,  221,  984, 1149, 1149,   78, 1149,
 /*  1780 */   810, 1149,   90,   87,   86,   85,   89,   88,   84,   83,
 /*  1790 */    81,   80,   79,   82,   77, 1149,   91,   92,   98,   97,
 /*  1800 */    96,  104,  103,  102,  101,  100,   99,  105,   93,   94,
 /*  1810 */    95,  108,  107,  106,  116,  117,  114,  113,  112,  110,
 /*  1820 */   109,  111,  167, 1149,  902, 1149,  152,  153,   78, 1149,
 /*  1830 */  1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,  222,
 /*  1840 */   408, 1149,  877, 1149, 1149,  902, 1149,  768,  928,  902,
 /*  1850 */   929,  404,  141, 1149, 1066,  931,  127,  126,  769,  911,
 /*  1860 */  1149, 1149,  872, 1149,  902,  124,  125, 1149,   36,  928,
 /*  1870 */   902,  929,  404,  400, 1149, 1149,  397,  982,  902,  317,
 /*  1880 */   911,    3, 1149, 1149, 1149, 1049, 1149, 1149,  928,  902,
 /*  1890 */   929,  404,  138, 1149, 1149, 1149, 1051, 1149, 1149,  911,
 /*  1900 */  1149, 1149,  928,  902,  929,  404,  141,  399,  403,  399,
 /*  1910 */   983, 1149, 1149,  911,  902,  263,  222,  984,  284, 1149,
 /*  1920 */  1060, 1076, 1059,  379, 1076, 1076, 1076, 1076, 1076, 1076,
 /*  1930 */  1076,  378,  377,  376,  362,  222,  408,  356,  928,  902,
 /*  1940 */   929,  404,  283, 1149, 1149,  423, 1149,  803,  805,  911,
 /*  1950 */  1066, 1149, 1149, 1149, 1149, 1149, 1149, 1149,  806,  807,
 /*  1960 */   902, 1149,  123,  122,  121,  120, 1052, 1053, 1054, 1055,
 /*  1970 */  1056, 1057, 1149, 1149,  773, 1149,  809,    4,  326,  808,
 /*  1980 */   426,   40,   40, 1149,  928,  902,  929,  404,  138,  221,
 /*  1990 */   408, 1149,  311,  221,  408,  911,  447,  445,  296, 1149,
 /*  2000 */  1149,  427,  408, 1149,  425,  389,  169, 1149, 1149, 1149,
 /*  2010 */  1149,  263,  222,  984, 1149, 1149, 1060, 1076, 1059,  379,
 /*  2020 */  1076, 1076, 1076, 1076, 1076, 1076, 1076,  378,  377,  376,
 /*  2030 */   362,   18, 1149,  356, 1149, 1149, 1149,  280, 1149,  220,
 /*  2040 */   408,  277,  363,  105,   93,   94,   95,  108,  107,  106,
 /*  2050 */   116,  117,  114,  113,  112,  110,  109,  111, 1149,  222,
 /*  2060 */   408, 1149,  902, 1149,   78,  263,  221,  984, 1149,  263,
 /*  2070 */   221,  984, 1149, 1149, 1066,   35, 1149,  263,  999,  984,
 /*  2080 */  1149, 1149, 1149, 1149,  902, 1149,  928,  902,  929,  294,
 /*  2090 */   141, 1149, 1149,  910,  408,  823,  363,  911, 1149,  318,
 /*  2100 */  1149, 1149, 1149, 1149,  825,  824,  828,  408,  928,  902,
 /*  2110 */   929,  404,  138,  222,  408,  263,  220,  984, 1149,  911,
 /*  2120 */  1149, 1149,  829,  830,  826,  827,  831, 1149, 1066, 1149,
 /*  2130 */  1149, 1149, 1149, 1149, 1149,  263,  222,  984,  902,  822,
 /*  2140 */  1060, 1077, 1059,  379, 1077, 1077, 1077, 1077, 1077, 1077,
 /*  2150 */  1077,  378,  377,  376,  362, 1149, 1149,  356, 1149, 1149,
 /*  2160 */   222,  408,  928,  902,  929,  404,  138, 1149, 1149,  263,
 /*  2170 */   998,  984, 1149,  911, 1149, 1149, 1149, 1149,   18, 1149,
 /*  2180 */  1149, 1149,  263,  997,  984, 1149, 1149, 1149, 1149,  263,
 /*  2190 */   222,  984,  363, 1149, 1060, 1077, 1059,  379, 1077, 1077,
 /*  2200 */  1077, 1077, 1077, 1077, 1077,  378,  377,  376,  362,  222,
 /*  2210 */   408,  356, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 /*  2220 */  1149, 1149, 1149, 1149, 1066, 1149,  326, 1149, 1149, 1149,
 /*  2230 */  1149, 1149,  221,  408,  902, 1149,  263,  222,  984, 1149,
 /*  2240 */   311, 1149, 1149,  820, 1091,  445,  296,  363, 1149,  427,
 /*  2250 */   223,  408,  425,  389,  169,  224,  408,  279,  928,  902,
 /*  2260 */   929,  404,  138, 1149,  222,  408, 1149, 1149, 1149,  911,
 /*  2270 */  1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1066,
 /*  2280 */   278, 1149, 1149, 1149, 1149,  263,  222,  984,  408,  902,
 /*  2290 */  1060, 1085, 1059,  379, 1085, 1085, 1085, 1085, 1085, 1085,
 /*  2300 */  1085,  378,  377,  376,  362, 1149, 1149,  356,  263,  221,
 /*  2310 */   984, 1149, 1149,  928,  902,  929,  404,  138, 1149, 1149,
 /*  2320 */  1149,  210,  408,   35,  911, 1149,  263,  223,  984, 1149,
 /*  2330 */  1149,  263,  224,  984, 1149, 1149, 1149, 1149, 1149, 1149,
 /*  2340 */   263,  222,  984, 1149,  902, 1060, 1084, 1059,  379, 1084,
 /*  2350 */  1084, 1084, 1084, 1084, 1084, 1084,  378,  377,  376,  362,
 /*  2360 */   363, 1149,  356,  263,  996,  984, 1149, 1149,  928,  902,
 /*  2370 */   929,  287,  141, 1149, 1149,  909, 1149,  222,  408,  911,
 /*  2380 */   152,  153, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 /*  2390 */  1149, 1149, 1066, 1149,  127,  126,  877,  263,  210,  984,
 /*  2400 */  1149,  768,  902,  124,  125,  264,   36, 1149, 1149, 1149,
 /*  2410 */   884, 1149,  769, 1149,  902,  982,  873,  211,  408, 1149,
 /*  2420 */  1149, 1149, 1149, 1049, 1149, 1149,  928,  902,  929,  404,
 /*  2430 */   138, 1149, 1149, 1149, 1051, 1149, 1149,  911,  928,  902,
 /*  2440 */   929,  404,  141, 1149, 1149,  413, 1149, 1149,  983,  911,
 /*  2450 */  1149, 1149,  902,  263,  222,  984,  363, 1149, 1060, 1083,
 /*  2460 */  1059,  379, 1083, 1083, 1083, 1083, 1083, 1083, 1083,  378,
 /*  2470 */   377,  376,  362,  222,  408,  356,  928,  902,  929,  404,
 /*  2480 */   141,  399,  131,  399, 1149, 1149, 1149,  911, 1066, 1149,
 /*  2490 */  1149, 1149, 1149,  263,  211,  984,  221,  408,  902,  943,
 /*  2500 */   123,  122,  121,  120, 1052, 1053, 1054, 1055, 1056, 1057,
 /*  2510 */   363, 1149,  902,  196,  408, 1149, 1149, 1149, 1149, 1149,
 /*  2520 */   197,  408,  928,  902,  929,  404,  138,  222,  408, 1149,
 /*  2530 */  1149, 1149, 1149,  911, 1149, 1149,  928,  902,  929,  286,
 /*  2540 */   141, 1149, 1066,  908,  281, 1149, 1149,  911, 1149,  263,
 /*  2550 */   222,  984,  902, 1149, 1060, 1096, 1059,  379, 1096, 1096,
 /*  2560 */  1096, 1096, 1096, 1096, 1096,  378,  377,  376,  362, 1149,
 /*  2570 */  1149,  356,  263,  221,  984, 1149,  928,  902,  929,  404,
 /*  2580 */   138, 1149, 1149,  212,  408, 1149, 1149,  911, 1149,  263,
 /*  2590 */   196,  984, 1149, 1149,  240,  408,  263,  197,  984, 1149,
 /*  2600 */  1149, 1149, 1149,  263,  222,  984, 1149,  902, 1060, 1095,
 /*  2610 */  1059,  379, 1095, 1095, 1095, 1095, 1095, 1095, 1095,  378,
 /*  2620 */   377,  376,  362,  363, 1149,  356, 1149, 1149,  221,  408,
 /*  2630 */  1149,  928,  902,  929,  404,  141,  213,  408,  415, 1149,
 /*  2640 */   222,  408,  911, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 /*  2650 */  1149, 1149, 1149, 1149, 1149, 1066, 1149,  127,  126,  263,
 /*  2660 */   212,  984, 1149, 1042,  408,  902,  124,  125, 1149,   36,
 /*  2670 */   263,  240,  984, 1071, 1149, 1149,  282, 1149,  982,  226,
 /*  2680 */   408, 1149,  227,  408, 1149, 1149, 1049, 1149, 1149,  928,
 /*  2690 */   902,  929,  404,  138, 1149, 1149, 1149, 1051, 1149, 1149,
 /*  2700 */   911,  228,  408, 1149,  263,  221,  984, 1149, 1149, 1149,
 /*  2710 */  1149,  983,  263,  213,  984, 1149,  263,  222,  984,  363,
 /*  2720 */  1149, 1060, 1094, 1059,  379, 1094, 1094, 1094, 1094, 1094,
 /*  2730 */  1094, 1094,  378,  377,  376,  362,  222,  408,  356,  263,
 /*  2740 */  1042,  984, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 /*  2750 */  1149, 1066, 1149, 1149, 1149,  263,  226,  984,  263,  227,
 /*  2760 */   984,  902, 1149,  123,  122,  121,  120, 1052, 1053, 1054,
 /*  2770 */  1055, 1056, 1057,  363, 1149,  229,  408,  263,  228,  984,
 /*  2780 */  1149, 1149, 1149,  230,  408,  928,  902,  929,  404,  138,
 /*  2790 */   222,  408, 1149, 1149, 1149, 1149,  911, 1149, 1149, 1149,
 /*  2800 */  1149, 1149, 1149, 1149, 1149, 1066, 1149, 1149, 1149, 1149,
 /*  2810 */  1149, 1149,  263,  222,  984,  902, 1149, 1060, 1082, 1059,
 /*  2820 */   379, 1082, 1082, 1082, 1082, 1082, 1082, 1082,  378,  377,
 /*  2830 */   376,  362, 1149, 1149,  356,  231,  408, 1149, 1149,  928,
 /*  2840 */   902,  929,  404,  138, 1149, 1149, 1149, 1149, 1149, 1149,
 /*  2850 */   911,  263,  229,  984, 1149, 1149, 1149, 1149, 1149,  263,
 /*  2860 */   230,  984,  232,  408, 1149, 1149,  263,  222,  984,  233,
 /*  2870 */   408, 1060, 1081, 1059,  379, 1081, 1081, 1081, 1081, 1081,
 /*  2880 */  1081, 1081,  378,  377,  376,  362,  363, 1149,  356, 1149,
 /*  2890 */  1149,  234,  408, 1149,  235,  408, 1149,  236,  408, 1149,
 /*  2900 */  1149, 1149, 1149,  222,  408, 1149, 1149, 1149, 1149, 1149,
 /*  2910 */  1149,  263,  231,  984, 1149, 1149, 1149, 1149, 1066, 1149,
 /*  2920 */  1149, 1149,  127,  126, 1149, 1149, 1149, 1149,  902, 1149,
 /*  2930 */  1149,  124,  125, 1149,   36,  237,  408, 1149,  263,  232,
 /*  2940 */   984,  241,  408,  982, 1149,  263,  233,  984, 1149,  242,
 /*  2950 */   408, 1049,  928,  902,  929,  404,  138,   37, 1149, 1149,
 /*  2960 */  1149, 1149, 1051,  911,  253,  408, 1149,  263,  234,  984,
 /*  2970 */   263,  235,  984,  263,  236,  984,  983, 1149, 1149,  263,
 /*  2980 */   222,  984,  363, 1149, 1060,  160, 1059,  379,  160,  160,
 /*  2990 */   160,  160,  160,  160,  160,  378,  377,  376,  362,  222,
 /*  3000 */   408,  356, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 /*  3010 */  1149,  263,  237,  984, 1066, 1149, 1149,  263,  241,  984,
 /*  3020 */  1149, 1149,  254,  408,  902,  263,  242,  984,  123,  122,
 /*  3030 */   121,  120, 1052, 1053, 1054, 1055, 1056, 1057, 1149, 1149,
 /*  3040 */   263,  253,  984, 1149, 1149, 1149, 1149, 1149,  928,  902,
 /*  3050 */   929,  404,  138, 1149, 1149, 1149, 1149,  255,  408,  911,
 /*  3060 */   243,  408, 1149, 1149,  244,  408, 1149, 1149, 1149, 1149,
 /*  3070 */  1149, 1149, 1149, 1149, 1149,  263,  222,  984, 1149, 1149,
 /*  3080 */  1060, 1079, 1059,  379, 1079, 1079, 1079, 1079, 1079, 1079,
 /*  3090 */  1079,  378,  377,  376,  362,  162, 1149,  356,  263,  254,
 /*  3100 */   984, 1149,  245,  408,  411,  903, 1149, 1149,  246,  408,
 /*  3110 */  1149, 1149, 1149, 1149,  247,  408, 1149, 1149,  900,   93,
 /*  3120 */    94,   95,  108,  107,  106,  116,  117,  114,  113,  112,
 /*  3130 */   110,  109,  111,  263,  255,  984,  263,  243,  984,   78,
 /*  3140 */   263,  244,  984, 1149, 1149, 1149,  885,  886,  887,  888,
 /*  3150 */   889,  890,  891,  892,  893,  894,  895,  896,  897,  898,
 /*  3160 */   899,  901,  422,  421, 1149,  416,  414,  412,  248,  408,
 /*  3170 */  1149,  249,  408,  423,  250,  408, 1149, 1149,  263,  245,
 /*  3180 */   984,  251,  408, 1149,  263,  246,  984,  979,  980,  981,
 /*  3190 */   263,  247,  984,  252,  408, 1149, 1149,  256,  408, 1149,
 /*  3200 */  1149,   77, 1149,   91,   92,   98,   97,   96,  104,  103,
 /*  3210 */   102,  101,  100,   99,  105,   93,   94,   95,  108,  107,
 /*  3220 */   106,  116,  117,  114,  113,  112,  110,  109,  111, 1149,
 /*  3230 */  1149,  257,  408,  162, 1149,   78, 1149,  258,  408, 1149,
 /*  3240 */   289,  408,  411,  903,  263,  248,  984,  263,  249,  984,
 /*  3250 */   263,  250,  984, 1149, 1149, 1149,  900,  263,  251,  984,
 /*  3260 */  1149, 1149, 1149, 1149,  290,  408, 1149,  407,  408,  263,
 /*  3270 */   252,  984, 1149,  263,  256,  984, 1149,  291,  408, 1149,
 /*  3280 */   292,  408, 1149, 1149,  885,  886,  887,  888,  889,  890,
 /*  3290 */   891,  892,  893,  894,  895,  896,  897,  898,  899,  901,
 /*  3300 */   422,  421, 1149,  416,  414,  412,  932,  263,  257,  984,
 /*  3310 */  1149,  423, 1149,  263,  258,  984,  263,  289,  984, 1149,
 /*  3320 */  1149, 1149, 1149, 1149, 1149, 1149,  293,  408, 1149,  162,
 /*  3330 */  1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,  411,  903,
 /*  3340 */   263,  290,  984,  263,  407,  984, 1149, 1149, 1149, 1149,
 /*  3350 */  1149, 1149,  900,  263,  291,  984,  263,  292,  984,  238,
 /*  3360 */   408, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 /*  3370 */  1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 /*  3380 */   885,  886,  887,  888,  889,  890,  891,  892,  893,  894,
 /*  3390 */   895,  896,  897,  898,  899,  901,  422,  421, 1149,  416,
 /*  3400 */   414,  412,  263,  293,  984,  261,  408,  423,   92,   98,
 /*  3410 */    97,   96,  104,  103,  102,  101,  100,   99,  105,   93,
 /*  3420 */    94,   95,  108,  107,  106,  116,  117,  114,  113,  112,
 /*  3430 */   110,  109,  111, 1149, 1149,  263,  238,  984, 1149,   78,
 /*  3440 */    98,   97,   96,  104,  103,  102,  101,  100,   99,  105,
 /*  3450 */    93,   94,   95,  108,  107,  106,  116,  117,  114,  113,
 /*  3460 */   112,  110,  109,  111,  127,  126,  260,  408, 1149, 1149,
 /*  3470 */    78,  214,  408,  124,  125, 1149,   36,  127,  126, 1149,
 /*  3480 */  1149,  263,  261,  984, 1149,  409,  124,  125, 1149,   36,
 /*  3490 */  1149, 1149, 1149, 1049, 1149, 1149, 1149, 1149,  982, 1149,
 /*  3500 */  1149, 1149, 1149, 1149, 1051, 1149, 1049, 1149, 1149, 1149,
 /*  3510 */  1149, 1149, 1149, 1149, 1149, 1149, 1149, 1051,  983, 1149,
 /*  3520 */  1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 /*  3530 */  1149,  983, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 /*  3540 */  1149, 1149,  263,  260,  984, 1149, 1149,  263,  214,  984,
 /*  3550 */  1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 /*  3560 */  1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,  222,  408,
 /*  3570 */   123,  122,  121,  120, 1052, 1053, 1054, 1055, 1056, 1057,
 /*  3580 */  1149, 1149, 1149,  123,  122,  121,  120, 1052, 1053, 1054,
 /*  3590 */  1055, 1056, 1057,  902, 1149, 1149, 1149, 1149, 1149, 1149,
 /*  3600 */  1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 /*  3610 */  1149, 1149, 1149, 1149, 1149, 1149, 1149,  928,  902,  929,
 /*  3620 */   404,  138, 1149, 1149, 1149, 1149, 1149, 1149,  911, 1149,
 /*  3630 */  1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 /*  3640 */  1149, 1149, 1149, 1149,  263,  222,  984, 1149, 1149, 1149,
 /*  3650 */  1149, 1149, 1091, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 /*  3660 */  1149, 1149, 1088, 1149,  359,  346,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */    33,   34,  169,  170,  171,  172,  173,  174,  175,   42,
 /*    10 */    43,   44,   45,   46,  181,  180,   49,  162,  179,  180,
 /*    20 */    53,   54,  167,  168,  179,  180,  240,  241,  242,   62,
 /*    30 */   244,  165,  166,   66,   67,   68,   69,   54,  205,   63,
 /*    40 */    73,   28,   29,   30,   31,   32,   33,   34,   35,   36,
 /*    50 */    37,   38,   39,   40,   87,   54,  179,  180,  214,  215,
 /*    60 */    47,  222,   95,   96,   97,   98,   99,  100,  101,  102,
 /*    70 */   103,  104,  105,  106,  107,  108,  109,  110,  111,  112,
 /*    80 */   162,  114,  115,  116,   42,   43,   44,   45,   46,  122,
 /*    90 */   255,  256,  257,  117,  255,  256,  257,  258,  259,  222,
 /*   100 */   255,  256,  257,  258,  259,  187,  139,  140,  141,  142,
 /*   110 */   143,  144,  145,  146,  147,  148,  149,  150,  151,  152,
 /*   120 */   153,  154,  155,  156,  157,  158,  260,  160,  161,  237,
 /*   130 */   238,   40,  255,  256,  257,  258,  259,  163,   47,  162,
 /*   140 */    33,   34,  224,  225,  226,  135,  172,  173,  174,   42,
 /*   150 */    43,   44,   45,   46,  179,  180,   49,  183,   54,   50,
 /*   160 */    53,   54,   54,  189,  190,  191,  192,  193,  194,   62,
 /*   170 */    66,   67,   63,   66,   67,   68,   69,  200,  201,  202,
 /*   180 */    73,   29,   30,   31,   32,   33,   34,   35,   36,   37,
 /*   190 */    38,   39,   40,   50,   87,   45,   46,  222,    1,   47,
 /*   200 */   237,  238,   95,   96,   97,   98,   99,  100,  101,  102,
 /*   210 */   103,  104,  105,  106,  107,  108,  109,  110,  111,  112,
 /*   220 */   246,  114,  115,  116,    0,  209,  210,  211,  212,  122,
 /*   230 */   255,  256,  257,  258,  259,  180,   55,   56,   57,   58,
 /*   240 */    59,   60,   61,   46,  162,   64,  139,  140,  141,  142,
 /*   250 */   143,  144,  145,  146,  147,  148,  149,  150,  151,  152,
 /*   260 */   153,  154,  155,  156,  157,  158,  123,  160,  161,  187,
 /*   270 */    54,   54,   48,   46,    1,   51,   52,   53,   63,   49,
 /*   280 */    33,   34,   65,   35,   36,   37,   38,   39,   40,   42,
 /*   290 */    43,   44,   45,   46,   70,   47,   49,   14,   68,   75,
 /*   300 */    53,   54,   78,   79,   87,  223,  224,  225,  226,   62,
 /*   310 */   255,  256,  257,   66,   67,   68,  237,  238,  162,   46,
 /*   320 */    73,   30,   31,   32,   33,   34,   35,   36,   37,   38,
 /*   330 */    39,   40,  117,   50,   87,  179,  180,   54,   47,  242,
 /*   340 */   204,  244,   95,   96,   97,   98,   99,  100,  101,  102,
 /*   350 */   103,  104,  105,  106,  107,  108,  109,  110,  111,  112,
 /*   360 */   162,  114,  115,  116,  228,  229,  230,  231,  232,  122,
 /*   370 */   217,   69,  244,   14,   72,  239,  162,  179,  180,  204,
 /*   380 */    78,   79,  254,  227,  278,  279,  139,  140,  141,  142,
 /*   390 */   143,  144,  145,  146,  147,  148,  149,  150,  151,  152,
 /*   400 */   153,  154,  155,  156,  157,  158,   44,  160,  161,   50,
 /*   410 */    54,  255,  256,  257,   54,   53,   54,   55,   56,   57,
 /*   420 */    58,   59,  208,   61,   68,   65,  243,   65,  187,   67,
 /*   430 */    95,   96,   97,   98,   99,  100,   74,  239,   76,  180,
 /*   440 */   156,  157,  188,   50,   88,   89,   90,   91,   92,   93,
 /*   450 */    94,  149,  198,  255,  256,  257,   63,   95,   96,   97,
 /*   460 */    98,   99,  100,  101,  102,  103,  104,  105,  106,  107,
 /*   470 */   108,  109,  110,  111,  112,  188,  114,  115,  116,  117,
 /*   480 */    49,   53,   49,   50,  122,  198,  124,  125,  126,  127,
 /*   490 */   128,  129,  130,  131,  132,  133,  134,   33,   34,   68,
 /*   500 */   250,  162,  163,   75,   49,   50,   42,   43,   44,   45,
 /*   510 */   163,  187,  173,  174,  255,  256,  257,   53,   54,   49,
 /*   520 */   173,  174,   34,  178,  179,  180,   62,  187,  187,   52,
 /*   530 */   191,   67,   44,  194,  195,  196,  197,   73,  191,   69,
 /*   540 */    50,  194,   46,   66,  197,   50,   69,   70,   71,   72,
 /*   550 */    54,   87,   75,   63,  187,   78,   79,   80,   63,   95,
 /*   560 */    96,   97,   98,   99,  100,  101,  102,  103,  104,  105,
 /*   570 */   106,  107,  108,  109,  110,  111,  112,   21,  114,  115,
 /*   580 */   116,  213,   69,   49,   50,  246,  122,   31,  187,   14,
 /*   590 */   179,  180,  213,  246,   81,   82,   83,   84,   85,   86,
 /*   600 */   255,  256,  257,  139,  140,  141,  142,  143,  144,  145,
 /*   610 */   146,  147,  148,    1,    2,    3,    4,    5,    6,    7,
 /*   620 */     8,    9,   10,   11,   12,   13,  149,   15,   16,   17,
 /*   630 */    18,   19,   20,   21,   22,   23,   24,   25,   26,   27,
 /*   640 */    28,   29,   30,   31,   32,   33,   34,   35,   36,   37,
 /*   650 */    38,   39,   40,   57,   58,   59,   81,   61,  180,   47,
 /*   660 */    69,   21,   50,   72,   68,   29,  255,  256,  257,   78,
 /*   670 */    79,   31,   76,   77,  263,   63,  213,    1,    2,    3,
 /*   680 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   690 */    54,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*   700 */    24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
 /*   710 */    34,   35,   36,   37,   38,   39,   40,  178,  179,  180,
 /*   720 */    21,  179,  180,   47,  179,  180,   50,  187,  274,   54,
 /*   730 */    31,  238,  184,  255,  256,  257,  187,  187,   54,   63,
 /*   740 */   149,    1,    2,    3,    4,    5,    6,    7,    8,    9,
 /*   750 */    10,   11,   12,   13,  188,   15,   16,   17,   18,   19,
 /*   760 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   770 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*   780 */    40,   14,  244,  185,   49,  247,  111,   47,  179,  180,
 /*   790 */    50,  253,  254,   45,  255,  256,  257,  255,  256,  257,
 /*   800 */   255,  256,  257,   63,   69,    1,    2,    3,    4,    5,
 /*   810 */     6,    7,    8,    9,   10,   11,   12,   13,  216,   15,
 /*   820 */    16,   17,   18,   19,   20,   21,   22,   23,   24,   25,
 /*   830 */    26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
 /*   840 */    36,   37,   38,   39,   40,   49,  219,   62,  220,   50,
 /*   850 */    50,   47,   45,  218,   33,   34,   35,   36,   37,   38,
 /*   860 */    39,   40,   63,   63,  255,  256,  257,   63,   47,    1,
 /*   870 */     2,    3,    4,    5,    6,    7,    8,    9,   10,   11,
 /*   880 */    12,   13,  162,   15,   16,   17,   18,   19,   20,   21,
 /*   890 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
 /*   900 */    32,   33,   34,   35,   36,   37,   38,   39,   40,   49,
 /*   910 */   176,   50,  252,   54,  188,   47,  218,   54,   50,  250,
 /*   920 */     1,    2,    3,    4,    5,    6,    7,    8,    9,   10,
 /*   930 */    11,   12,   13,   74,   15,   16,   17,   18,   19,   20,
 /*   940 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   950 */    31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
 /*   960 */   179,  180,  250,  250,  279,  245,   47,  179,  180,  249,
 /*   970 */   250,  250,   78,  248,  202,   50,   14,  176,   50,  177,
 /*   980 */   203,  176,   63,   62,    1,    2,    3,    4,    5,    6,
 /*   990 */     7,    8,    9,   10,   11,   12,   13,   69,   15,   16,
 /*  1000 */    17,   18,   19,   20,   21,   22,   23,   24,   25,   26,
 /*  1010 */    27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
 /*  1020 */    37,   38,   39,   40,  179,  180,  180,  186,  206,  182,
 /*  1030 */    47,  179,  180,  219,  219,  219,  255,  256,  257,  199,
 /*  1040 */   182,   68,   50,  255,  256,  257,   63,   54,    1,    2,
 /*  1050 */     3,    4,    5,    6,    7,    8,    9,   10,   11,   12,
 /*  1060 */    13,   69,   15,   16,   17,   18,   19,   20,   21,   22,
 /*  1070 */    23,   24,   25,   26,   27,   28,   29,   30,   31,   32,
 /*  1080 */    33,   34,   35,   36,   37,   38,   39,   40,   53,   44,
 /*  1090 */    63,   45,   62,   50,   47,   45,   54,   49,   54,   68,
 /*  1100 */   255,  256,  257,   47,   47,   69,   63,  255,  256,  257,
 /*  1110 */    63,   49,    1,    2,    3,    4,    5,    6,    7,    8,
 /*  1120 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*  1130 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*  1140 */    29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
 /*  1150 */    39,   40,   49,   69,   62,   69,   69,   45,   47,   45,
 /*  1160 */     1,    2,    3,    4,    5,    6,    7,    8,    9,   10,
 /*  1170 */    11,   12,   13,   68,   15,   16,   17,   18,   19,   20,
 /*  1180 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*  1190 */    31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
 /*  1200 */   179,  180,   68,  179,  180,   54,   47,   75,   63,   62,
 /*  1210 */    45,   63,   74,   63,   45,   62,   45,   63,   50,   62,
 /*  1220 */    62,   45,   63,   49,    1,    2,    3,    4,    5,    6,
 /*  1230 */     7,    8,    9,   10,   11,   12,   13,   69,   15,   16,
 /*  1240 */    17,   18,   19,   20,   21,   22,   23,   24,   25,   26,
 /*  1250 */    27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
 /*  1260 */    37,   38,   39,   40,  179,  180,   54,  179,  180,    1,
 /*  1270 */    47,   54,    1,   14,   50,   50,  255,  256,  257,  255,
 /*  1280 */   256,  257,   50,   14,   69,   50,   63,   68,    1,    2,
 /*  1290 */     3,    4,    5,    6,    7,    8,    9,   10,   11,   12,
 /*  1300 */    13,   69,   15,   16,   17,   18,   19,   20,   21,   22,
 /*  1310 */    23,   24,   25,   26,   27,   28,   29,   30,   31,   32,
 /*  1320 */    33,   34,   35,   36,   37,   38,   39,   40,  179,  180,
 /*  1330 */     1,  179,  180,   14,   47,   45,   45,  159,   45,   45,
 /*  1340 */   255,  256,  257,  255,  256,  257,   49,   49,   45,   45,
 /*  1350 */    63,   49,    1,    2,    3,    4,    5,    6,    7,    8,
 /*  1360 */     9,   10,   11,   12,   13,   49,   15,   16,   17,   18,
 /*  1370 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*  1380 */    29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
 /*  1390 */    39,   40,   49,   68,    1,  123,   54,   49,   47,   68,
 /*  1400 */     1,  123,   46,   49,  255,  256,  257,  255,  256,  257,
 /*  1410 */    49,   58,   59,   49,   63,   49,    1,    2,    3,    4,
 /*  1420 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   76,
 /*  1430 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /*  1440 */    25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
 /*  1450 */    35,   36,   37,   38,   39,   40,  179,  180,   54,  179,
 /*  1460 */   180,    1,   47,  123,   46,   63,   20,    1,   54,   69,
 /*  1470 */   117,   68,   45,   63,   21,   45,   63,   21,   63,   54,
 /*  1480 */     1,    2,    3,    4,    5,    6,    7,    8,    9,   10,
 /*  1490 */    11,   12,   13,   20,   15,   16,   17,   18,   19,   20,
 /*  1500 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*  1510 */    31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
 /*  1520 */   179,  180,   63,  179,  180,   50,   47,   29,   50,   45,
 /*  1530 */    63,   21,  255,  256,  257,  255,  256,  257,   47,  123,
 /*  1540 */    54,   14,   63,   62,    1,    2,    3,    4,    5,    6,
 /*  1550 */     7,    8,    9,   10,   11,   12,   13,   20,   15,   16,
 /*  1560 */    17,   18,   19,   20,   21,   22,   23,   24,   25,   26,
 /*  1570 */    27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
 /*  1580 */    37,   38,   39,   40,   20,   50,   20,   20,   50,   21,
 /*  1590 */    47,   21,   20,   54,   54,    1,  255,  256,  257,  255,
 /*  1600 */   256,  257,   54,   69,   54,   49,   63,   50,    1,    2,
 /*  1610 */     3,    4,    5,    6,    7,    8,    9,   10,   11,   12,
 /*  1620 */    13,   50,   15,   16,   17,   18,   19,   20,   21,   22,
 /*  1630 */    23,   24,   25,   26,   27,   28,   29,   30,   31,   32,
 /*  1640 */    33,   34,   35,   36,   37,   38,   39,   40,   73,   54,
 /*  1650 */    14,   54,   49,   73,   47,   54,    1,    2,    3,    4,
 /*  1660 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*  1670 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /*  1680 */    25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
 /*  1690 */    35,   36,   37,   38,   39,   40,   14,  179,  180,   50,
 /*  1700 */    54,   50,   47,   50,   20,   21,   22,   23,   24,   25,
 /*  1710 */    26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
 /*  1720 */    36,   37,   38,   39,   40,   49,   14,   54,   49,   54,
 /*  1730 */   123,   47,    1,    2,    3,    4,    5,    6,    7,    8,
 /*  1740 */     9,   10,   11,   12,   13,  227,   15,   16,   17,   18,
 /*  1750 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*  1760 */    29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
 /*  1770 */    39,   40,  280,  255,  256,  257,  280,  280,   47,  280,
 /*  1780 */    49,  280,    1,    2,    3,    4,    5,    6,    7,    8,
 /*  1790 */     9,   10,   11,   12,   13,  280,   15,   16,   17,   18,
 /*  1800 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*  1810 */    29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
 /*  1820 */    39,   40,  162,  280,  204,  280,   33,   34,   47,  280,
 /*  1830 */   280,  280,  280,  280,  280,  280,  280,  280,  280,  179,
 /*  1840 */   180,  280,   49,  280,  280,  204,  280,   54,  228,  229,
 /*  1850 */   230,  231,  232,  280,  194,  235,   33,   34,   65,  239,
 /*  1860 */   280,  280,   69,  280,  204,   42,   43,  280,   45,  228,
 /*  1870 */   229,  230,  231,  232,  280,  280,   53,   54,  204,  219,
 /*  1880 */   239,  221,  280,  280,  280,   62,  280,  280,  228,  229,
 /*  1890 */   230,  231,  232,  280,  280,  280,   73,  280,  280,  239,
 /*  1900 */   280,  280,  228,  229,  230,  231,  232,  233,  234,  235,
 /*  1910 */    87,  280,  280,  239,  204,  255,  256,  257,  162,  280,
 /*  1920 */   260,  261,  262,  263,  264,  265,  266,  267,  268,  269,
 /*  1930 */   270,  271,  272,  273,  274,  179,  180,  277,  228,  229,
 /*  1940 */   230,  231,  232,  280,  280,  122,  280,  162,  163,  239,
 /*  1950 */   194,  280,  280,  280,  280,  280,  280,  280,  173,  174,
 /*  1960 */   204,  280,  139,  140,  141,  142,  143,  144,  145,  146,
 /*  1970 */   147,  148,  280,  280,   48,  280,  191,  221,   52,  194,
 /*  1980 */   195,  196,  197,  280,  228,  229,  230,  231,  232,  179,
 /*  1990 */   180,  280,   66,  179,  180,  239,   70,   71,   72,  280,
 /*  2000 */   280,   75,  180,  280,   78,   79,   80,  280,  280,  280,
 /*  2010 */   280,  255,  256,  257,  280,  280,  260,  261,  262,  263,
 /*  2020 */   264,  265,  266,  267,  268,  269,  270,  271,  272,  273,
 /*  2030 */   274,  246,  280,  277,  280,  280,  280,  227,  280,  179,
 /*  2040 */   180,  227,  162,   26,   27,   28,   29,   30,   31,   32,
 /*  2050 */    33,   34,   35,   36,   37,   38,   39,   40,  280,  179,
 /*  2060 */   180,  280,  204,  280,   47,  255,  256,  257,  280,  255,
 /*  2070 */   256,  257,  280,  280,  194,  149,  280,  255,  256,  257,
 /*  2080 */   280,  280,  280,  280,  204,  280,  228,  229,  230,  231,
 /*  2090 */   232,  280,  280,  235,  180,  163,  162,  239,  280,  219,
 /*  2100 */   280,  280,  280,  280,  172,  173,  174,  180,  228,  229,
 /*  2110 */   230,  231,  232,  179,  180,  255,  256,  257,  280,  239,
 /*  2120 */   280,  280,  190,  191,  192,  193,  194,  280,  194,  280,
 /*  2130 */   280,  280,  280,  280,  280,  255,  256,  257,  204,  207,
 /*  2140 */   260,  261,  262,  263,  264,  265,  266,  267,  268,  269,
 /*  2150 */   270,  271,  272,  273,  274,  280,  280,  277,  280,  280,
 /*  2160 */   179,  180,  228,  229,  230,  231,  232,  280,  280,  255,
 /*  2170 */   256,  257,  280,  239,  280,  280,  280,  280,  246,  280,
 /*  2180 */   280,  280,  255,  256,  257,  280,  280,  280,  280,  255,
 /*  2190 */   256,  257,  162,  280,  260,  261,  262,  263,  264,  265,
 /*  2200 */   266,  267,  268,  269,  270,  271,  272,  273,  274,  179,
 /*  2210 */   180,  277,  280,  280,  280,  280,  280,  280,  280,  280,
 /*  2220 */   280,  280,  280,  280,  194,  280,   52,  280,  280,  280,
 /*  2230 */   280,  280,  179,  180,  204,  280,  255,  256,  257,  280,
 /*  2240 */    66,  280,  280,   69,  263,   71,   72,  162,  280,   75,
 /*  2250 */   179,  180,   78,   79,   80,  179,  180,  276,  228,  229,
 /*  2260 */   230,  231,  232,  280,  179,  180,  280,  280,  280,  239,
 /*  2270 */   280,  280,  280,  280,  280,  280,  280,  280,  280,  194,
 /*  2280 */   227,  280,  280,  280,  280,  255,  256,  257,  180,  204,
 /*  2290 */   260,  261,  262,  263,  264,  265,  266,  267,  268,  269,
 /*  2300 */   270,  271,  272,  273,  274,  280,  280,  277,  255,  256,
 /*  2310 */   257,  280,  280,  228,  229,  230,  231,  232,  280,  280,
 /*  2320 */   280,  179,  180,  149,  239,  280,  255,  256,  257,  280,
 /*  2330 */   280,  255,  256,  257,  280,  280,  280,  280,  280,  280,
 /*  2340 */   255,  256,  257,  280,  204,  260,  261,  262,  263,  264,
 /*  2350 */   265,  266,  267,  268,  269,  270,  271,  272,  273,  274,
 /*  2360 */   162,  280,  277,  255,  256,  257,  280,  280,  228,  229,
 /*  2370 */   230,  231,  232,  280,  280,  235,  280,  179,  180,  239,
 /*  2380 */    33,   34,  280,  280,  280,  280,  280,  280,  280,  280,
 /*  2390 */   280,  280,  194,  280,   33,   34,   49,  255,  256,  257,
 /*  2400 */   280,   54,  204,   42,   43,   44,   45,  280,  280,  280,
 /*  2410 */    49,  280,   65,  280,  204,   54,   69,  179,  180,  280,
 /*  2420 */   280,  280,  280,   62,  280,  280,  228,  229,  230,  231,
 /*  2430 */   232,  280,  280,  280,   73,  280,  280,  239,  228,  229,
 /*  2440 */   230,  231,  232,  280,  280,  235,  280,  280,   87,  239,
 /*  2450 */   280,  280,  204,  255,  256,  257,  162,  280,  260,  261,
 /*  2460 */   262,  263,  264,  265,  266,  267,  268,  269,  270,  271,
 /*  2470 */   272,  273,  274,  179,  180,  277,  228,  229,  230,  231,
 /*  2480 */   232,  233,  234,  235,  280,  280,  280,  239,  194,  280,
 /*  2490 */   280,  280,  280,  255,  256,  257,  179,  180,  204,  251,
 /*  2500 */   139,  140,  141,  142,  143,  144,  145,  146,  147,  148,
 /*  2510 */   162,  280,  204,  179,  180,  280,  280,  280,  280,  280,
 /*  2520 */   179,  180,  228,  229,  230,  231,  232,  179,  180,  280,
 /*  2530 */   280,  280,  280,  239,  280,  280,  228,  229,  230,  231,
 /*  2540 */   232,  280,  194,  235,  227,  280,  280,  239,  280,  255,
 /*  2550 */   256,  257,  204,  280,  260,  261,  262,  263,  264,  265,
 /*  2560 */   266,  267,  268,  269,  270,  271,  272,  273,  274,  280,
 /*  2570 */   280,  277,  255,  256,  257,  280,  228,  229,  230,  231,
 /*  2580 */   232,  280,  280,  179,  180,  280,  280,  239,  280,  255,
 /*  2590 */   256,  257,  280,  280,  179,  180,  255,  256,  257,  280,
 /*  2600 */   280,  280,  280,  255,  256,  257,  280,  204,  260,  261,
 /*  2610 */   262,  263,  264,  265,  266,  267,  268,  269,  270,  271,
 /*  2620 */   272,  273,  274,  162,  280,  277,  280,  280,  179,  180,
 /*  2630 */   280,  228,  229,  230,  231,  232,  179,  180,  235,  280,
 /*  2640 */   179,  180,  239,  280,  280,  280,  280,  280,  280,  280,
 /*  2650 */   280,  280,  280,  280,  280,  194,  280,   33,   34,  255,
 /*  2660 */   256,  257,  280,  179,  180,  204,   42,   43,  280,   45,
 /*  2670 */   255,  256,  257,   49,  280,  280,  227,  280,   54,  179,
 /*  2680 */   180,  280,  179,  180,  280,  280,   62,  280,  280,  228,
 /*  2690 */   229,  230,  231,  232,  280,  280,  280,   73,  280,  280,
 /*  2700 */   239,  179,  180,  280,  255,  256,  257,  280,  280,  280,
 /*  2710 */   280,   87,  255,  256,  257,  280,  255,  256,  257,  162,
 /*  2720 */   280,  260,  261,  262,  263,  264,  265,  266,  267,  268,
 /*  2730 */   269,  270,  271,  272,  273,  274,  179,  180,  277,  255,
 /*  2740 */   256,  257,  280,  280,  280,  280,  280,  280,  280,  280,
 /*  2750 */   280,  194,  280,  280,  280,  255,  256,  257,  255,  256,
 /*  2760 */   257,  204,  280,  139,  140,  141,  142,  143,  144,  145,
 /*  2770 */   146,  147,  148,  162,  280,  179,  180,  255,  256,  257,
 /*  2780 */   280,  280,  280,  179,  180,  228,  229,  230,  231,  232,
 /*  2790 */   179,  180,  280,  280,  280,  280,  239,  280,  280,  280,
 /*  2800 */   280,  280,  280,  280,  280,  194,  280,  280,  280,  280,
 /*  2810 */   280,  280,  255,  256,  257,  204,  280,  260,  261,  262,
 /*  2820 */   263,  264,  265,  266,  267,  268,  269,  270,  271,  272,
 /*  2830 */   273,  274,  280,  280,  277,  179,  180,  280,  280,  228,
 /*  2840 */   229,  230,  231,  232,  280,  280,  280,  280,  280,  280,
 /*  2850 */   239,  255,  256,  257,  280,  280,  280,  280,  280,  255,
 /*  2860 */   256,  257,  179,  180,  280,  280,  255,  256,  257,  179,
 /*  2870 */   180,  260,  261,  262,  263,  264,  265,  266,  267,  268,
 /*  2880 */   269,  270,  271,  272,  273,  274,  162,  280,  277,  280,
 /*  2890 */   280,  179,  180,  280,  179,  180,  280,  179,  180,  280,
 /*  2900 */   280,  280,  280,  179,  180,  280,  280,  280,  280,  280,
 /*  2910 */   280,  255,  256,  257,  280,  280,  280,  280,  194,  280,
 /*  2920 */   280,  280,   33,   34,  280,  280,  280,  280,  204,  280,
 /*  2930 */   280,   42,   43,  280,   45,  179,  180,  280,  255,  256,
 /*  2940 */   257,  179,  180,   54,  280,  255,  256,  257,  280,  179,
 /*  2950 */   180,   62,  228,  229,  230,  231,  232,   68,  280,  280,
 /*  2960 */   280,  280,   73,  239,  179,  180,  280,  255,  256,  257,
 /*  2970 */   255,  256,  257,  255,  256,  257,   87,  280,  280,  255,
 /*  2980 */   256,  257,  162,  280,  260,  261,  262,  263,  264,  265,
 /*  2990 */   266,  267,  268,  269,  270,  271,  272,  273,  274,  179,
 /*  3000 */   180,  277,  280,  280,  280,  280,  280,  280,  280,  280,
 /*  3010 */   280,  255,  256,  257,  194,  280,  280,  255,  256,  257,
 /*  3020 */   280,  280,  179,  180,  204,  255,  256,  257,  139,  140,
 /*  3030 */   141,  142,  143,  144,  145,  146,  147,  148,  280,  280,
 /*  3040 */   255,  256,  257,  280,  280,  280,  280,  280,  228,  229,
 /*  3050 */   230,  231,  232,  280,  280,  280,  280,  179,  180,  239,
 /*  3060 */   179,  180,  280,  280,  179,  180,  280,  280,  280,  280,
 /*  3070 */   280,  280,  280,  280,  280,  255,  256,  257,  280,  280,
 /*  3080 */   260,  261,  262,  263,  264,  265,  266,  267,  268,  269,
 /*  3090 */   270,  271,  272,  273,  274,   44,  280,  277,  255,  256,
 /*  3100 */   257,  280,  179,  180,   53,   54,  280,  280,  179,  180,
 /*  3110 */   280,  280,  280,  280,  179,  180,  280,  280,   67,   27,
 /*  3120 */    28,   29,   30,   31,   32,   33,   34,   35,   36,   37,
 /*  3130 */    38,   39,   40,  255,  256,  257,  255,  256,  257,   47,
 /*  3140 */   255,  256,  257,  280,  280,  280,   95,   96,   97,   98,
 /*  3150 */    99,  100,  101,  102,  103,  104,  105,  106,  107,  108,
 /*  3160 */   109,  110,  111,  112,  280,  114,  115,  116,  179,  180,
 /*  3170 */   280,  179,  180,  122,  179,  180,  280,  280,  255,  256,
 /*  3180 */   257,  179,  180,  280,  255,  256,  257,  136,  137,  138,
 /*  3190 */   255,  256,  257,  179,  180,  280,  280,  179,  180,  280,
 /*  3200 */   280,   13,  280,   15,   16,   17,   18,   19,   20,   21,
 /*  3210 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
 /*  3220 */    32,   33,   34,   35,   36,   37,   38,   39,   40,  280,
 /*  3230 */   280,  179,  180,   44,  280,   47,  280,  179,  180,  280,
 /*  3240 */   179,  180,   53,   54,  255,  256,  257,  255,  256,  257,
 /*  3250 */   255,  256,  257,  280,  280,  280,   67,  255,  256,  257,
 /*  3260 */   280,  280,  280,  280,  179,  180,  280,  179,  180,  255,
 /*  3270 */   256,  257,  280,  255,  256,  257,  280,  179,  180,  280,
 /*  3280 */   179,  180,  280,  280,   95,   96,   97,   98,   99,  100,
 /*  3290 */   101,  102,  103,  104,  105,  106,  107,  108,  109,  110,
 /*  3300 */   111,  112,  280,  114,  115,  116,  117,  255,  256,  257,
 /*  3310 */   280,  122,  280,  255,  256,  257,  255,  256,  257,  280,
 /*  3320 */   280,  280,  280,  280,  280,  280,  179,  180,  280,   44,
 /*  3330 */   280,  280,  280,  280,  280,  280,  280,  280,   53,   54,
 /*  3340 */   255,  256,  257,  255,  256,  257,  280,  280,  280,  280,
 /*  3350 */   280,  280,   67,  255,  256,  257,  255,  256,  257,  179,
 /*  3360 */   180,  280,  280,  280,  280,  280,  280,  280,  280,  280,
 /*  3370 */   280,  280,  280,  280,  280,  280,  280,  280,  280,  280,
 /*  3380 */    95,   96,   97,   98,   99,  100,  101,  102,  103,  104,
 /*  3390 */   105,  106,  107,  108,  109,  110,  111,  112,  280,  114,
 /*  3400 */   115,  116,  255,  256,  257,  179,  180,  122,   16,   17,
 /*  3410 */    18,   19,   20,   21,   22,   23,   24,   25,   26,   27,
 /*  3420 */    28,   29,   30,   31,   32,   33,   34,   35,   36,   37,
 /*  3430 */    38,   39,   40,  280,  280,  255,  256,  257,  280,   47,
 /*  3440 */    17,   18,   19,   20,   21,   22,   23,   24,   25,   26,
 /*  3450 */    27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
 /*  3460 */    37,   38,   39,   40,   33,   34,  179,  180,  280,  280,
 /*  3470 */    47,  179,  180,   42,   43,  280,   45,   33,   34,  280,
 /*  3480 */   280,  255,  256,  257,  280,   54,   42,   43,  280,   45,
 /*  3490 */   280,  280,  280,   62,  280,  280,  280,  280,   54,  280,
 /*  3500 */   280,  280,  280,  280,   73,  280,   62,  280,  280,  280,
 /*  3510 */   280,  280,  280,  280,  280,  280,  280,   73,   87,  280,
 /*  3520 */   280,  280,  280,  280,  280,  280,  280,  280,  280,  280,
 /*  3530 */   280,   87,  280,  280,  280,  280,  280,  280,  280,  280,
 /*  3540 */   280,  280,  255,  256,  257,  280,  280,  255,  256,  257,
 /*  3550 */   280,  280,  280,  280,  280,  280,  280,  280,  280,  280,
 /*  3560 */   280,  280,  280,  280,  280,  280,  280,  280,  179,  180,
 /*  3570 */   139,  140,  141,  142,  143,  144,  145,  146,  147,  148,
 /*  3580 */   280,  280,  280,  139,  140,  141,  142,  143,  144,  145,
 /*  3590 */   146,  147,  148,  204,  280,  280,  280,  280,  280,  280,
 /*  3600 */   280,  280,  280,  280,  280,  280,  280,  280,  280,  280,
 /*  3610 */   280,  280,  280,  280,  280,  280,  280,  228,  229,  230,
 /*  3620 */   231,  232,  280,  280,  280,  280,  280,  280,  239,  280,
 /*  3630 */   280,  280,  280,  280,  280,  280,  280,  280,  280,  280,
 /*  3640 */   280,  280,  280,  280,  255,  256,  257,  280,  280,  280,
 /*  3650 */   280,  280,  263,  280,  280,  280,  280,  280,  280,  280,
 /*  3660 */   280,  280,  273,  280,  275,  276,
};
#define YY_SHIFT_USE_DFLT (3666)
#define YY_SHIFT_COUNT    (448)
#define YY_SHIFT_MIN      (-33)
#define YY_SHIFT_MAX      (3444)
static const short yy_shift_ofst[] = {
 /*     0 */  3666,  247,  -33,  247,  107,  247,  247,  247,  247,  247,
 /*    10 */   247,  247,  247,  247,  247,  464,  477, 1926,  362, 2174,
 /*    20 */  3189,  302,  302,  224, 3285, 3285, 3285, 3285, 3285, 3285,
 /*    30 */  3431, 3431, 3431, 3051, 3051, 3285, 1823, 3444, 3444, 3431,
 /*    40 */   591, 2361, 2624, 3444, 3444, 3444, 3444, 3444, 3444, 3444,
 /*    50 */  1793, 2889, 3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444,
 /*    60 */  3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444,
 /*    70 */  3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444,
 /*    80 */  3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444,
 /*    90 */  3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444,
 /*   100 */  3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444,
 /*   110 */  3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444, 2347,
 /*   120 */  3444, 3444, 3444, 3444, 3444, 3444, 3444, 3444,  513,  -24,
 /*   130 */   215,  -17,    1,  230,  356,  273,  150,   10,  108,  227,
 /*   140 */   216,  227,  216, 3666, 3666, 1781,  335, 1353,  217,  283,
 /*   150 */   360,  360,  360,  360,  488,  360,  488,  488,  360,  197,
 /*   160 */   284,  360,  360,  431,  684,  767,  748,  796,  785,  807,
 /*   170 */   860,  861,  684,  807,  863,  863,  863,  108,  863,  894,
 /*   180 */   227,    1,  925,  860,  962,  227,  860,  921, 3666, 3666,
 /*   190 */  3666, 3666, 3666, 3666, 3666, 3666,  612,  676,  740,  804,
 /*   200 */   868,  919,  983, 1047, 1111, 1159, 1223, 1287, 1351, 1415,
 /*   210 */  1479, 1543, 1607, 1655, 1731, 1781, 1781, 1781, 1781, 1781,
 /*   220 */  1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781,
 /*   230 */  1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781, 1781,
 /*   240 */  3188, 3392, 3423, 1684, 1684, 1684, 2017, 2017, 2017, 2017,
 /*   250 */  2017, 2017, 3092,   13,  152,  291,  821,  821,  821,  181,
 /*   260 */   248,  248,  596,   42,  104,  109,  428,  470,  433,  393,
 /*   270 */   490,  575,  495,  455,  636,  359,  928,  992,  143,  799,
 /*   280 */   534, 1168, 1232,  496,  735,  800,  556,  640, 1043,   91,
 /*   290 */    91,   91,   91,   91,  699,  675,  859,  973,  993, 1035,
 /*   300 */  1045, 1046, 1027, 1030, 1050, 1045, 1042, 1044, 1045, 1045,
 /*   310 */  1048, 1031, 1056, 1057, 1062, 1103, 1036, 1084, 1086, 1092,
 /*   320 */  1112, 1114, 1105, 1087, 1134, 1151, 1132, 1145, 1147, 1165,
 /*   330 */  1148, 1138, 1169, 1150, 1153, 1171, 1154, 1157, 1158, 1176,
 /*   340 */  1212, 1174, 1268, 1217, 1271, 1224, 1225, 1259, 1269, 1215,
 /*   350 */  1219, 1235, 1329, 1319, 1290, 1291, 1178, 1293, 1297, 1298,
 /*   360 */  1294, 1303, 1304,  796, 1302, 1316, 1343, 1325, 1393, 1342,
 /*   370 */  1272, 1348, 1331, 1399, 1278, 1356, 1354, 1361, 1364, 1366,
 /*   380 */  1404, 1460, 1340, 1418, 1402, 1446, 1466, 1400, 1403, 1414,
 /*   390 */  1427, 1410, 1453, 1430, 1413, 1456, 1425, 1473, 1459, 1475,
 /*   400 */  1498, 1478, 1467, 1484, 1510, 1416, 1486, 1491, 1481, 1527,
 /*   410 */  1045, 1537, 1564, 1535, 1566, 1538, 1567, 1045, 1568, 1539,
 /*   420 */  1570, 1446, 1540, 1572, 1594, 1548, 1534, 1550, 1556, 1575,
 /*   430 */  1557, 1595, 1636, 1597, 1603, 1580, 1571, 1601, 1682, 1649,
 /*   440 */  1646, 1651, 1653, 1676, 1712, 1673, 1679, 1675, 1481,
};
#define YY_REDUCE_USE_DFLT (-215)
#define YY_REDUCE_COUNT (195)
#define YY_REDUCE_MIN   (-214)
#define YY_REDUCE_MAX   (3389)
static const short yy_reduce_ofst[] = {
 /*     0 */  -145, 1660, 1756, 1880, 1934, 2030, 2085, 2198, 2294, 2348,
 /*    10 */  2461, 2557, 2611, 2724, 2820, 3389,  -26,  -26, 2248, 1932,
 /*    20 */  1674,  339, 1785, -167, 1620, 1858, 2140, 2210, 2308, 2403,
 /*    30 */  -161, -123,  -25,  136, 1641, 1710,  198,  156, 1981, -155,
 /*    40 */   347, 1518, 1810,  411, 1814, 2053,  345, 2317, 2449,  539,
 /*    50 */    82,  542,  545,  609,  781,  788,  845,  852, 1021, 1024,
 /*    60 */  1085, 1088, 1149, 1152, 1277, 1280, 1341, 1344, 1860, 2071,
 /*    70 */  2076, 2142, 2238, 2334, 2341, 2404, 2415, 2457, 2484, 2500,
 /*    80 */  2503, 2522, 2596, 2604, 2656, 2683, 2690, 2712, 2715, 2718,
 /*    90 */  2756, 2762, 2770, 2785, 2843, 2878, 2881, 2885, 2923, 2929,
 /*   100 */  2935, 2989, 2992, 2995, 3002, 3014, 3018, 3052, 3058, 3061,
 /*   110 */  3085, 3088, 3098, 3101, 3147, 3180, 3226, 3287, 3292,  -82,
 /*   120 */  -165,   55,  259,  478, 1822, 1914, 1927, 2108,   16,  538,
 /*   130 */  -214,  720,  -23, -134, -156, -108,  -37,  128,  106,  -37,
 /*   140 */   254,   79,  287,  214,   97,  153,  175,  183,  241,  250,
 /*   150 */   324,  340,  341,  367,  368,  401,  379,  463,  540,  493,
 /*   160 */   454,  549,  550,  548,  566,  598,  602,  627,  628,  635,
 /*   170 */   734,  660,  726,  698,  669,  712,  713,  685,  721,  725,
 /*   180 */   493,  772,  802,  801,  777,  493,  805,  846,  822,  841,
 /*   190 */   847,  814,  815,  816,  840,  858,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */  1148, 1242, 1552, 1242, 1552, 1552, 1552, 1552, 1552, 1552,
 /*    10 */  1552, 1552, 1552, 1552, 1552, 1495, 1347, 1347, 1552, 1347,
 /*    20 */  1552, 1347, 1347, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 /*    30 */  1451, 1451, 1451, 1552, 1552, 1552, 1552, 1552, 1495, 1451,
 /*    40 */  1347, 1552, 1552, 1552, 1552, 1552, 1157, 1552, 1552, 1157,
 /*    50 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 /*    60 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 /*    70 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 /*    80 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 /*    90 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 /*   100 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 /*   110 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 /*   120 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1383,
 /*   130 */  1383, 1552, 1221, 1552, 1273, 1507, 1344, 1383, 1552, 1344,
 /*   140 */  1552, 1528, 1552, 1243, 1383, 1259, 1552, 1552, 1552, 1552,
 /*   150 */  1552, 1552, 1552, 1552, 1256, 1552, 1256, 1256, 1552, 1508,
 /*   160 */  1552, 1552, 1552, 1552, 1552, 1162, 1275, 1242, 1552, 1238,
 /*   170 */  1515, 1350, 1552, 1238, 1552, 1552, 1552, 1552, 1552, 1372,
 /*   180 */  1345, 1518, 1517, 1515, 1217, 1335, 1515, 1552, 1226, 1164,
 /*   190 */  1180, 1242, 1242, 1242, 1200, 1180, 1552, 1552, 1552, 1552,
 /*   200 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 /*   210 */  1552, 1552, 1552, 1552, 1552, 1257, 1382, 1380, 1509, 1504,
 /*   220 */  1449, 1539, 1483, 1505, 1223, 1453, 1446, 1445, 1444, 1443,
 /*   230 */  1442, 1441, 1440, 1439, 1438, 1437, 1436, 1435, 1452, 1519,
 /*   240 */  1448, 1434, 1433, 1429, 1428, 1427, 1426, 1425, 1424, 1423,
 /*   250 */  1422, 1421, 1420, 1432, 1431, 1430, 1419, 1418, 1417, 1161,
 /*   260 */  1409, 1410, 1552, 1537, 1552, 1552, 1552, 1552, 1552, 1552,
 /*   270 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 /*   280 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1416,
 /*   290 */  1415, 1413, 1412, 1411, 1552, 1552, 1552, 1552, 1552, 1552,
 /*   300 */  1163, 1552, 1552, 1552, 1552, 1170, 1552, 1552, 1287, 1286,
 /*   310 */  1552, 1552, 1552, 1173, 1552, 1552, 1552, 1552, 1552, 1552,
 /*   320 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 /*   330 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 /*   340 */  1552, 1552, 1381, 1552, 1379, 1534, 1494, 1552, 1552, 1552,
 /*   350 */  1552, 1506, 1552, 1552, 1552, 1552, 1498, 1552, 1552, 1552,
 /*   360 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 /*   370 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 /*   380 */  1387, 1552, 1552, 1306, 1552, 1362, 1222, 1552, 1552, 1552,
 /*   390 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1530,
 /*   400 */  1331, 1526, 1552, 1552, 1552, 1552, 1552, 1414, 1542, 1387,
 /*   410 */  1317, 1322, 1552, 1552, 1552, 1552, 1552, 1312, 1552, 1552,
 /*   420 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552,
 /*   430 */  1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1552, 1197,
 /*   440 */  1552, 1552, 1196, 1552, 1552, 1552, 1552, 1552, 1158,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*         EQ => nothing */
    0,  /*      MULEQ => nothing */
    0,  /*      DIVEQ => nothing */
    0,  /*      MODEQ => nothing */
    0,  /*      ADDEQ => nothing */
    0,  /*      SUBEQ => nothing */
    0,  /*      LSHEQ => nothing */
    0,  /*      RSHEQ => nothing */
    0,  /*      ANDEQ => nothing */
    0,  /*       OREQ => nothing */
    0,  /*      XOREQ => nothing */
    0,  /*     URSHEQ => nothing */
    0,  /*   QUESTION => nothing */
    0,  /*      COLON => nothing */
    0,  /*       OROR => nothing */
    0,  /*     ANDAND => nothing */
    0,  /*       EQEQ => nothing */
    0,  /*        NEQ => nothing */
    0,  /*   APPROXEQ => nothing */
    0,  /*         LT => nothing */
    0,  /*         GT => nothing */
    0,  /*       LTEQ => nothing */
    0,  /*       GTEQ => nothing */
    0,  /*     LTGTEQ => nothing */
    0,  /*         IS => nothing */
    0,  /*     DOTDOT => nothing */
    0,  /*         OR => nothing */
    0,  /*        XOR => nothing */
    0,  /*        AND => nothing */
    0,  /*        LSH => nothing */
    0,  /*        RSH => nothing */
    0,  /*       URSH => nothing */
    0,  /*        SUB => nothing */
    0,  /*        ADD => nothing */
    0,  /*        MUL => nothing */
    0,  /*        DIV => nothing */
    0,  /*        MOD => nothing */
    0,  /*  CROSSPROD => nothing */
    0,  /*    DOTPROD => nothing */
    0,  /*        POW => nothing */
    0,  /*      UNARY => nothing */
    0,  /*     ADDADD => nothing */
    0,  /*     SUBSUB => nothing */
    0,  /*        DOT => nothing */
    0,  /*     LPAREN => nothing */
    0,  /*   LBRACKET => nothing */
    0,  /*      SCOPE => nothing */
    0,  /*        EOF => nothing */
    0,  /*  SEMICOLON => nothing */
    0,  /*      COMMA => nothing */
    0,  /*    INCLUDE => nothing */
    0,  /*     EXTEND => nothing */
    0,  /*      CLASS => nothing */
    0,  /* IDENTIFIER => nothing */
    0,  /*   ABSTRACT => nothing */
    0,  /*      FINAL => nothing */
    0,  /*     NATIVE => nothing */
    0,  /*         UI => nothing */
    0,  /*       PLAY => nothing */
    0,  /*   REPLACES => nothing */
    0,  /*    VERSION => nothing */
    0,  /*   STRCONST => nothing */
    0,  /*     RPAREN => nothing */
    0,  /*     SEALED => nothing */
    0,  /*     ACTION => nothing */
   54,  /*    DEFAULT => IDENTIFIER */
   54,  /*      COLOR => IDENTIFIER */
    0,  /*     LBRACE => nothing */
    0,  /*     RBRACE => nothing */
    0,  /*      MIXIN => nothing */
   54,  /*   PROPERTY => IDENTIFIER */
    0,  /*    FLAGDEF => nothing */
    0,  /*   INTCONST => nothing */
    0,  /*   INTERNAL => nothing */
    0,  /*     STRUCT => nothing */
    0,  /* CLEARSCOPE => nothing */
    0,  /*     UNSAFE => nothing */
    0,  /*      CONST => nothing */
    0,  /*       ENUM => nothing */
    0,  /*     STATES => nothing */
    0,  /*        NWS => nothing */
    0,  /*       STOP => nothing */
    0,  /*       WAIT => nothing */
    0,  /*       FAIL => nothing */
    0,  /*       LOOP => nothing */
    0,  /*       GOTO => nothing */
    0,  /*      SUPER => nothing */
    0,  /*     BRIGHT => nothing */
    0,  /*       FAST => nothing */
    0,  /*       SLOW => nothing */
    0,  /*    NODELAY => nothing */
    0,  /*   CANRAISE => nothing */
    0,  /*     OFFSET => nothing */
    0,  /*      LIGHT => nothing */
   54,  /*      SBYTE => IDENTIFIER */
   54,  /*       BYTE => IDENTIFIER */
   54,  /*      SHORT => IDENTIFIER */
   54,  /*     USHORT => IDENTIFIER */
   54,  /*        INT => IDENTIFIER */
   54,  /*       UINT => IDENTIFIER */
   54,  /*       BOOL => IDENTIFIER */
   54,  /*      FLOAT => IDENTIFIER */
   54,  /*     DOUBLE => IDENTIFIER */
   54,  /*    VECTOR2 => IDENTIFIER */
   54,  /*    VECTOR3 => IDENTIFIER */
   54,  /*    VECTOR4 => IDENTIFIER */
   54,  /*       NAME => IDENTIFIER */
   54,  /*      SOUND => IDENTIFIER */
   54,  /*      STATE => IDENTIFIER */
    0,  /*        LET => nothing */
    0,  /*     ATSIGN => nothing */
    0,  /*   READONLY => nothing */
   54,  /*     STRING => IDENTIFIER */
   54,  /*        MAP => IDENTIFIER */
   54,  /* MAPITERATOR => IDENTIFIER */
   54,  /*      ARRAY => IDENTIFIER */
   54,  /*       VOID => IDENTIFIER */
   54,  /*      UINT8 => IDENTIFIER */
   54,  /*       INT8 => IDENTIFIER */
   54,  /*     UINT16 => IDENTIFIER */
   54,  /*      INT16 => IDENTIFIER */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  ZCCParseARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void ZCCParseTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "EQ",            "MULEQ",         "DIVEQ",       
  "MODEQ",         "ADDEQ",         "SUBEQ",         "LSHEQ",       
  "RSHEQ",         "ANDEQ",         "OREQ",          "XOREQ",       
  "URSHEQ",        "QUESTION",      "COLON",         "OROR",        
  "ANDAND",        "EQEQ",          "NEQ",           "APPROXEQ",    
  "LT",            "GT",            "LTEQ",          "GTEQ",        
  "LTGTEQ",        "IS",            "DOTDOT",        "OR",          
  "XOR",           "AND",           "LSH",           "RSH",         
  "URSH",          "SUB",           "ADD",           "MUL",         
  "DIV",           "MOD",           "CROSSPROD",     "DOTPROD",     
  "POW",           "UNARY",         "ADDADD",        "SUBSUB",      
  "DOT",           "LPAREN",        "LBRACKET",      "SCOPE",       
  "EOF",           "SEMICOLON",     "COMMA",         "INCLUDE",     
  "EXTEND",        "CLASS",         "IDENTIFIER",    "ABSTRACT",    
  "FINAL",         "NATIVE",        "UI",            "PLAY",        
  "REPLACES",      "VERSION",       "STRCONST",      "RPAREN",      
  "SEALED",        "ACTION",        "DEFAULT",       "COLOR",       
  "LBRACE",        "RBRACE",        "MIXIN",         "PROPERTY",    
  "FLAGDEF",       "INTCONST",      "INTERNAL",      "STRUCT",      
  "CLEARSCOPE",    "UNSAFE",        "CONST",         "ENUM",        
  "STATES",        "NWS",           "STOP",          "WAIT",        
  "FAIL",          "LOOP",          "GOTO",          "SUPER",       
  "BRIGHT",        "FAST",          "SLOW",          "NODELAY",     
  "CANRAISE",      "OFFSET",        "LIGHT",         "SBYTE",       
  "BYTE",          "SHORT",         "USHORT",        "INT",         
  "UINT",          "BOOL",          "FLOAT",         "DOUBLE",      
  "VECTOR2",       "VECTOR3",       "VECTOR4",       "NAME",        
  "SOUND",         "STATE",         "LET",           "ATSIGN",      
  "READONLY",      "STRING",        "MAP",           "MAPITERATOR", 
  "ARRAY",         "VOID",          "UINT8",         "INT8",        
  "UINT16",        "INT16",         "FNTYPE",        "RBRACKET",    
  "DEPRECATED",    "STATIC",        "PRIVATE",       "PROTECTED",   
  "LATENT",        "META",          "TRANSIENT",     "VIRTUAL",     
  "OVERRIDE",      "VARARG",        "VIRTUALSCOPE",  "ELLIPSIS",    
  "IN",            "OUT",           "OPTIONAL",      "TILDE",       
  "BANG",          "SIZEOF",        "ALIGNOF",       "UINTCONST",   
  "FLOATCONST",    "NAMECONST",     "FALSE",         "TRUE",        
  "NULLPTR",       "STATICCONST",   "CONTINUE",      "BREAK",       
  "RETURN",        "DO",            "FOR",           "FOREACH",     
  "WHILE",         "UNTIL",         "IF",            "ELSE",        
  "SWITCH",        "CASE",          "error",         "declarator",  
  "declarator_no_fun",  "opt_func_body",  "function_body",  "main",        
  "translation_unit",  "external_declaration",  "mixin_definition",  "class_definition",
  "struct_def",    "enum_def",      "const_def",     "include_def", 
  "opt_semicolon",  "opt_comma",     "opt_expr",      "expr",        
  "string_constant",  "class_head",    "class_innards",  "class_member",
  "class_body",    "class_ancestry",  "class_flags",   "dottable_id", 
  "states_opt",    "mixin_statement",  "property_def",  "flag_def",    
  "states_def",    "default_def",   "staticarray_statement",  "opt_struct_body",
  "struct_body",   "struct_member",  "identifier_list",  "struct_flags",
  "enum_list",     "opt_enum_list",  "enumerator",    "enum_type",   
  "int_type",      "mixin_class_definition",  "mixin_class_body",  "mixin_class_member",
  "states_body",   "state_line",    "state_label",   "state_flow",  
  "state_flow_type",  "state_goto_offset",  "state_action",  "state_call",  
  "state_call_params",  "state_opts",    "states_opts",   "scanner_mode",
  "light_list",    "statement_list",  "func_expr_list",  "default_statement_list",
  "default_statement",  "property_statement",  "flag_statement",  "expr_list",   
  "type_name",     "type_name1",    "aggregate_type",  "aggregate_type_pre",
  "type",          "type_list",     "type_list_or_void",  "type_or_array",
  "class_restrictor",  "array_size",    "array_size_expr",  "func_ptr_type",
  "func_ptr_params",  "func_ptr_param_list",  "func_ptr_param",  "fn_ptr_flag", 
  "func_param_flags",  "variables_or_function",  "decl_flags",    "func_params", 
  "func_const",    "variable_list",  "variable_name",  "decl_flag",   
  "opt_deprecation_message",  "func_param_list",  "func_param",    "primary",     
  "unary_expr",    "constant",      "func_expr_item",  "named_expr",  
  "compound_statement",  "statement",     "labeled_statement",  "expression_statement",
  "selection_statement",  "iteration_statement",  "array_iteration_statement",  "two_arg_iteration_statement",
  "three_arg_iteration_statement",  "typed_iteration_statement",  "jump_statement",  "assign_statement",
  "assign_decl_statement",  "local_var",     "while_or_until",  "for_init",    
  "for_bump",      "if_front",      "variable_list_with_init",  "var_init",    
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "main ::= translation_unit",
 /*   1 */ "translation_unit ::=",
 /*   2 */ "translation_unit ::= translation_unit external_declaration",
 /*   3 */ "translation_unit ::= error",
 /*   4 */ "external_declaration ::= mixin_definition",
 /*   5 */ "external_declaration ::= class_definition",
 /*   6 */ "external_declaration ::= struct_def",
 /*   7 */ "external_declaration ::= enum_def",
 /*   8 */ "external_declaration ::= const_def",
 /*   9 */ "external_declaration ::= include_def",
 /*  10 */ "opt_expr ::=",
 /*  11 */ "include_def ::= INCLUDE string_constant",
 /*  12 */ "class_definition ::= class_head class_body",
 /*  13 */ "class_head ::= EXTEND CLASS IDENTIFIER",
 /*  14 */ "class_head ::= CLASS IDENTIFIER class_ancestry class_flags",
 /*  15 */ "class_ancestry ::=",
 /*  16 */ "class_ancestry ::= COLON dottable_id",
 /*  17 */ "class_flags ::=",
 /*  18 */ "class_flags ::= class_flags ABSTRACT",
 /*  19 */ "class_flags ::= class_flags FINAL",
 /*  20 */ "class_flags ::= class_flags NATIVE",
 /*  21 */ "class_flags ::= class_flags UI",
 /*  22 */ "class_flags ::= class_flags PLAY",
 /*  23 */ "class_flags ::= class_flags REPLACES dottable_id",
 /*  24 */ "class_flags ::= class_flags VERSION LPAREN STRCONST RPAREN",
 /*  25 */ "class_flags ::= class_flags SEALED LPAREN states_opt RPAREN",
 /*  26 */ "dottable_id ::= IDENTIFIER",
 /*  27 */ "dottable_id ::= ACTION",
 /*  28 */ "dottable_id ::= dottable_id DOT IDENTIFIER",
 /*  29 */ "dottable_id ::= dottable_id DOT DEFAULT",
 /*  30 */ "dottable_id ::= dottable_id DOT COLOR",
 /*  31 */ "class_body ::= SEMICOLON class_innards EOF",
 /*  32 */ "class_body ::= LBRACE class_innards RBRACE",
 /*  33 */ "class_innards ::=",
 /*  34 */ "class_innards ::= class_innards class_member",
 /*  35 */ "class_member ::= declarator",
 /*  36 */ "class_member ::= mixin_statement",
 /*  37 */ "class_member ::= enum_def",
 /*  38 */ "class_member ::= struct_def",
 /*  39 */ "class_member ::= states_def",
 /*  40 */ "class_member ::= default_def",
 /*  41 */ "class_member ::= const_def",
 /*  42 */ "class_member ::= property_def",
 /*  43 */ "class_member ::= flag_def",
 /*  44 */ "class_member ::= staticarray_statement",
 /*  45 */ "mixin_statement ::= MIXIN IDENTIFIER SEMICOLON",
 /*  46 */ "property_def ::= PROPERTY IDENTIFIER COLON identifier_list SEMICOLON",
 /*  47 */ "flag_def ::= FLAGDEF IDENTIFIER COLON IDENTIFIER COMMA INTCONST SEMICOLON",
 /*  48 */ "flag_def ::= FLAGDEF INTERNAL IDENTIFIER COLON IDENTIFIER COMMA INTCONST SEMICOLON",
 /*  49 */ "identifier_list ::= IDENTIFIER",
 /*  50 */ "identifier_list ::= states_opt COMMA IDENTIFIER",
 /*  51 */ "struct_def ::= STRUCT IDENTIFIER struct_flags LBRACE opt_struct_body RBRACE opt_semicolon",
 /*  52 */ "struct_def ::= EXTEND STRUCT IDENTIFIER LBRACE opt_struct_body RBRACE opt_semicolon",
 /*  53 */ "struct_flags ::=",
 /*  54 */ "struct_flags ::= struct_flags UI",
 /*  55 */ "struct_flags ::= struct_flags PLAY",
 /*  56 */ "struct_flags ::= struct_flags CLEARSCOPE",
 /*  57 */ "struct_flags ::= struct_flags NATIVE",
 /*  58 */ "struct_flags ::= struct_flags UNSAFE LPAREN INTERNAL RPAREN",
 /*  59 */ "struct_flags ::= struct_flags VERSION LPAREN STRCONST RPAREN",
 /*  60 */ "opt_struct_body ::=",
 /*  61 */ "opt_struct_body ::= error",
 /*  62 */ "struct_body ::= struct_body struct_member",
 /*  63 */ "struct_member ::= declarator",
 /*  64 */ "struct_member ::= enum_def",
 /*  65 */ "struct_member ::= const_def",
 /*  66 */ "struct_member ::= staticarray_statement",
 /*  67 */ "struct_member ::= flag_def",
 /*  68 */ "const_def ::= CONST IDENTIFIER EQ expr SEMICOLON",
 /*  69 */ "enum_def ::= ENUM IDENTIFIER enum_type LBRACE opt_enum_list RBRACE opt_semicolon",
 /*  70 */ "enum_type ::=",
 /*  71 */ "enum_type ::= COLON int_type",
 /*  72 */ "enum_list ::= error",
 /*  73 */ "enum_list ::= enum_list COMMA enumerator",
 /*  74 */ "opt_enum_list ::=",
 /*  75 */ "enumerator ::= IDENTIFIER",
 /*  76 */ "enumerator ::= IDENTIFIER EQ expr",
 /*  77 */ "mixin_definition ::= mixin_class_definition",
 /*  78 */ "mixin_class_definition ::= MIXIN CLASS IDENTIFIER LBRACE mixin_class_body RBRACE",
 /*  79 */ "mixin_class_body ::=",
 /*  80 */ "mixin_class_body ::= mixin_class_body mixin_class_member",
 /*  81 */ "mixin_class_member ::= declarator",
 /*  82 */ "mixin_class_member ::= enum_def",
 /*  83 */ "mixin_class_member ::= struct_def",
 /*  84 */ "mixin_class_member ::= states_def",
 /*  85 */ "mixin_class_member ::= default_def",
 /*  86 */ "mixin_class_member ::= const_def",
 /*  87 */ "mixin_class_member ::= property_def",
 /*  88 */ "mixin_class_member ::= flag_def",
 /*  89 */ "mixin_class_member ::= staticarray_statement",
 /*  90 */ "states_def ::= STATES states_opts scanner_mode LBRACE states_body RBRACE",
 /*  91 */ "states_opts ::=",
 /*  92 */ "states_opts ::= LPAREN states_opt RPAREN",
 /*  93 */ "states_opt ::= IDENTIFIER",
 /*  94 */ "states_opt ::= states_opt COMMA IDENTIFIER",
 /*  95 */ "scanner_mode ::=",
 /*  96 */ "states_body ::=",
 /*  97 */ "states_body ::= error",
 /*  98 */ "states_body ::= states_body state_line",
 /*  99 */ "states_body ::= states_body state_label",
 /* 100 */ "states_body ::= states_body state_flow",
 /* 101 */ "state_label ::= NWS COLON",
 /* 102 */ "state_flow_type ::= STOP",
 /* 103 */ "state_flow_type ::= WAIT",
 /* 104 */ "state_flow_type ::= FAIL",
 /* 105 */ "state_flow_type ::= LOOP",
 /* 106 */ "state_flow_type ::= GOTO dottable_id state_goto_offset",
 /* 107 */ "state_flow_type ::= GOTO IDENTIFIER SCOPE dottable_id state_goto_offset",
 /* 108 */ "state_flow_type ::= GOTO SUPER SCOPE dottable_id state_goto_offset",
 /* 109 */ "state_goto_offset ::=",
 /* 110 */ "state_goto_offset ::= ADD expr",
 /* 111 */ "state_line ::= NWS NWS expr state_opts state_action",
 /* 112 */ "state_opts ::=",
 /* 113 */ "state_opts ::= state_opts BRIGHT",
 /* 114 */ "state_opts ::= state_opts FAST",
 /* 115 */ "state_opts ::= state_opts SLOW",
 /* 116 */ "state_opts ::= state_opts NODELAY",
 /* 117 */ "state_opts ::= state_opts CANRAISE",
 /* 118 */ "state_opts ::= state_opts OFFSET LPAREN expr COMMA expr RPAREN",
 /* 119 */ "state_opts ::= state_opts LIGHT LPAREN light_list RPAREN",
 /* 120 */ "light_list ::= STRCONST",
 /* 121 */ "light_list ::= light_list COMMA STRCONST",
 /* 122 */ "state_action ::= LBRACE statement_list scanner_mode RBRACE",
 /* 123 */ "state_action ::= LBRACE scanner_mode RBRACE",
 /* 124 */ "state_action ::= LBRACE error scanner_mode RBRACE",
 /* 125 */ "state_action ::= state_call scanner_mode SEMICOLON",
 /* 126 */ "state_call ::=",
 /* 127 */ "state_call ::= IDENTIFIER state_call_params",
 /* 128 */ "state_call_params ::=",
 /* 129 */ "state_call_params ::= LPAREN func_expr_list RPAREN",
 /* 130 */ "default_def ::= DEFAULT LBRACE RBRACE",
 /* 131 */ "default_def ::= DEFAULT LBRACE default_statement_list RBRACE",
 /* 132 */ "default_def ::= DEFAULT LBRACE error RBRACE",
 /* 133 */ "default_statement_list ::= default_statement",
 /* 134 */ "default_statement_list ::= default_statement_list default_statement",
 /* 135 */ "default_statement ::= SEMICOLON",
 /* 136 */ "default_statement ::= error SEMICOLON",
 /* 137 */ "default_statement ::= property_statement",
 /* 138 */ "default_statement ::= flag_statement",
 /* 139 */ "flag_statement ::= ADD dottable_id",
 /* 140 */ "flag_statement ::= SUB dottable_id",
 /* 141 */ "property_statement ::= dottable_id expr_list SEMICOLON",
 /* 142 */ "property_statement ::= dottable_id SEMICOLON",
 /* 143 */ "int_type ::= SBYTE",
 /* 144 */ "int_type ::= BYTE",
 /* 145 */ "int_type ::= SHORT",
 /* 146 */ "int_type ::= USHORT",
 /* 147 */ "int_type ::= INT",
 /* 148 */ "int_type ::= UINT",
 /* 149 */ "type_name1 ::= BOOL",
 /* 150 */ "type_name1 ::= FLOAT",
 /* 151 */ "type_name1 ::= DOUBLE",
 /* 152 */ "type_name1 ::= VECTOR2",
 /* 153 */ "type_name1 ::= VECTOR3",
 /* 154 */ "type_name1 ::= VECTOR4",
 /* 155 */ "type_name1 ::= NAME",
 /* 156 */ "type_name1 ::= SOUND",
 /* 157 */ "type_name1 ::= STATE",
 /* 158 */ "type_name1 ::= COLOR",
 /* 159 */ "type_name1 ::= LET",
 /* 160 */ "type_name ::= type_name1",
 /* 161 */ "type_name ::= IDENTIFIER",
 /* 162 */ "type_name ::= ATSIGN IDENTIFIER",
 /* 163 */ "type_name ::= READONLY LT IDENTIFIER GT",
 /* 164 */ "type_name ::= READONLY LT ATSIGN IDENTIFIER GT",
 /* 165 */ "type_name ::= DOT dottable_id",
 /* 166 */ "aggregate_type_pre ::= MAP LT type_or_array COMMA type_or_array",
 /* 167 */ "aggregate_type_pre ::= MAPITERATOR LT type_or_array COMMA type_or_array",
 /* 168 */ "aggregate_type_pre ::= ARRAY LT type_or_array",
 /* 169 */ "aggregate_type_pre ::= func_ptr_type",
 /* 170 */ "aggregate_type_pre ::= CLASS LT dottable_id",
 /* 171 */ "aggregate_type ::= aggregate_type_pre GT",
 /* 172 */ "aggregate_type ::= MAP LT type_or_array COMMA aggregate_type_pre RSH",
 /* 173 */ "aggregate_type ::= MAPITERATOR LT type_or_array COMMA aggregate_type_pre RSH",
 /* 174 */ "aggregate_type ::= ARRAY LT aggregate_type_pre RSH",
 /* 175 */ "aggregate_type ::= CLASS",
 /* 176 */ "fn_ptr_flag ::= UI",
 /* 177 */ "fn_ptr_flag ::= PLAY",
 /* 178 */ "fn_ptr_flag ::= CLEARSCOPE",
 /* 179 */ "func_ptr_type ::= FNTYPE LT fn_ptr_flag type_list_or_void LPAREN func_ptr_params RPAREN",
 /* 180 */ "func_ptr_type ::= FNTYPE LT VOID",
 /* 181 */ "func_ptr_params ::=",
 /* 182 */ "func_ptr_params ::= VOID",
 /* 183 */ "func_ptr_param_list ::= func_ptr_param_list COMMA func_ptr_param",
 /* 184 */ "func_ptr_param ::= func_param_flags type",
 /* 185 */ "func_ptr_param ::= func_param_flags type AND",
 /* 186 */ "type ::= type_name",
 /* 187 */ "type ::= aggregate_type",
 /* 188 */ "type_or_array ::= type array_size",
 /* 189 */ "type_list ::= type_list COMMA type_or_array",
 /* 190 */ "type_list_or_void ::= VOID",
 /* 191 */ "array_size_expr ::= LBRACKET opt_expr RBRACKET",
 /* 192 */ "array_size ::= array_size array_size_expr",
 /* 193 */ "declarator ::= decl_flags type_list_or_void variables_or_function",
 /* 194 */ "variables_or_function ::= IDENTIFIER LPAREN func_params RPAREN func_const opt_func_body",
 /* 195 */ "variables_or_function ::= variable_list SEMICOLON",
 /* 196 */ "variables_or_function ::= error SEMICOLON",
 /* 197 */ "variable_name ::= IDENTIFIER",
 /* 198 */ "variable_name ::= IDENTIFIER array_size",
 /* 199 */ "variable_list ::= variable_list COMMA variable_name",
 /* 200 */ "decl_flags ::=",
 /* 201 */ "decl_flags ::= decl_flags decl_flag",
 /* 202 */ "decl_flags ::= decl_flags ACTION states_opts",
 /* 203 */ "opt_deprecation_message ::=",
 /* 204 */ "opt_deprecation_message ::= COMMA STRCONST",
 /* 205 */ "decl_flags ::= decl_flags DEPRECATED LPAREN STRCONST opt_deprecation_message RPAREN",
 /* 206 */ "decl_flags ::= decl_flags VERSION LPAREN STRCONST RPAREN",
 /* 207 */ "decl_flag ::= NATIVE",
 /* 208 */ "decl_flag ::= STATIC",
 /* 209 */ "decl_flag ::= PRIVATE",
 /* 210 */ "decl_flag ::= PROTECTED",
 /* 211 */ "decl_flag ::= LATENT",
 /* 212 */ "decl_flag ::= FINAL",
 /* 213 */ "decl_flag ::= META",
 /* 214 */ "decl_flag ::= TRANSIENT",
 /* 215 */ "decl_flag ::= READONLY",
 /* 216 */ "decl_flag ::= INTERNAL",
 /* 217 */ "decl_flag ::= VIRTUAL",
 /* 218 */ "decl_flag ::= OVERRIDE",
 /* 219 */ "decl_flag ::= ABSTRACT",
 /* 220 */ "decl_flag ::= VARARG",
 /* 221 */ "decl_flag ::= UI",
 /* 222 */ "decl_flag ::= PLAY",
 /* 223 */ "decl_flag ::= CLEARSCOPE",
 /* 224 */ "decl_flag ::= VIRTUALSCOPE",
 /* 225 */ "func_const ::=",
 /* 226 */ "func_const ::= CONST",
 /* 227 */ "opt_func_body ::= SEMICOLON",
 /* 228 */ "func_params ::=",
 /* 229 */ "func_params ::= VOID",
 /* 230 */ "func_params ::= func_param_list COMMA ELLIPSIS",
 /* 231 */ "func_param_list ::= func_param_list COMMA func_param",
 /* 232 */ "func_param ::= func_param_flags type IDENTIFIER",
 /* 233 */ "func_param ::= func_param_flags type IDENTIFIER EQ expr",
 /* 234 */ "func_param ::= func_param_flags type AND IDENTIFIER",
 /* 235 */ "func_param ::= func_param_flags type AND IDENTIFIER EQ expr",
 /* 236 */ "func_param_flags ::=",
 /* 237 */ "func_param_flags ::= func_param_flags IN",
 /* 238 */ "func_param_flags ::= func_param_flags OUT",
 /* 239 */ "func_param_flags ::= func_param_flags OPTIONAL",
 /* 240 */ "primary ::= IDENTIFIER",
 /* 241 */ "primary ::= SUPER",
 /* 242 */ "primary ::= constant",
 /* 243 */ "primary ::= LPAREN expr COMMA expr COMMA expr COMMA expr RPAREN",
 /* 244 */ "primary ::= LPAREN expr COMMA expr COMMA expr RPAREN",
 /* 245 */ "primary ::= LPAREN expr COMMA expr RPAREN",
 /* 246 */ "primary ::= LPAREN expr RPAREN",
 /* 247 */ "primary ::= primary LPAREN func_expr_list RPAREN",
 /* 248 */ "primary ::= LPAREN CLASS LT IDENTIFIER GT RPAREN LPAREN func_expr_list RPAREN",
 /* 249 */ "primary ::= LPAREN func_ptr_type GT RPAREN LPAREN expr RPAREN",
 /* 250 */ "primary ::= primary LBRACKET expr RBRACKET",
 /* 251 */ "primary ::= primary DOT IDENTIFIER",
 /* 252 */ "primary ::= primary ADDADD",
 /* 253 */ "primary ::= primary SUBSUB",
 /* 254 */ "unary_expr ::= SUB unary_expr",
 /* 255 */ "unary_expr ::= ADD unary_expr",
 /* 256 */ "unary_expr ::= SUBSUB unary_expr",
 /* 257 */ "unary_expr ::= ADDADD unary_expr",
 /* 258 */ "unary_expr ::= TILDE unary_expr",
 /* 259 */ "unary_expr ::= BANG unary_expr",
 /* 260 */ "unary_expr ::= SIZEOF unary_expr",
 /* 261 */ "unary_expr ::= ALIGNOF unary_expr",
 /* 262 */ "expr ::= expr ADD expr",
 /* 263 */ "expr ::= expr SUB expr",
 /* 264 */ "expr ::= expr MUL expr",
 /* 265 */ "expr ::= expr DIV expr",
 /* 266 */ "expr ::= expr MOD expr",
 /* 267 */ "expr ::= expr POW expr",
 /* 268 */ "expr ::= expr CROSSPROD expr",
 /* 269 */ "expr ::= expr DOTPROD expr",
 /* 270 */ "expr ::= expr LSH expr",
 /* 271 */ "expr ::= expr RSH expr",
 /* 272 */ "expr ::= expr URSH expr",
 /* 273 */ "expr ::= expr DOTDOT expr",
 /* 274 */ "expr ::= expr LT expr",
 /* 275 */ "expr ::= expr GT expr",
 /* 276 */ "expr ::= expr LTEQ expr",
 /* 277 */ "expr ::= expr GTEQ expr",
 /* 278 */ "expr ::= expr LTGTEQ expr",
 /* 279 */ "expr ::= expr IS expr",
 /* 280 */ "expr ::= expr EQEQ expr",
 /* 281 */ "expr ::= expr NEQ expr",
 /* 282 */ "expr ::= expr APPROXEQ expr",
 /* 283 */ "expr ::= expr AND expr",
 /* 284 */ "expr ::= expr XOR expr",
 /* 285 */ "expr ::= expr OR expr",
 /* 286 */ "expr ::= expr ANDAND expr",
 /* 287 */ "expr ::= expr OROR expr",
 /* 288 */ "expr ::= expr EQ expr",
 /* 289 */ "expr ::= expr ADDEQ expr",
 /* 290 */ "expr ::= expr SUBEQ expr",
 /* 291 */ "expr ::= expr MULEQ expr",
 /* 292 */ "expr ::= expr DIVEQ expr",
 /* 293 */ "expr ::= expr MODEQ expr",
 /* 294 */ "expr ::= expr LSHEQ expr",
 /* 295 */ "expr ::= expr RSHEQ expr",
 /* 296 */ "expr ::= expr URSHEQ expr",
 /* 297 */ "expr ::= expr ANDEQ expr",
 /* 298 */ "expr ::= expr OREQ expr",
 /* 299 */ "expr ::= expr XOREQ expr",
 /* 300 */ "expr ::= expr SCOPE expr",
 /* 301 */ "expr ::= expr QUESTION expr COLON expr",
 /* 302 */ "expr_list ::= expr_list COMMA expr",
 /* 303 */ "func_expr_list ::= func_expr_list COMMA func_expr_item",
 /* 304 */ "func_expr_item ::=",
 /* 305 */ "named_expr ::= IDENTIFIER COLON expr",
 /* 306 */ "named_expr ::= expr",
 /* 307 */ "string_constant ::= STRCONST",
 /* 308 */ "string_constant ::= string_constant STRCONST",
 /* 309 */ "constant ::= INTCONST",
 /* 310 */ "constant ::= UINTCONST",
 /* 311 */ "constant ::= FLOATCONST",
 /* 312 */ "constant ::= NAMECONST",
 /* 313 */ "constant ::= FALSE",
 /* 314 */ "constant ::= TRUE",
 /* 315 */ "constant ::= NULLPTR",
 /* 316 */ "statement ::= SEMICOLON",
 /* 317 */ "statement ::= labeled_statement",
 /* 318 */ "statement ::= compound_statement",
 /* 319 */ "statement ::= expression_statement SEMICOLON",
 /* 320 */ "statement ::= assign_statement SEMICOLON",
 /* 321 */ "statement ::= assign_decl_statement SEMICOLON",
 /* 322 */ "statement ::= local_var SEMICOLON",
 /* 323 */ "statement ::= error SEMICOLON",
 /* 324 */ "statement ::= staticarray_statement",
 /* 325 */ "staticarray_statement ::= STATICCONST type IDENTIFIER LBRACKET RBRACKET EQ LBRACE expr_list RBRACE SEMICOLON",
 /* 326 */ "staticarray_statement ::= STATICCONST type LBRACKET RBRACKET IDENTIFIER EQ LBRACE expr_list RBRACE SEMICOLON",
 /* 327 */ "jump_statement ::= CONTINUE SEMICOLON",
 /* 328 */ "jump_statement ::= BREAK SEMICOLON",
 /* 329 */ "jump_statement ::= RETURN SEMICOLON",
 /* 330 */ "jump_statement ::= RETURN expr_list SEMICOLON",
 /* 331 */ "compound_statement ::= LBRACE RBRACE",
 /* 332 */ "compound_statement ::= LBRACE statement_list RBRACE",
 /* 333 */ "compound_statement ::= LBRACE error RBRACE",
 /* 334 */ "statement_list ::= statement",
 /* 335 */ "statement_list ::= statement_list statement",
 /* 336 */ "expression_statement ::= expr",
 /* 337 */ "iteration_statement ::= while_or_until LPAREN expr RPAREN statement",
 /* 338 */ "iteration_statement ::= DO statement while_or_until LPAREN expr RPAREN",
 /* 339 */ "iteration_statement ::= FOR LPAREN for_init SEMICOLON opt_expr SEMICOLON for_bump RPAREN statement",
 /* 340 */ "array_iteration_statement ::= FOREACH LPAREN variable_name COLON expr RPAREN statement",
 /* 341 */ "two_arg_iteration_statement ::= FOREACH LPAREN variable_name COMMA variable_name COLON expr RPAREN statement",
 /* 342 */ "three_arg_iteration_statement ::= FOREACH LPAREN variable_name COMMA variable_name COMMA variable_name COLON expr RPAREN statement",
 /* 343 */ "typed_iteration_statement ::= FOREACH LPAREN variable_name variable_name COLON expr RPAREN statement",
 /* 344 */ "while_or_until ::= WHILE",
 /* 345 */ "while_or_until ::= UNTIL",
 /* 346 */ "for_init ::= local_var",
 /* 347 */ "for_init ::= for_bump",
 /* 348 */ "for_bump ::=",
 /* 349 */ "for_bump ::= expression_statement",
 /* 350 */ "for_bump ::= for_bump COMMA expression_statement",
 /* 351 */ "selection_statement ::= if_front",
 /* 352 */ "selection_statement ::= if_front ELSE statement",
 /* 353 */ "if_front ::= IF LPAREN expr RPAREN statement",
 /* 354 */ "selection_statement ::= SWITCH LPAREN expr RPAREN statement",
 /* 355 */ "labeled_statement ::= CASE expr COLON",
 /* 356 */ "labeled_statement ::= DEFAULT COLON",
 /* 357 */ "assign_statement ::= LBRACKET expr_list RBRACKET EQ expr",
 /* 358 */ "assign_decl_statement ::= LET LBRACKET identifier_list RBRACKET EQ expr",
 /* 359 */ "local_var ::= type variable_list_with_init",
 /* 360 */ "var_init ::= IDENTIFIER",
 /* 361 */ "var_init ::= IDENTIFIER array_size",
 /* 362 */ "var_init ::= IDENTIFIER EQ expr",
 /* 363 */ "var_init ::= IDENTIFIER EQ LBRACE expr_list RBRACE",
 /* 364 */ "var_init ::= IDENTIFIER array_size EQ LBRACE expr_list RBRACE",
 /* 365 */ "var_init ::= IDENTIFIER EQ LBRACE error RBRACE",
 /* 366 */ "variable_list_with_init ::= variable_list_with_init COMMA var_init",
 /* 367 */ "translation_unit ::= translation_unit EOF",
 /* 368 */ "opt_semicolon ::=",
 /* 369 */ "opt_semicolon ::= SEMICOLON",
 /* 370 */ "opt_comma ::=",
 /* 371 */ "opt_comma ::= COMMA",
 /* 372 */ "opt_expr ::= expr",
 /* 373 */ "opt_struct_body ::= struct_body",
 /* 374 */ "struct_body ::= struct_member",
 /* 375 */ "enum_list ::= enumerator",
 /* 376 */ "opt_enum_list ::= enum_list opt_comma",
 /* 377 */ "state_flow ::= state_flow_type scanner_mode SEMICOLON",
 /* 378 */ "type_name1 ::= int_type",
 /* 379 */ "func_ptr_params ::= func_ptr_param_list",
 /* 380 */ "func_ptr_param_list ::= func_ptr_param",
 /* 381 */ "type_or_array ::= type",
 /* 382 */ "type_list ::= type_or_array",
 /* 383 */ "type_list_or_void ::= type_list",
 /* 384 */ "array_size ::= array_size_expr",
 /* 385 */ "variable_list ::= variable_name",
 /* 386 */ "opt_func_body ::= function_body",
 /* 387 */ "func_params ::= func_param_list",
 /* 388 */ "func_param_list ::= func_param",
 /* 389 */ "primary ::= LPAREN error RPAREN",
 /* 390 */ "unary_expr ::= primary",
 /* 391 */ "expr ::= unary_expr",
 /* 392 */ "expr_list ::= expr",
 /* 393 */ "func_expr_list ::= func_expr_item",
 /* 394 */ "func_expr_item ::= named_expr",
 /* 395 */ "constant ::= string_constant",
 /* 396 */ "function_body ::= compound_statement",
 /* 397 */ "statement ::= selection_statement",
 /* 398 */ "statement ::= iteration_statement",
 /* 399 */ "statement ::= array_iteration_statement",
 /* 400 */ "statement ::= two_arg_iteration_statement",
 /* 401 */ "statement ::= three_arg_iteration_statement",
 /* 402 */ "statement ::= typed_iteration_statement",
 /* 403 */ "statement ::= jump_statement",
 /* 404 */ "variable_list_with_init ::= var_init",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = (yyStackEntry *)malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = (yyStackEntry *)realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
      fflush(yyTraceFILE);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to ZCCParseAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to ZCCParse and ZCCParseFree.
*/
void *ZCCParseAlloc(void *(CDECL *mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ){
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyhwm = 0;
#endif
#if YYSTACKDEPTH<=0
    pParser->yytos = NULL;
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    if( yyGrowStack(pParser) ){
      pParser->yystack = &pParser->yystk0;
      pParser->yystksz = 1;
    }
#endif
#ifndef YYNOERRORRECOVERY
    pParser->yyerrcnt = -1;
#endif
    pParser->yytos = pParser->yystack;
    pParser->yystack[0].stateno = 0;
    pParser->yystack[0].major = 0;
  }
  return pParser;
}

/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  ZCCParseARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
      /* TERMINAL Destructor */
    case 1: /* EQ */
    case 2: /* MULEQ */
    case 3: /* DIVEQ */
    case 4: /* MODEQ */
    case 5: /* ADDEQ */
    case 6: /* SUBEQ */
    case 7: /* LSHEQ */
    case 8: /* RSHEQ */
    case 9: /* ANDEQ */
    case 10: /* OREQ */
    case 11: /* XOREQ */
    case 12: /* URSHEQ */
    case 13: /* QUESTION */
    case 14: /* COLON */
    case 15: /* OROR */
    case 16: /* ANDAND */
    case 17: /* EQEQ */
    case 18: /* NEQ */
    case 19: /* APPROXEQ */
    case 20: /* LT */
    case 21: /* GT */
    case 22: /* LTEQ */
    case 23: /* GTEQ */
    case 24: /* LTGTEQ */
    case 25: /* IS */
    case 26: /* DOTDOT */
    case 27: /* OR */
    case 28: /* XOR */
    case 29: /* AND */
    case 30: /* LSH */
    case 31: /* RSH */
    case 32: /* URSH */
    case 33: /* SUB */
    case 34: /* ADD */
    case 35: /* MUL */
    case 36: /* DIV */
    case 37: /* MOD */
    case 38: /* CROSSPROD */
    case 39: /* DOTPROD */
    case 40: /* POW */
    case 41: /* UNARY */
    case 42: /* ADDADD */
    case 43: /* SUBSUB */
    case 44: /* DOT */
    case 45: /* LPAREN */
    case 46: /* LBRACKET */
    case 47: /* SCOPE */
    case 48: /* EOF */
    case 49: /* SEMICOLON */
    case 50: /* COMMA */
    case 51: /* INCLUDE */
    case 52: /* EXTEND */
    case 53: /* CLASS */
    case 54: /* IDENTIFIER */
    case 55: /* ABSTRACT */
    case 56: /* FINAL */
    case 57: /* NATIVE */
    case 58: /* UI */
    case 59: /* PLAY */
    case 60: /* REPLACES */
    case 61: /* VERSION */
    case 62: /* STRCONST */
    case 63: /* RPAREN */
    case 64: /* SEALED */
    case 65: /* ACTION */
    case 66: /* DEFAULT */
    case 67: /* COLOR */
    case 68: /* LBRACE */
    case 69: /* RBRACE */
    case 70: /* MIXIN */
    case 71: /* PROPERTY */
    case 72: /* FLAGDEF */
    case 73: /* INTCONST */
    case 74: /* INTERNAL */
    case 75: /* STRUCT */
    case 76: /* CLEARSCOPE */
    case 77: /* UNSAFE */
    case 78: /* CONST */
    case 79: /* ENUM */
    case 80: /* STATES */
    case 81: /* NWS */
    case 82: /* STOP */
    case 83: /* WAIT */
    case 84: /* FAIL */
    case 85: /* LOOP */
    case 86: /* GOTO */
    case 87: /* SUPER */
    case 88: /* BRIGHT */
    case 89: /* FAST */
    case 90: /* SLOW */
    case 91: /* NODELAY */
    case 92: /* CANRAISE */
    case 93: /* OFFSET */
    case 94: /* LIGHT */
    case 95: /* SBYTE */
    case 96: /* BYTE */
    case 97: /* SHORT */
    case 98: /* USHORT */
    case 99: /* INT */
    case 100: /* UINT */
    case 101: /* BOOL */
    case 102: /* FLOAT */
    case 103: /* DOUBLE */
    case 104: /* VECTOR2 */
    case 105: /* VECTOR3 */
    case 106: /* VECTOR4 */
    case 107: /* NAME */
    case 108: /* SOUND */
    case 109: /* STATE */
    case 110: /* LET */
    case 111: /* ATSIGN */
    case 112: /* READONLY */
    case 113: /* STRING */
    case 114: /* MAP */
    case 115: /* MAPITERATOR */
    case 116: /* ARRAY */
    case 117: /* VOID */
    case 118: /* UINT8 */
    case 119: /* INT8 */
    case 120: /* UINT16 */
    case 121: /* INT16 */
    case 122: /* FNTYPE */
    case 123: /* RBRACKET */
    case 124: /* DEPRECATED */
    case 125: /* STATIC */
    case 126: /* PRIVATE */
    case 127: /* PROTECTED */
    case 128: /* LATENT */
    case 129: /* META */
    case 130: /* TRANSIENT */
    case 131: /* VIRTUAL */
    case 132: /* OVERRIDE */
    case 133: /* VARARG */
    case 134: /* VIRTUALSCOPE */
    case 135: /* ELLIPSIS */
    case 136: /* IN */
    case 137: /* OUT */
    case 138: /* OPTIONAL */
    case 139: /* TILDE */
    case 140: /* BANG */
    case 141: /* SIZEOF */
    case 142: /* ALIGNOF */
    case 143: /* UINTCONST */
    case 144: /* FLOATCONST */
    case 145: /* NAMECONST */
    case 146: /* FALSE */
    case 147: /* TRUE */
    case 148: /* NULLPTR */
    case 149: /* STATICCONST */
    case 150: /* CONTINUE */
    case 151: /* BREAK */
    case 152: /* RETURN */
    case 153: /* DO */
    case 154: /* FOR */
    case 155: /* FOREACH */
    case 156: /* WHILE */
    case 157: /* UNTIL */
    case 158: /* IF */
    case 159: /* ELSE */
    case 160: /* SWITCH */
    case 161: /* CASE */
{
#line 118 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"

#line 2156 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
    fflush(yyTraceFILE);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void ZCCParseFree(
  void *p,                    /* The parser to be deleted */
  void (CDECL *freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
#ifndef YYPARSEFREENEVERNULL
  if( pParser==0 ) return;
#endif
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int ZCCParseStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>=YY_MIN_REDUCE ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
  do{
    i = yy_shift_ofst[stateno];
    assert( iLookAhead!=YYNOCODE );
    i += iLookAhead;
    if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
          fflush(yyTraceFILE);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
            fflush(yyTraceFILE);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   ZCCParseARG_FETCH;
   yypParser->yytos--;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
     fflush(yyTraceFILE);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
/******** End %stack_overflow code ********************************************/
   ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%sShift '%s', go to state %d\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%sShift '%s'\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major]);
    }
    fflush(yyTraceFILE);
  }
}
#else
# define yyTraceShift(X,Y)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  ZCCParseTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH] ){
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState);
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 167, 1 },
  { 168, 0 },
  { 168, 2 },
  { 168, 1 },
  { 169, 1 },
  { 169, 1 },
  { 169, 1 },
  { 169, 1 },
  { 169, 1 },
  { 169, 1 },
  { 178, 0 },
  { 175, 2 },
  { 171, 2 },
  { 181, 3 },
  { 181, 4 },
  { 185, 0 },
  { 185, 2 },
  { 186, 0 },
  { 186, 2 },
  { 186, 2 },
  { 186, 2 },
  { 186, 2 },
  { 186, 2 },
  { 186, 3 },
  { 186, 5 },
  { 186, 5 },
  { 187, 1 },
  { 187, 1 },
  { 187, 3 },
  { 187, 3 },
  { 187, 3 },
  { 184, 3 },
  { 184, 3 },
  { 182, 0 },
  { 182, 2 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 189, 3 },
  { 190, 5 },
  { 191, 7 },
  { 191, 8 },
  { 198, 1 },
  { 198, 3 },
  { 172, 7 },
  { 172, 7 },
  { 199, 0 },
  { 199, 2 },
  { 199, 2 },
  { 199, 2 },
  { 199, 2 },
  { 199, 5 },
  { 199, 5 },
  { 195, 0 },
  { 195, 1 },
  { 196, 2 },
  { 197, 1 },
  { 197, 1 },
  { 197, 1 },
  { 197, 1 },
  { 197, 1 },
  { 174, 5 },
  { 173, 7 },
  { 203, 0 },
  { 203, 2 },
  { 200, 1 },
  { 200, 3 },
  { 201, 0 },
  { 202, 1 },
  { 202, 3 },
  { 170, 1 },
  { 205, 6 },
  { 206, 0 },
  { 206, 2 },
  { 207, 1 },
  { 207, 1 },
  { 207, 1 },
  { 207, 1 },
  { 207, 1 },
  { 207, 1 },
  { 207, 1 },
  { 207, 1 },
  { 207, 1 },
  { 192, 6 },
  { 218, 0 },
  { 218, 3 },
  { 188, 1 },
  { 188, 3 },
  { 219, 0 },
  { 208, 0 },
  { 208, 1 },
  { 208, 2 },
  { 208, 2 },
  { 208, 2 },
  { 210, 2 },
  { 212, 1 },
  { 212, 1 },
  { 212, 1 },
  { 212, 1 },
  { 212, 3 },
  { 212, 5 },
  { 212, 5 },
  { 213, 0 },
  { 213, 2 },
  { 209, 5 },
  { 217, 0 },
  { 217, 2 },
  { 217, 2 },
  { 217, 2 },
  { 217, 2 },
  { 217, 2 },
  { 217, 7 },
  { 217, 5 },
  { 220, 1 },
  { 220, 3 },
  { 214, 4 },
  { 214, 3 },
  { 214, 4 },
  { 214, 3 },
  { 215, 0 },
  { 215, 2 },
  { 216, 0 },
  { 216, 3 },
  { 193, 3 },
  { 193, 4 },
  { 193, 4 },
  { 223, 1 },
  { 223, 2 },
  { 224, 1 },
  { 224, 2 },
  { 224, 1 },
  { 224, 1 },
  { 226, 2 },
  { 226, 2 },
  { 225, 3 },
  { 225, 2 },
  { 204, 1 },
  { 204, 1 },
  { 204, 1 },
  { 204, 1 },
  { 204, 1 },
  { 204, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 229, 1 },
  { 228, 1 },
  { 228, 1 },
  { 228, 2 },
  { 228, 4 },
  { 228, 5 },
  { 228, 2 },
  { 231, 5 },
  { 231, 5 },
  { 231, 3 },
  { 231, 1 },
  { 231, 3 },
  { 230, 2 },
  { 230, 6 },
  { 230, 6 },
  { 230, 4 },
  { 230, 1 },
  { 243, 1 },
  { 243, 1 },
  { 243, 1 },
  { 239, 7 },
  { 239, 3 },
  { 240, 0 },
  { 240, 1 },
  { 241, 3 },
  { 242, 2 },
  { 242, 3 },
  { 232, 1 },
  { 232, 1 },
  { 235, 2 },
  { 233, 3 },
  { 234, 1 },
  { 238, 3 },
  { 237, 2 },
  { 163, 3 },
  { 245, 6 },
  { 245, 2 },
  { 245, 2 },
  { 250, 1 },
  { 250, 2 },
  { 249, 3 },
  { 246, 0 },
  { 246, 2 },
  { 246, 3 },
  { 252, 0 },
  { 252, 2 },
  { 246, 6 },
  { 246, 5 },
  { 251, 1 },
  { 251, 1 },
  { 251, 1 },
  { 251, 1 },
  { 251, 1 },
  { 251, 1 },
  { 251, 1 },
  { 251, 1 },
  { 251, 1 },
  { 251, 1 },
  { 251, 1 },
  { 251, 1 },
  { 251, 1 },
  { 251, 1 },
  { 251, 1 },
  { 251, 1 },
  { 251, 1 },
  { 251, 1 },
  { 248, 0 },
  { 248, 1 },
  { 165, 1 },
  { 247, 0 },
  { 247, 1 },
  { 247, 3 },
  { 253, 3 },
  { 254, 3 },
  { 254, 5 },
  { 254, 4 },
  { 254, 6 },
  { 244, 0 },
  { 244, 2 },
  { 244, 2 },
  { 244, 2 },
  { 255, 1 },
  { 255, 1 },
  { 255, 1 },
  { 255, 9 },
  { 255, 7 },
  { 255, 5 },
  { 255, 3 },
  { 255, 4 },
  { 255, 9 },
  { 255, 7 },
  { 255, 4 },
  { 255, 3 },
  { 255, 2 },
  { 255, 2 },
  { 256, 2 },
  { 256, 2 },
  { 256, 2 },
  { 256, 2 },
  { 256, 2 },
  { 256, 2 },
  { 256, 2 },
  { 256, 2 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 3 },
  { 179, 5 },
  { 227, 3 },
  { 222, 3 },
  { 258, 0 },
  { 259, 3 },
  { 259, 1 },
  { 180, 1 },
  { 180, 2 },
  { 257, 1 },
  { 257, 1 },
  { 257, 1 },
  { 257, 1 },
  { 257, 1 },
  { 257, 1 },
  { 257, 1 },
  { 261, 1 },
  { 261, 1 },
  { 261, 1 },
  { 261, 2 },
  { 261, 2 },
  { 261, 2 },
  { 261, 2 },
  { 261, 2 },
  { 261, 1 },
  { 194, 10 },
  { 194, 10 },
  { 270, 2 },
  { 270, 2 },
  { 270, 2 },
  { 270, 3 },
  { 260, 2 },
  { 260, 3 },
  { 260, 3 },
  { 221, 1 },
  { 221, 2 },
  { 263, 1 },
  { 265, 5 },
  { 265, 6 },
  { 265, 9 },
  { 266, 7 },
  { 267, 9 },
  { 268, 11 },
  { 269, 8 },
  { 274, 1 },
  { 274, 1 },
  { 275, 1 },
  { 275, 1 },
  { 276, 0 },
  { 276, 1 },
  { 276, 3 },
  { 264, 1 },
  { 264, 3 },
  { 277, 5 },
  { 264, 5 },
  { 262, 3 },
  { 262, 2 },
  { 271, 5 },
  { 272, 6 },
  { 273, 2 },
  { 279, 1 },
  { 279, 2 },
  { 279, 3 },
  { 279, 5 },
  { 279, 6 },
  { 279, 5 },
  { 278, 3 },
  { 168, 2 },
  { 176, 0 },
  { 176, 1 },
  { 177, 0 },
  { 177, 1 },
  { 178, 1 },
  { 195, 1 },
  { 196, 1 },
  { 200, 1 },
  { 201, 2 },
  { 211, 3 },
  { 229, 1 },
  { 240, 1 },
  { 241, 1 },
  { 235, 1 },
  { 233, 1 },
  { 234, 1 },
  { 237, 1 },
  { 249, 1 },
  { 165, 1 },
  { 247, 1 },
  { 253, 1 },
  { 255, 3 },
  { 256, 1 },
  { 179, 1 },
  { 227, 1 },
  { 222, 1 },
  { 258, 1 },
  { 257, 1 },
  { 166, 1 },
  { 261, 1 },
  { 261, 1 },
  { 261, 1 },
  { 261, 1 },
  { 261, 1 },
  { 261, 1 },
  { 261, 1 },
  { 278, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno        /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  ZCCParseARG_FETCH;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    fprintf(yyTraceFILE, "%sReduce [%s], go to state %d.\n", yyTracePrompt,
      yyRuleName[yyruleno], yymsp[-yysize].stateno);
    fflush(yyTraceFILE);
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH-1] ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* main ::= translation_unit */
#line 174 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ stat->TopNode = yymsp[0].minor.yy536; DPrintf(DMSG_SPAMMY, "Parse complete\n"); }
#line 2875 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 1: /* translation_unit ::= */
      case 33: /*class_innards ::= */ yytestcase(yyruleno==33);
      case 60: /*opt_struct_body ::= */ yytestcase(yyruleno==60);
      case 79: /*mixin_class_body ::= */ yytestcase(yyruleno==79);
#line 177 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy536 = NULL; }
#line 2883 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 2: /* translation_unit ::= translation_unit external_declaration */
      case 34: /*class_innards ::= class_innards class_member */ yytestcase(yyruleno==34);
      case 80: /*mixin_class_body ::= mixin_class_body mixin_class_member */ yytestcase(yyruleno==80);
#line 178 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ SAFE_APPEND(yymsp[-1].minor.yy536,yymsp[0].minor.yy536); }
#line 2890 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 3: /* translation_unit ::= error */
      case 61: /*opt_struct_body ::= error */ yytestcase(yyruleno==61);
#line 180 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy536 = NULL; }
#line 2896 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 4: /* external_declaration ::= mixin_definition */
#line 183 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy536 = yymsp[0].minor.yy290; /*X-overwrites-A*/ }
#line 2901 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 5: /* external_declaration ::= class_definition */
#line 184 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy536 = yymsp[0].minor.yy228; /*X-overwrites-A*/ }
#line 2906 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 6: /* external_declaration ::= struct_def */
      case 38: /*class_member ::= struct_def */ yytestcase(yyruleno==38);
      case 83: /*mixin_class_member ::= struct_def */ yytestcase(yyruleno==83);
#line 185 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy536 = yymsp[0].minor.yy59; /*X-overwrites-A*/ }
#line 2913 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 7: /* external_declaration ::= enum_def */
      case 37: /*class_member ::= enum_def */ yytestcase(yyruleno==37);
      case 64: /*struct_member ::= enum_def */ yytestcase(yyruleno==64);
      case 82: /*mixin_class_member ::= enum_def */ yytestcase(yyruleno==82);
#line 186 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy536 = yymsp[0].minor.yy443; /*X-overwrites-A*/ }
#line 2921 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 8: /* external_declaration ::= const_def */
      case 41: /*class_member ::= const_def */ yytestcase(yyruleno==41);
      case 65: /*struct_member ::= const_def */ yytestcase(yyruleno==65);
      case 86: /*mixin_class_member ::= const_def */ yytestcase(yyruleno==86);
#line 187 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy536 = yymsp[0].minor.yy547; /*X-overwrites-A*/ }
#line 2929 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 9: /* external_declaration ::= include_def */
#line 188 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy536 = nullptr; }
#line 2934 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 10: /* opt_expr ::= */
#line 199 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[1].minor.yy374 = NULL;
}
#line 2941 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 11: /* include_def ::= INCLUDE string_constant */
{  yy_destructor(yypParser,51,&yymsp[-1].minor);
#line 206 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	AddInclude(yymsp[0].minor.yy47);
}
#line 2949 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 12: /* class_definition ::= class_head class_body */
#line 220 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[-1].minor.yy228->Body = yymsp[0].minor.yy536;
	yymsp[-1].minor.yy228 = yymsp[-1].minor.yy228; /*X-overwrites-A*/
}
#line 2958 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 13: /* class_head ::= EXTEND CLASS IDENTIFIER */
{  yy_destructor(yypParser,52,&yymsp[-2].minor);
#line 226 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Class,head,yymsp[-1].minor.yy0);
	head->NodeName = yymsp[0].minor.yy0.Name();
	head->ParentName = nullptr;
	head->Flags =  ZCC_Extension;
	head->Replaces = nullptr;
	head->Version = {0, 0};
	head->Type = nullptr;
	head->Symbol = nullptr;
	yymsp[-2].minor.yy228 = head;
}
#line 2974 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 14: /* class_head ::= CLASS IDENTIFIER class_ancestry class_flags */
#line 240 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Class,head,yymsp[-3].minor.yy0);
	head->NodeName = yymsp[-2].minor.yy0.Name();
	head->ParentName = yymsp[-1].minor.yy533;
	head->Flags = yymsp[0].minor.yy335.Flags;
	head->Replaces = yymsp[0].minor.yy335.Replaces;
	head->Sealed = yymsp[0].minor.yy335.Sealed;
	head->Version = yymsp[0].minor.yy335.Version;
	head->Type = nullptr;
	head->Symbol = nullptr;
	yylhsminor.yy228 = head;
}
#line 2991 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[-3].minor.yy228 = yylhsminor.yy228;
        break;
      case 15: /* class_ancestry ::= */
#line 254 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy533 = NULL; }
#line 2997 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 16: /* class_ancestry ::= COLON dottable_id */
{  yy_destructor(yypParser,14,&yymsp[-1].minor);
#line 255 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy533 = yymsp[0].minor.yy533; /*yymsp[-1].minor.yy533-overwrites-yymsp[0].minor.yy533*/ }
#line 3003 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 17: /* class_flags ::= */
#line 258 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy335.Flags = 0; yymsp[1].minor.yy335.Replaces = NULL; yymsp[1].minor.yy335.Version = {0,0}; yymsp[1].minor.yy335.Sealed = NULL; }
#line 3009 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 18: /* class_flags ::= class_flags ABSTRACT */
#line 259 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_Abstract; yylhsminor.yy335.Replaces = yymsp[-1].minor.yy335.Replaces; yylhsminor.yy335.Version = yymsp[-1].minor.yy335.Version; yylhsminor.yy335.Sealed = yymsp[-1].minor.yy335.Sealed; }
#line 3014 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,55,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 19: /* class_flags ::= class_flags FINAL */
#line 260 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_Final; yylhsminor.yy335.Replaces = yymsp[-1].minor.yy335.Replaces; yylhsminor.yy335.Version = yymsp[-1].minor.yy335.Version; yylhsminor.yy335.Sealed =  yymsp[-1].minor.yy335.Sealed;}
#line 3021 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,56,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 20: /* class_flags ::= class_flags NATIVE */
#line 261 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_Native; yylhsminor.yy335.Replaces = yymsp[-1].minor.yy335.Replaces; yylhsminor.yy335.Version = yymsp[-1].minor.yy335.Version; yylhsminor.yy335.Sealed =  yymsp[-1].minor.yy335.Sealed; }
#line 3028 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,57,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 21: /* class_flags ::= class_flags UI */
#line 262 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_UIFlag; yylhsminor.yy335.Replaces = yymsp[-1].minor.yy335.Replaces; yylhsminor.yy335.Version = yymsp[-1].minor.yy335.Version; yylhsminor.yy335.Sealed =  yymsp[-1].minor.yy335.Sealed; }
#line 3035 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,58,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 22: /* class_flags ::= class_flags PLAY */
#line 263 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_Play; yylhsminor.yy335.Replaces = yymsp[-1].minor.yy335.Replaces; yylhsminor.yy335.Version = yymsp[-1].minor.yy335.Version; yylhsminor.yy335.Sealed =  yymsp[-1].minor.yy335.Sealed; }
#line 3042 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,59,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 23: /* class_flags ::= class_flags REPLACES dottable_id */
#line 264 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-2].minor.yy335.Flags; yylhsminor.yy335.Replaces = yymsp[0].minor.yy533; yylhsminor.yy335.Version = yymsp[-2].minor.yy335.Version; yylhsminor.yy335.Sealed = yymsp[-2].minor.yy335.Sealed; }
#line 3049 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,60,&yymsp[-1].minor);
  yymsp[-2].minor.yy335 = yylhsminor.yy335;
        break;
      case 24: /* class_flags ::= class_flags VERSION LPAREN STRCONST RPAREN */
#line 265 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-4].minor.yy335.Flags | ZCC_Version; yylhsminor.yy335.Replaces = yymsp[-4].minor.yy335.Replaces; yylhsminor.yy335.Version = yymsp[-1].minor.yy0.String->GetChars(); yylhsminor.yy335.Sealed =  yymsp[-4].minor.yy335.Sealed; }
#line 3056 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,61,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
  yymsp[-4].minor.yy335 = yylhsminor.yy335;
        break;
      case 25: /* class_flags ::= class_flags SEALED LPAREN states_opt RPAREN */
#line 266 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-4].minor.yy335.Flags | ZCC_Sealed; yylhsminor.yy335.Replaces = yymsp[-4].minor.yy335.Replaces; yylhsminor.yy335.Version = yymsp[-4].minor.yy335.Version; yylhsminor.yy335.Sealed = yymsp[-1].minor.yy533; }
#line 3065 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,64,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
  yymsp[-4].minor.yy335 = yylhsminor.yy335;
        break;
      case 26: /* dottable_id ::= IDENTIFIER */
      case 49: /*identifier_list ::= IDENTIFIER */ yytestcase(yyruleno==49);
      case 93: /*states_opt ::= IDENTIFIER */ yytestcase(yyruleno==93);
#line 274 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id,yymsp[0].minor.yy0);
	id->Id = yymsp[0].minor.yy0.Name();
	yylhsminor.yy533 = id;
}
#line 3080 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy533 = yylhsminor.yy533;
        break;
      case 27: /* dottable_id ::= ACTION */
#line 281 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id,yymsp[0].minor.yy0);
	id->Id = NAME_Action;
	yylhsminor.yy533 = id;
}
#line 3090 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy533 = yylhsminor.yy533;
        break;
      case 28: /* dottable_id ::= dottable_id DOT IDENTIFIER */
#line 287 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy533);
	id2->Id = yymsp[0].minor.yy0.Name();
	AppendTreeNodeSibling(yymsp[-2].minor.yy533, id2);
	yymsp[-2].minor.yy533 = yymsp[-2].minor.yy533; /*X-overwrites-A*/
}
#line 3101 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
        break;
      case 29: /* dottable_id ::= dottable_id DOT DEFAULT */
#line 294 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy533);
	id2->Id = NAME_Default;
	AppendTreeNodeSibling(yymsp[-2].minor.yy533, id2);
	yymsp[-2].minor.yy533 = yymsp[-2].minor.yy533; /*X-overwrites-A*/
}
#line 3112 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yy_destructor(yypParser,66,&yymsp[0].minor);
        break;
      case 30: /* dottable_id ::= dottable_id DOT COLOR */
#line 305 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy533);
	id2->Id = NAME_Color;
	AppendTreeNodeSibling(yymsp[-2].minor.yy533, id2);
	yymsp[-2].minor.yy533 = yymsp[-2].minor.yy533; /*X-overwrites-A*/
}
#line 3124 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yy_destructor(yypParser,67,&yymsp[0].minor);
        break;
      case 31: /* class_body ::= SEMICOLON class_innards EOF */
{  yy_destructor(yypParser,49,&yymsp[-2].minor);
#line 322 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy536 = yymsp[-1].minor.yy536; /*yymsp[-2].minor.yy536-overwrites-yymsp[-1].minor.yy536*/ }
#line 3132 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,48,&yymsp[0].minor);
}
        break;
      case 32: /* class_body ::= LBRACE class_innards RBRACE */
{  yy_destructor(yypParser,68,&yymsp[-2].minor);
#line 323 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy536 = yymsp[-1].minor.yy536; /*yymsp[-2].minor.yy536-overwrites-yymsp[-1].minor.yy536*/ }
#line 3140 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,69,&yymsp[0].minor);
}
        break;
      case 35: /* class_member ::= declarator */
      case 63: /*struct_member ::= declarator */ yytestcase(yyruleno==63);
      case 81: /*mixin_class_member ::= declarator */ yytestcase(yyruleno==81);
#line 336 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy536 = yymsp[0].minor.yy15; /*X-overwrites-A*/ }
#line 3149 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 36: /* class_member ::= mixin_statement */
#line 337 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy536 = yymsp[0].minor.yy199; /*X-overwrites-A*/ }
#line 3154 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 39: /* class_member ::= states_def */
      case 84: /*mixin_class_member ::= states_def */ yytestcase(yyruleno==84);
#line 340 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy536 = yymsp[0].minor.yy134; /*X-overwrites-A*/ }
#line 3160 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 40: /* class_member ::= default_def */
      case 85: /*mixin_class_member ::= default_def */ yytestcase(yyruleno==85);
#line 341 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy536 = yymsp[0].minor.yy167; /*X-overwrites-A*/ }
#line 3166 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 42: /* class_member ::= property_def */
      case 87: /*mixin_class_member ::= property_def */ yytestcase(yyruleno==87);
#line 343 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy536 = yymsp[0].minor.yy387; /*X-overwrites-A*/ }
#line 3172 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 43: /* class_member ::= flag_def */
      case 67: /*struct_member ::= flag_def */ yytestcase(yyruleno==67);
      case 88: /*mixin_class_member ::= flag_def */ yytestcase(yyruleno==88);
#line 344 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy536 = yymsp[0].minor.yy491; /*X-overwrites-A*/ }
#line 3179 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 44: /* class_member ::= staticarray_statement */
      case 66: /*struct_member ::= staticarray_statement */ yytestcase(yyruleno==66);
      case 89: /*mixin_class_member ::= staticarray_statement */ yytestcase(yyruleno==89);
#line 345 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy536 = yymsp[0].minor.yy546; /*X-overwrites-A*/ }
#line 3186 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 45: /* mixin_statement ::= MIXIN IDENTIFIER SEMICOLON */
#line 350 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(MixinStmt,stmt,yymsp[-2].minor.yy0);
	stmt->MixinName = yymsp[-1].minor.yy0.Name();
	yylhsminor.yy199 = stmt;
}
#line 3195 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-2].minor.yy199 = yylhsminor.yy199;
        break;
      case 46: /* property_def ::= PROPERTY IDENTIFIER COLON identifier_list SEMICOLON */
#line 365 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Property,def,yymsp[-4].minor.yy0);
	def->NodeName = yymsp[-3].minor.yy0.Name();
	def->Body = yymsp[-1].minor.yy533;
	yylhsminor.yy387 = def;
}
#line 3207 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-4].minor.yy387 = yylhsminor.yy387;
        break;
      case 47: /* flag_def ::= FLAGDEF IDENTIFIER COLON IDENTIFIER COMMA INTCONST SEMICOLON */
#line 373 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagDef,def,yymsp[-6].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->RefName = yymsp[-3].minor.yy0.Name();
	def->BitValue = yymsp[-1].minor.yy0.Int;
	yylhsminor.yy491 = def;
}
#line 3221 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-6].minor.yy491 = yylhsminor.yy491;
        break;
      case 48: /* flag_def ::= FLAGDEF INTERNAL IDENTIFIER COLON IDENTIFIER COMMA INTCONST SEMICOLON */
#line 382 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagDef,def,yymsp[-7].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->RefName = yymsp[-3].minor.yy0.Name();
	def->BitValue = yymsp[-1].minor.yy0.Int | 0x10000;
	yylhsminor.yy491 = def;
}
#line 3236 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,74,&yymsp[-6].minor);
  yy_destructor(yypParser,14,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-7].minor.yy491 = yylhsminor.yy491;
        break;
      case 50: /* identifier_list ::= states_opt COMMA IDENTIFIER */
      case 94: /*states_opt ::= states_opt COMMA IDENTIFIER */ yytestcase(yyruleno==94);
#line 399 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id,yymsp[0].minor.yy0);
	id->Id = yymsp[0].minor.yy0.Name();
	yymsp[-2].minor.yy533 = yymsp[-2].minor.yy533; /*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy533, id);
}
#line 3252 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 51: /* struct_def ::= STRUCT IDENTIFIER struct_flags LBRACE opt_struct_body RBRACE opt_semicolon */
#line 407 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Struct,def,yymsp[-6].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->Body = yymsp[-2].minor.yy536;
	def->Type = nullptr;
	def->Symbol = nullptr;
	def->Version = yymsp[-4].minor.yy335.Version;
	def->Flags = yymsp[-4].minor.yy335.Flags;
	yylhsminor.yy59 = def;
}
#line 3267 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,68,&yymsp[-3].minor);
  yy_destructor(yypParser,69,&yymsp[-1].minor);
  yymsp[-6].minor.yy59 = yylhsminor.yy59;
        break;
      case 52: /* struct_def ::= EXTEND STRUCT IDENTIFIER LBRACE opt_struct_body RBRACE opt_semicolon */
{  yy_destructor(yypParser,52,&yymsp[-6].minor);
#line 419 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Struct,def,yymsp[-5].minor.yy0);
	def->NodeName = yymsp[-4].minor.yy0.Name();
	def->Body = yymsp[-2].minor.yy536;
	def->Type = nullptr;
	def->Symbol = nullptr;
	def->Flags = ZCC_Extension;
	yymsp[-6].minor.yy59 = def;
}
#line 3284 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,68,&yymsp[-3].minor);
  yy_destructor(yypParser,69,&yymsp[-1].minor);
}
        break;
      case 53: /* struct_flags ::= */
#line 430 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy335.Flags = 0; yymsp[1].minor.yy335.Version = {0, 0}; }
#line 3292 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 54: /* struct_flags ::= struct_flags UI */
#line 431 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_UIFlag; yylhsminor.yy335.Version = yymsp[-1].minor.yy335.Version; }
#line 3297 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,58,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 55: /* struct_flags ::= struct_flags PLAY */
#line 432 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_Play; yylhsminor.yy335.Version = yymsp[-1].minor.yy335.Version; }
#line 3304 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,59,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 56: /* struct_flags ::= struct_flags CLEARSCOPE */
#line 433 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_ClearScope; yylhsminor.yy335.Version = yymsp[-1].minor.yy335.Version; }
#line 3311 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,76,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 57: /* struct_flags ::= struct_flags NATIVE */
#line 434 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-1].minor.yy335.Flags | ZCC_Native; yylhsminor.yy335.Version = yymsp[-1].minor.yy335.Version; }
#line 3318 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,57,&yymsp[0].minor);
  yymsp[-1].minor.yy335 = yylhsminor.yy335;
        break;
      case 58: /* struct_flags ::= struct_flags UNSAFE LPAREN INTERNAL RPAREN */
#line 435 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-4].minor.yy335.Flags | ZCC_VMInternalStruct; yylhsminor.yy335.Version = yymsp[-4].minor.yy335.Version; }
#line 3325 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,77,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,74,&yymsp[-1].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
  yymsp[-4].minor.yy335 = yylhsminor.yy335;
        break;
      case 59: /* struct_flags ::= struct_flags VERSION LPAREN STRCONST RPAREN */
#line 436 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy335.Flags = yymsp[-4].minor.yy335.Flags | ZCC_Version; yylhsminor.yy335.Version = yymsp[-1].minor.yy0.String->GetChars(); }
#line 3335 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,61,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
  yymsp[-4].minor.yy335 = yylhsminor.yy335;
        break;
      case 62: /* struct_body ::= struct_body struct_member */
#line 444 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy536 = yymsp[-1].minor.yy536; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-1].minor.yy536, yymsp[0].minor.yy536); }
#line 3344 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 68: /* const_def ::= CONST IDENTIFIER EQ expr SEMICOLON */
#line 455 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,def,yymsp[-4].minor.yy0);
	def->NodeName = yymsp[-3].minor.yy0.Name();
	def->Value = yymsp[-1].minor.yy374;
	def->Symbol = NULL;
	yylhsminor.yy547 = def;
}
#line 3355 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-4].minor.yy547 = yylhsminor.yy547;
        break;
      case 69: /* enum_def ::= ENUM IDENTIFIER enum_type LBRACE opt_enum_list RBRACE opt_semicolon */
#line 472 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Enum,def,yymsp[-6].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->EnumType = (EZCCBuiltinType)yymsp[-4].minor.yy0.Int;
	def->Elements = yymsp[-2].minor.yy547;
	def->Symbol = nullptr;

	// If the first element does not have an explicit value, make it 0.
	if (yymsp[-2].minor.yy547 != NULL)
	{
		ZCC_ConstantDef *node = yymsp[-2].minor.yy547, *prev = node;

		if (node->Value == NULL)
		{
			NEW_INTCONST_NODE(zero, TypeSInt32, 0, yymsp[-2].minor.yy547);
			node->Value = zero;
		}
		for (node = static_cast<ZCC_ConstantDef *>(node->SiblingNext);
			node != yymsp[-2].minor.yy547;
			prev = node, node = static_cast<ZCC_ConstantDef *>(node->SiblingNext))
		{
			assert(node->NodeType == AST_ConstantDef);
			// Leave explicit values alone.
			if (node->Value != NULL)
			{
				continue;
			}
			// Compute implicit values by adding one to the preceding value.
			assert(prev->Value != NULL);
			// If the preceding node is a constant, then we can do this now.
			if (prev->Value->Operation == PEX_ConstValue && prev->Value->Type->isInt())
			{
				NEW_INTCONST_NODE(cval, prev->Value->Type, static_cast<ZCC_ExprConstant *>(prev->Value)->IntVal + 1, node);
				node->Value = cval;
			}
			// Otherwise, create a new addition expression to add 1.
			else
			{
				NEW_INTCONST_NODE(one, TypeSInt32, 1, yymsp[-6].minor.yy0);
				NEW_AST_NODE(ExprID, label, node);
				label->Operation = PEX_ID;
				label->Identifier = prev->NodeName;
				label->Type = NULL;

				BINARY_EXPR(label, one, PEX_Add);
				node->Value = expr2;
			}
		}
		// Add a new terminating node, to indicate that the ConstantDefs for this enum are done.
		NEW_AST_NODE(EnumTerminator,term,yymsp[-1].minor.yy0);
		AppendTreeNodeSibling(yymsp[-2].minor.yy547, term);
	}
	if (yymsp[-2].minor.yy547 != NULL)
	{
		AppendTreeNodeSibling(def, yymsp[-2].minor.yy547);
	}
	yylhsminor.yy443 = def;
}
#line 3420 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,68,&yymsp[-3].minor);
  yymsp[-6].minor.yy443 = yylhsminor.yy443;
        break;
      case 70: /* enum_type ::= */
#line 531 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = ZCC_IntAuto; yymsp[1].minor.yy0.SourceLoc = stat->sc->GetMessageLine(); }
#line 3427 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 71: /* enum_type ::= COLON int_type */
{  yy_destructor(yypParser,14,&yymsp[-1].minor);
#line 532 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; /*yymsp[-1].minor.yy0-overwrites-yymsp[0].minor.yy0*/ }
#line 3433 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 72: /* enum_list ::= error */
#line 534 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy547 = NULL; }
#line 3439 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 73: /* enum_list ::= enum_list COMMA enumerator */
#line 536 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy547 = yymsp[-2].minor.yy547; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy547, yymsp[0].minor.yy547); }
#line 3444 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 74: /* opt_enum_list ::= */
#line 538 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy547 = NULL; }
#line 3450 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 75: /* enumerator ::= IDENTIFIER */
#line 542 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,node,yymsp[0].minor.yy0);
	node->NodeName = yymsp[0].minor.yy0.Name();
	node->Value = NULL;
	node->Symbol = NULL;
	yylhsminor.yy547 = node;
}
#line 3461 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy547 = yylhsminor.yy547;
        break;
      case 76: /* enumerator ::= IDENTIFIER EQ expr */
#line 550 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,node,yymsp[-2].minor.yy0);
	node->NodeName = yymsp[-2].minor.yy0.Name();
	node->Value = yymsp[0].minor.yy374;
	node->Symbol = NULL;
	yylhsminor.yy547 = node;
}
#line 3473 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy547 = yylhsminor.yy547;
        break;
      case 77: /* mixin_definition ::= mixin_class_definition */
#line 564 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy290 = yymsp[0].minor.yy290; /*X-overwrites-A*/ }
#line 3480 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 78: /* mixin_class_definition ::= MIXIN CLASS IDENTIFIER LBRACE mixin_class_body RBRACE */
#line 571 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(MixinDef,def,yymsp[-5].minor.yy0);
	def->Body = yymsp[-1].minor.yy536;
	def->NodeName = yymsp[-3].minor.yy0.Name();
	def->MixinType = ZCC_Mixin_Class;
	def->Symbol = nullptr;
	yylhsminor.yy290 = def;
}
#line 3492 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,53,&yymsp[-4].minor);
  yy_destructor(yypParser,68,&yymsp[-2].minor);
  yy_destructor(yypParser,69,&yymsp[0].minor);
  yymsp[-5].minor.yy290 = yylhsminor.yy290;
        break;
      case 90: /* states_def ::= STATES states_opts scanner_mode LBRACE states_body RBRACE */
#line 620 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(States,def,yymsp[-5].minor.yy0);
	def->Flags = yymsp[-4].minor.yy533;
	def->Body = yymsp[-1].minor.yy458;
	yylhsminor.yy134 = def;
}
#line 3506 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,68,&yymsp[-2].minor);
  yy_destructor(yypParser,69,&yymsp[0].minor);
  yymsp[-5].minor.yy134 = yylhsminor.yy134;
        break;
      case 91: /* states_opts ::= */
#line 627 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy533 = nullptr; }
#line 3514 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 92: /* states_opts ::= LPAREN states_opt RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 628 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy533 = yymsp[-1].minor.yy533; /*yymsp[-2].minor.yy533-overwrites-yymsp[-1].minor.yy533*/ }
#line 3520 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,63,&yymsp[0].minor);
}
        break;
      case 95: /* scanner_mode ::= */
#line 657 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ stat->sc->SetStateMode(true); }
#line 3527 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 96: /* states_body ::= */
#line 659 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy458 = NULL; }
#line 3532 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 97: /* states_body ::= error */
#line 660 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy458 = NULL; }
#line 3537 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 98: /* states_body ::= states_body state_line */
      case 99: /*states_body ::= states_body state_label */ yytestcase(yyruleno==99);
      case 100: /*states_body ::= states_body state_flow */ yytestcase(yyruleno==100);
#line 661 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ SAFE_APPEND(yymsp[-1].minor.yy458,yymsp[0].minor.yy458); }
#line 3544 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 101: /* state_label ::= NWS COLON */
#line 666 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StateLabel, label, yymsp[-1].minor.yy0);
	label->Label = yymsp[-1].minor.yy0.Name();
	yylhsminor.yy458 = label;
}
#line 3553 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-1].minor.yy458 = yylhsminor.yy458;
        break;
      case 102: /* state_flow_type ::= STOP */
#line 674 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ NEW_AST_NODE(StateStop, flow, yymsp[0].minor.yy0); yylhsminor.yy458 = flow; }
#line 3560 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy458 = yylhsminor.yy458;
        break;
      case 103: /* state_flow_type ::= WAIT */
#line 675 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ NEW_AST_NODE(StateWait, flow, yymsp[0].minor.yy0); yylhsminor.yy458 = flow; }
#line 3566 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy458 = yylhsminor.yy458;
        break;
      case 104: /* state_flow_type ::= FAIL */
#line 676 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ NEW_AST_NODE(StateFail, flow, yymsp[0].minor.yy0); yylhsminor.yy458 = flow; }
#line 3572 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy458 = yylhsminor.yy458;
        break;
      case 105: /* state_flow_type ::= LOOP */
#line 677 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ NEW_AST_NODE(StateLoop, flow, yymsp[0].minor.yy0); yylhsminor.yy458 = flow; }
#line 3578 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy458 = yylhsminor.yy458;
        break;
      case 106: /* state_flow_type ::= GOTO dottable_id state_goto_offset */
#line 679 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-2].minor.yy0);
	flow->Label = yymsp[-1].minor.yy533;
	flow->Offset = yymsp[0].minor.yy374;
	flow->Qualifier = nullptr;
	yylhsminor.yy458 = flow;
}
#line 3590 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[-2].minor.yy458 = yylhsminor.yy458;
        break;
      case 107: /* state_flow_type ::= GOTO IDENTIFIER SCOPE dottable_id state_goto_offset */
#line 688 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-4].minor.yy0);
	flow->Label = yymsp[-1].minor.yy533;
	flow->Offset = yymsp[0].minor.yy374;

	NEW_AST_NODE(Identifier,id,yymsp[-3].minor.yy0);
	id->Id = yymsp[-3].minor.yy0.Name();
	flow->Qualifier =id;
	yylhsminor.yy458 = flow;
}
#line 3605 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-2].minor);
  yymsp[-4].minor.yy458 = yylhsminor.yy458;
        break;
      case 108: /* state_flow_type ::= GOTO SUPER SCOPE dottable_id state_goto_offset */
#line 700 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-4].minor.yy0);
	flow->Label = yymsp[-1].minor.yy533;
	flow->Offset = yymsp[0].minor.yy374;

	NEW_AST_NODE(Identifier,id,yymsp[-3].minor.yy0);
	id->Id = NAME_Super;
	flow->Qualifier =id;
	yylhsminor.yy458 = flow;
}
#line 3621 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-2].minor);
  yymsp[-4].minor.yy458 = yylhsminor.yy458;
        break;
      case 109: /* state_goto_offset ::= */
#line 711 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy374 = NULL; }
#line 3628 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 110: /* state_goto_offset ::= ADD expr */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 712 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy374 = yymsp[0].minor.yy374; /*yymsp[-1].minor.yy374-overwrites-yymsp[0].minor.yy374*/ }
#line 3634 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 111: /* state_line ::= NWS NWS expr state_opts state_action */
#line 715 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StateLine, line, yymsp[-4].minor.yy0);
	line->Sprite = stat->Strings.Alloc(FName(yymsp[-4].minor.yy0.Name()).GetChars());
	line->Frames = stat->Strings.Alloc(FName(yymsp[-3].minor.yy0.Name()).GetChars());
	line->Duration = yymsp[-2].minor.yy374;
	line->bBright = yymsp[-1].minor.yy68.Bright;
	line->bFast = yymsp[-1].minor.yy68.Fast;
	line->bSlow = yymsp[-1].minor.yy68.Slow;
	line->bNoDelay = yymsp[-1].minor.yy68.NoDelay;
	line->bCanRaise = yymsp[-1].minor.yy68.CanRaise;
	line->Offset = yymsp[-1].minor.yy68.Offset;
	line->Lights = yymsp[-1].minor.yy68.Lights;
	line->Action = yymsp[0].minor.yy536;
	yylhsminor.yy458 = line;
}
#line 3654 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[-4].minor.yy458 = yylhsminor.yy458;
        break;
      case 112: /* state_opts ::= */
#line 731 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ StateOpts opts; opts.Zero(); yymsp[1].minor.yy68 = opts; }
#line 3660 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 113: /* state_opts ::= state_opts BRIGHT */
#line 732 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy68.Bright = true; yymsp[-1].minor.yy68 = yymsp[-1].minor.yy68; /*X-overwrites-A*/ }
#line 3665 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,88,&yymsp[0].minor);
        break;
      case 114: /* state_opts ::= state_opts FAST */
#line 733 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy68.Fast = true; yymsp[-1].minor.yy68 = yymsp[-1].minor.yy68; /*X-overwrites-A*/ }
#line 3671 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,89,&yymsp[0].minor);
        break;
      case 115: /* state_opts ::= state_opts SLOW */
#line 734 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy68.Slow = true; yymsp[-1].minor.yy68 = yymsp[-1].minor.yy68; /*X-overwrites-A*/ }
#line 3677 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,90,&yymsp[0].minor);
        break;
      case 116: /* state_opts ::= state_opts NODELAY */
#line 735 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy68.NoDelay = true; yymsp[-1].minor.yy68 = yymsp[-1].minor.yy68; /*X-overwrites-A*/ }
#line 3683 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,91,&yymsp[0].minor);
        break;
      case 117: /* state_opts ::= state_opts CANRAISE */
#line 736 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy68.CanRaise = true; yymsp[-1].minor.yy68 = yymsp[-1].minor.yy68; /*X-overwrites-A*/ }
#line 3689 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,92,&yymsp[0].minor);
        break;
      case 118: /* state_opts ::= state_opts OFFSET LPAREN expr COMMA expr RPAREN */
#line 737 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-6].minor.yy68.Offset = yymsp[-3].minor.yy374; AppendTreeNodeSibling(yymsp[-3].minor.yy374, yymsp[-1].minor.yy374); yymsp[-6].minor.yy68 = yymsp[-6].minor.yy68; /*X-overwrites-A*/ }
#line 3695 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,93,&yymsp[-5].minor);
  yy_destructor(yypParser,45,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
        break;
      case 119: /* state_opts ::= state_opts LIGHT LPAREN light_list RPAREN */
#line 738 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-4].minor.yy68 = yymsp[-4].minor.yy68; /*X-overwrites-A*/ yymsp[-4].minor.yy68.Lights = yymsp[-1].minor.yy47; }
#line 3704 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,94,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
        break;
      case 120: /* light_list ::= STRCONST */
      case 307: /*string_constant ::= STRCONST */ yytestcase(yyruleno==307);
#line 743 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[0].minor.yy0);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = yymsp[0].minor.yy0.String;
	yylhsminor.yy47 = strconst;
}
#line 3719 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy47 = yylhsminor.yy47;
        break;
      case 121: /* light_list ::= light_list COMMA STRCONST */
#line 752 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[0].minor.yy0);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = yymsp[0].minor.yy0.String;
	AppendTreeNodeSibling(yymsp[-2].minor.yy47, strconst); 
	yymsp[-2].minor.yy47 = yymsp[-2].minor.yy47; /*X-overwrites-A*/
}
#line 3732 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 122: /* state_action ::= LBRACE statement_list scanner_mode RBRACE */
#line 763 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-3].minor.yy0);
	stmt->Content = yymsp[-2].minor.yy523;
	yylhsminor.yy536 = stmt;
}
#line 3742 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,69,&yymsp[0].minor);
  yymsp[-3].minor.yy536 = yylhsminor.yy536;
        break;
      case 123: /* state_action ::= LBRACE scanner_mode RBRACE */
{  yy_destructor(yypParser,68,&yymsp[-2].minor);
#line 769 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[-2].minor.yy536 = NULL;
}
#line 3752 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,69,&yymsp[0].minor);
}
        break;
      case 124: /* state_action ::= LBRACE error scanner_mode RBRACE */
{  yy_destructor(yypParser,68,&yymsp[-3].minor);
#line 772 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-3].minor.yy536 = NULL; }
#line 3760 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,69,&yymsp[0].minor);
}
        break;
      case 125: /* state_action ::= state_call scanner_mode SEMICOLON */
#line 773 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy536 = yymsp[-2].minor.yy61; /*X-overwrites-A*/ }
#line 3767 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 126: /* state_call ::= */
#line 775 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy61 = NULL; }
#line 3773 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 127: /* state_call ::= IDENTIFIER state_call_params */
#line 777 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprFuncCall, expr, yymsp[-1].minor.yy0);
	NEW_AST_NODE(ExprID, func, yymsp[-1].minor.yy0);

	func->Operation = PEX_ID;
	func->Identifier = yymsp[-1].minor.yy0.Name();
	expr->Operation = PEX_FuncCall;
	expr->Function = func;
	expr->Parameters = yymsp[0].minor.yy370;
	yylhsminor.yy61 = expr;
}
#line 3788 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[-1].minor.yy61 = yylhsminor.yy61;
        break;
      case 128: /* state_call_params ::= */
#line 789 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy370 = NULL; }
#line 3794 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 129: /* state_call_params ::= LPAREN func_expr_list RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 790 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy370 = yymsp[-1].minor.yy370; /*yymsp[-2].minor.yy370-overwrites-yymsp[-1].minor.yy370*/ }
#line 3800 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,63,&yymsp[0].minor);
}
        break;
      case 130: /* default_def ::= DEFAULT LBRACE RBRACE */
{  yy_destructor(yypParser,66,&yymsp[-2].minor);
#line 798 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-1].minor.yy0);
	stmt->Content = NULL;
	yymsp[-2].minor.yy167 = stmt;
}
#line 3812 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,69,&yymsp[0].minor);
}
        break;
      case 131: /* default_def ::= DEFAULT LBRACE default_statement_list RBRACE */
{  yy_destructor(yypParser,66,&yymsp[-3].minor);
#line 804 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-2].minor.yy0);
	stmt->Content = yymsp[-1].minor.yy523;
	yymsp[-3].minor.yy167 = stmt;
}
#line 3824 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,69,&yymsp[0].minor);
}
        break;
      case 132: /* default_def ::= DEFAULT LBRACE error RBRACE */
{  yy_destructor(yypParser,66,&yymsp[-3].minor);
#line 810 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-2].minor.yy0);
	stmt->Content = NULL;
	yymsp[-3].minor.yy167 = stmt;
}
#line 3836 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,69,&yymsp[0].minor);
}
        break;
      case 133: /* default_statement_list ::= default_statement */
      case 334: /*statement_list ::= statement */ yytestcase(yyruleno==334);
#line 817 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[0].minor.yy523 = yymsp[0].minor.yy523; /*X-overwrites-A*/
}
#line 3846 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 134: /* default_statement_list ::= default_statement_list default_statement */
      case 335: /*statement_list ::= statement_list statement */ yytestcase(yyruleno==335);
#line 821 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	SAFE_APPEND(yymsp[-1].minor.yy523,yymsp[0].minor.yy523);
}
#line 3854 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 135: /* default_statement ::= SEMICOLON */
      case 316: /*statement ::= SEMICOLON */ yytestcase(yyruleno==316);
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 826 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy523 = NULL; }
#line 3861 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 136: /* default_statement ::= error SEMICOLON */
      case 323: /*statement ::= error SEMICOLON */ yytestcase(yyruleno==323);
#line 827 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy523 = NULL; }
#line 3868 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 137: /* default_statement ::= property_statement */
#line 829 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy523 = yymsp[0].minor.yy195; /*X-overwrites-A*/ }
#line 3874 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 138: /* default_statement ::= flag_statement */
#line 830 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy523 = yymsp[0].minor.yy180; /*X-overwrites-A*/ }
#line 3879 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 139: /* flag_statement ::= ADD dottable_id */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 835 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagStmt, type, yymsp[0].minor.yy533);
	type->set = true;
	type->name = yymsp[0].minor.yy533;
	yymsp[-1].minor.yy180 = type;
}
#line 3890 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 140: /* flag_statement ::= SUB dottable_id */
{  yy_destructor(yypParser,33,&yymsp[-1].minor);
#line 842 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagStmt, type, yymsp[0].minor.yy533);
	type->set = false;
	type->name = yymsp[0].minor.yy533;
	yymsp[-1].minor.yy180 = type;
}
#line 3902 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 141: /* property_statement ::= dottable_id expr_list SEMICOLON */
#line 852 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(PropertyStmt,stmt,yymsp[-2].minor.yy533);
	stmt->Prop = yymsp[-2].minor.yy533;
	stmt->Values = yymsp[-1].minor.yy374;
	yylhsminor.yy195 = stmt;
}
#line 3913 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-2].minor.yy195 = yylhsminor.yy195;
        break;
      case 142: /* property_statement ::= dottable_id SEMICOLON */
#line 860 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(PropertyStmt,stmt,yymsp[-1].minor.yy533);
	stmt->Prop = yymsp[-1].minor.yy533;
	stmt->Values = nullptr;
	yylhsminor.yy195 = stmt;
}
#line 3925 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy195 = yylhsminor.yy195;
        break;
      case 143: /* int_type ::= SBYTE */
#line 872 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt8; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3932 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 144: /* int_type ::= BYTE */
#line 873 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt8; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3938 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 145: /* int_type ::= SHORT */
#line 874 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt16; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3944 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 146: /* int_type ::= USHORT */
#line 875 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt16; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3950 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 147: /* int_type ::= INT */
#line 876 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt32; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3956 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 148: /* int_type ::= UINT */
#line 877 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt32; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3962 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 149: /* type_name1 ::= BOOL */
#line 879 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Bool; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3968 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 150: /* type_name1 ::= FLOAT */
#line 881 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_FloatAuto; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3974 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 151: /* type_name1 ::= DOUBLE */
#line 882 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Float64; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3980 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 152: /* type_name1 ::= VECTOR2 */
#line 884 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Vector2; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3986 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 153: /* type_name1 ::= VECTOR3 */
#line 885 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Vector3; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3992 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 154: /* type_name1 ::= VECTOR4 */
#line 886 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Vector4; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3998 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 155: /* type_name1 ::= NAME */
#line 887 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Name; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4004 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 156: /* type_name1 ::= SOUND */
#line 888 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Sound; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4010 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 157: /* type_name1 ::= STATE */
#line 889 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_State; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4016 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 158: /* type_name1 ::= COLOR */
#line 890 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Color; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4022 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 159: /* type_name1 ::= LET */
#line 891 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Let; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4028 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 160: /* type_name ::= type_name1 */
#line 894 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	type->Type = (EZCCBuiltinType)yymsp[0].minor.yy0.Int;
	type->UserType = NULL;
	type->isconst = false;
	yylhsminor.yy46 = type;
}
#line 4040 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy46 = yylhsminor.yy46;
        break;
      case 161: /* type_name ::= IDENTIFIER */
#line 902 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[0].minor.yy0);
	type->Type = ZCC_UserType;
	type->UserType = id;
	type->isconst = false;
	id->Id = yymsp[0].minor.yy0.Name();
	yylhsminor.yy46 = type;
}
#line 4054 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy46 = yylhsminor.yy46;
        break;
      case 162: /* type_name ::= ATSIGN IDENTIFIER */
{  yy_destructor(yypParser,111,&yymsp[-1].minor);
#line 913 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[0].minor.yy0);
	type->Type = ZCC_NativeType;
	type->UserType = id;
	type->isconst = false;
	id->Id = yymsp[0].minor.yy0.Name();
	yymsp[-1].minor.yy46 = type;
}
#line 4069 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 163: /* type_name ::= READONLY LT IDENTIFIER GT */
{  yy_destructor(yypParser,112,&yymsp[-3].minor);
#line 924 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[-1].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[-1].minor.yy0);
	type->Type = ZCC_UserType;
	type->UserType = id;
	type->isconst = true;
	id->Id = yymsp[-1].minor.yy0.Name();
	yymsp[-3].minor.yy46 = type;
}
#line 4084 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 164: /* type_name ::= READONLY LT ATSIGN IDENTIFIER GT */
{  yy_destructor(yypParser,112,&yymsp[-4].minor);
#line 935 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[-1].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[-1].minor.yy0);
	type->Type = ZCC_NativeType;
	type->UserType = id;
	type->isconst = true;
	id->Id = yymsp[-1].minor.yy0.Name();
	yymsp[-4].minor.yy46 = type;
}
#line 4101 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-3].minor);
  yy_destructor(yypParser,111,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 165: /* type_name ::= DOT dottable_id */
{  yy_destructor(yypParser,44,&yymsp[-1].minor);
#line 946 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy533);
	type->Type = ZCC_UserType;
	type->UserType = yymsp[0].minor.yy533;
	type->isconst = false;
	yymsp[-1].minor.yy46 = type;
}
#line 4117 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 166: /* aggregate_type_pre ::= MAP LT type_or_array COMMA type_or_array */
#line 971 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(MapType,map,yymsp[-4].minor.yy0);
	map->KeyType = yymsp[-2].minor.yy168;
	map->ValueType = yymsp[0].minor.yy168;
	yylhsminor.yy168 = map;
	yylhsminor.yy168->ArraySize = NULL;
}
#line 4129 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-3].minor);
  yy_destructor(yypParser,50,&yymsp[-1].minor);
  yymsp[-4].minor.yy168 = yylhsminor.yy168;
        break;
      case 167: /* aggregate_type_pre ::= MAPITERATOR LT type_or_array COMMA type_or_array */
#line 980 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(MapIteratorType,map_it,yymsp[-4].minor.yy0);
	map_it->KeyType = yymsp[-2].minor.yy168;
	map_it->ValueType = yymsp[0].minor.yy168;
	yylhsminor.yy168 = map_it;
	yylhsminor.yy168->ArraySize = NULL;
}
#line 4143 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-3].minor);
  yy_destructor(yypParser,50,&yymsp[-1].minor);
  yymsp[-4].minor.yy168 = yylhsminor.yy168;
        break;
      case 168: /* aggregate_type_pre ::= ARRAY LT type_or_array */
#line 989 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(DynArrayType,arr,yymsp[-2].minor.yy0);
	arr->ElementType = yymsp[0].minor.yy168;
	yylhsminor.yy168 = arr;
	yylhsminor.yy168->ArraySize = NULL;
}
#line 4156 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-1].minor);
  yymsp[-2].minor.yy168 = yylhsminor.yy168;
        break;
      case 169: /* aggregate_type_pre ::= func_ptr_type */
#line 996 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy168 = yymsp[0].minor.yy422; /*X-overwrites-A*/ yymsp[0].minor.yy168->ArraySize = NULL; }
#line 4163 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 170: /* aggregate_type_pre ::= CLASS LT dottable_id */
#line 999 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ClassType,cls,yymsp[-2].minor.yy0);
	cls->Restriction = yymsp[0].minor.yy533;
	yylhsminor.yy168 = cls;
	yylhsminor.yy168->ArraySize = NULL;
}
#line 4173 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-1].minor);
  yymsp[-2].minor.yy168 = yylhsminor.yy168;
        break;
      case 171: /* aggregate_type ::= aggregate_type_pre GT */
#line 1006 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy168 = yymsp[-1].minor.yy168; yylhsminor.yy168->ArraySize = NULL; }
#line 4180 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,21,&yymsp[0].minor);
  yymsp[-1].minor.yy168 = yylhsminor.yy168;
        break;
      case 172: /* aggregate_type ::= MAP LT type_or_array COMMA aggregate_type_pre RSH */
#line 1009 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	if(!stat->sc->CheckParseVersion(MakeVersion(4, 15, 1)))
	{
		stat->sc->ScriptMessage(">> without space in parametrized types only supported for zscript >= 4.15.1");
		FScriptPosition::ErrorCounter++;
	}
	NEW_AST_NODE(MapType,map,yymsp[-5].minor.yy0);
	map->KeyType = yymsp[-3].minor.yy168;
	map->ValueType = yymsp[-1].minor.yy168;
	yylhsminor.yy168 = map;
	yylhsminor.yy168->ArraySize = NULL;
}
#line 4198 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,31,&yymsp[0].minor);
  yymsp[-5].minor.yy168 = yylhsminor.yy168;
        break;
      case 173: /* aggregate_type ::= MAPITERATOR LT type_or_array COMMA aggregate_type_pre RSH */
#line 1023 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	if(!stat->sc->CheckParseVersion(MakeVersion(4, 15, 1)))
	{
		stat->sc->ScriptMessage(">> without space in parametrized types only supported for zscript >= 4.15.1");
		FScriptPosition::ErrorCounter++;
	}
	NEW_AST_NODE(MapIteratorType,map_it,yymsp[-5].minor.yy0);
	map_it->KeyType = yymsp[-3].minor.yy168;
	map_it->ValueType = yymsp[-1].minor.yy168;
	yylhsminor.yy168 = map_it;
	yylhsminor.yy168->ArraySize = NULL;
}
#line 4218 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,31,&yymsp[0].minor);
  yymsp[-5].minor.yy168 = yylhsminor.yy168;
        break;
      case 174: /* aggregate_type ::= ARRAY LT aggregate_type_pre RSH */
#line 1037 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	if(!stat->sc->CheckParseVersion(MakeVersion(4, 15, 1)))
	{
		stat->sc->ScriptMessage(">> without space in parametrized types only supported for zscript >= 4.15.1");
		FScriptPosition::ErrorCounter++;
	}
	NEW_AST_NODE(DynArrayType,arr,yymsp[-3].minor.yy0);
	arr->ElementType = yymsp[-1].minor.yy168;
	yylhsminor.yy168 = arr;
	yylhsminor.yy168->ArraySize = NULL;
}
#line 4237 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-2].minor);
  yy_destructor(yypParser,31,&yymsp[0].minor);
  yymsp[-3].minor.yy168 = yylhsminor.yy168;
        break;
      case 175: /* aggregate_type ::= CLASS */
#line 1050 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ClassType,cls,yymsp[0].minor.yy0);
	cls->Restriction = NULL;
	yylhsminor.yy168 = cls;
	yylhsminor.yy168->ArraySize = NULL;
}
#line 4250 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy168 = yylhsminor.yy168;
        break;
      case 176: /* fn_ptr_flag ::= UI */
{  yy_destructor(yypParser,58,&yymsp[0].minor);
#line 1063 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy0.Int = ZCC_UIFlag; }
#line 4257 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 177: /* fn_ptr_flag ::= PLAY */
{  yy_destructor(yypParser,59,&yymsp[0].minor);
#line 1064 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy0.Int = ZCC_Play; }
#line 4264 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 178: /* fn_ptr_flag ::= CLEARSCOPE */
{  yy_destructor(yypParser,76,&yymsp[0].minor);
#line 1065 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy0.Int = ZCC_ClearScope; }
#line 4271 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 179: /* func_ptr_type ::= FNTYPE LT fn_ptr_flag type_list_or_void LPAREN func_ptr_params RPAREN */
#line 1070 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncPtrType,fn_ptr,yymsp[-6].minor.yy0);
	fn_ptr->RetType = yymsp[-3].minor.yy168;
	fn_ptr->Params = yymsp[-1].minor.yy453;
	fn_ptr->Scope = yymsp[-4].minor.yy0.Int;
	yylhsminor.yy422 = fn_ptr;
}
#line 4283 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-5].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
  yymsp[-6].minor.yy422 = yylhsminor.yy422;
        break;
      case 180: /* func_ptr_type ::= FNTYPE LT VOID */
#line 1079 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncPtrType,fn_ptr,yymsp[-2].minor.yy0);
	fn_ptr->RetType = nullptr;
	fn_ptr->Params = nullptr;
	fn_ptr->Scope = -1;
	yylhsminor.yy422 = fn_ptr;
}
#line 4298 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-1].minor);
  yy_destructor(yypParser,117,&yymsp[0].minor);
  yymsp[-2].minor.yy422 = yylhsminor.yy422;
        break;
      case 181: /* func_ptr_params ::= */
#line 1087 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy453 = NULL; }
#line 4306 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 182: /* func_ptr_params ::= VOID */
{  yy_destructor(yypParser,117,&yymsp[0].minor);
#line 1088 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy453 = NULL; }
#line 4312 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 183: /* func_ptr_param_list ::= func_ptr_param_list COMMA func_ptr_param */
#line 1102 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy453 = yymsp[-2].minor.yy453; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy453, yymsp[0].minor.yy453); }
#line 4318 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 184: /* func_ptr_param ::= func_param_flags type */
#line 1105 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncPtrParamDecl,parm,yymsp[-1].minor.yy0.SourceLoc ? yymsp[-1].minor.yy0.SourceLoc : yymsp[0].minor.yy168->SourceLoc);
	parm->Type = yymsp[0].minor.yy168;
	parm->Flags = yymsp[-1].minor.yy0.Int;
	yylhsminor.yy453 = parm;
}
#line 4329 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[-1].minor.yy453 = yylhsminor.yy453;
        break;
      case 185: /* func_ptr_param ::= func_param_flags type AND */
#line 1113 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncPtrParamDecl,parm,yymsp[-2].minor.yy0.SourceLoc ? yymsp[-2].minor.yy0.SourceLoc : yymsp[-1].minor.yy168->SourceLoc);
	parm->Type = yymsp[-1].minor.yy168;
	parm->Flags = yymsp[-2].minor.yy0.Int | ZCC_Out;
	yylhsminor.yy453 = parm;
}
#line 4340 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,29,&yymsp[0].minor);
  yymsp[-2].minor.yy453 = yylhsminor.yy453;
        break;
      case 186: /* type ::= type_name */
#line 1120 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy168 = yymsp[0].minor.yy46; /*X-overwrites-A*/ yymsp[0].minor.yy168->ArraySize = NULL; }
#line 4347 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 187: /* type ::= aggregate_type */
#line 1121 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy168 = yymsp[0].minor.yy168; /*X-overwrites-A*/ yymsp[0].minor.yy168->ArraySize = NULL; }
#line 4352 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 188: /* type_or_array ::= type array_size */
#line 1124 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy168 = yymsp[-1].minor.yy168; /*X-overwrites-A*/ yymsp[-1].minor.yy168->ArraySize = yymsp[0].minor.yy374; }
#line 4357 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 189: /* type_list ::= type_list COMMA type_or_array */
#line 1127 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy168 = yymsp[-2].minor.yy168; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy168, yymsp[0].minor.yy168); }
#line 4362 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 190: /* type_list_or_void ::= VOID */
{  yy_destructor(yypParser,117,&yymsp[0].minor);
#line 1129 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy168 = NULL; }
#line 4369 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 191: /* array_size_expr ::= LBRACKET opt_expr RBRACKET */
#line 1133 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	if (yymsp[-1].minor.yy374 == NULL)
	{
		NEW_AST_NODE(Expression,nil,yymsp[-2].minor.yy0.SourceLoc);
		nil->Operation = PEX_Nil;
		nil->Type = NULL;
		yylhsminor.yy374 = nil;
	}
	else
	{
		yylhsminor.yy374 = yymsp[-1].minor.yy374;
	}
}
#line 4387 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,123,&yymsp[0].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 192: /* array_size ::= array_size array_size_expr */
#line 1148 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-1].minor.yy374, yymsp[0].minor.yy374);
	yymsp[-1].minor.yy374 = yymsp[-1].minor.yy374; /*X-overwrites-A*/
}
#line 4397 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 193: /* declarator ::= decl_flags type_list_or_void variables_or_function */
#line 1157 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	if (yymsp[0].minor.yy520.FuncName == NAME_None && yymsp[0].minor.yy520.VarNames == NULL)
	{ // An error. yymsp[-2].minor.yy127 message was already printed.
		yylhsminor.yy15 = NULL;
	}
	else if (yymsp[0].minor.yy520.FuncName != NAME_None)
	{ // yymsp[-2].minor.yy127 function
		NEW_AST_NODE(FuncDeclarator, decl, yymsp[-2].minor.yy127 == nullptr? yymsp[0].minor.yy520.SourceLoc : yymsp[-2].minor.yy127->SourceLoc);
		decl->Type = yymsp[-1].minor.yy168;
		decl->Params = yymsp[0].minor.yy520.FuncParams;
		decl->Name = yymsp[0].minor.yy520.FuncName;
		decl->UseFlags = yymsp[-2].minor.yy127 == nullptr? nullptr : yymsp[-2].minor.yy127->Id;
		decl->Flags = (yymsp[-2].minor.yy127 == nullptr? 0 : yymsp[-2].minor.yy127->Flags) | yymsp[0].minor.yy520.FuncFlags;
		decl->DeprecationMessage = yymsp[-2].minor.yy127 == nullptr ? nullptr : yymsp[-2].minor.yy127->DeprecationMessage;
		if (yymsp[-2].minor.yy127 == nullptr) decl->Version = {0,0,0};
		else decl->Version = yymsp[-2].minor.yy127->Version;

		decl->Body = yymsp[0].minor.yy520.FuncBody;
		yylhsminor.yy15 = decl;
	}
	else if (yymsp[-1].minor.yy168 != NULL && yymsp[-1].minor.yy168->SiblingNext == yymsp[-1].minor.yy168)
	{ // yymsp[-2].minor.yy127 variable
		NEW_AST_NODE(VarDeclarator, decl, yymsp[-2].minor.yy127 == nullptr? yymsp[-1].minor.yy168->SourceLoc : yymsp[-2].minor.yy127->SourceLoc);
		decl->Type = yymsp[-1].minor.yy168;
		decl->Names = yymsp[0].minor.yy520.VarNames;
		if (yymsp[-2].minor.yy127 == nullptr)
		{
			decl->Flags = 0;
			decl->Version = {0,0,0};
			decl->DeprecationMessage = nullptr;
		}
		else
		{
			decl->Flags = yymsp[-2].minor.yy127->Flags;
			decl->Version = yymsp[-2].minor.yy127->Version;
			decl->DeprecationMessage = yymsp[-2].minor.yy127->DeprecationMessage;
		}
		yylhsminor.yy15 = decl;
	}
	else
	{ // An invalid
		if (yymsp[-1].minor.yy168 == NULL)
		{
			stat->sc->ScriptMessage("Variables may not be of type void.\n");
		}
		else
		{
			stat->sc->ScriptMessage("Variables may be of only one type.\n");
		}
		yylhsminor.yy15 = NULL;
	}
}
#line 4453 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[-2].minor.yy15 = yylhsminor.yy15;
        break;
      case 194: /* variables_or_function ::= IDENTIFIER LPAREN func_params RPAREN func_const opt_func_body */
#line 1212 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	VarOrFun fun;

	fun.VarNames = NULL;
	fun.FuncParams = yymsp[-3].minor.yy147;
	fun.FuncFlags = yymsp[-1].minor.yy0.Int;
	fun.FuncName = yymsp[-5].minor.yy0.Name();
	fun.FuncBody = yymsp[0].minor.yy271;
	fun.SourceLoc = yymsp[-5].minor.yy0.SourceLoc;
	yylhsminor.yy520 = fun;
}
#line 4469 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-4].minor);
  yy_destructor(yypParser,63,&yymsp[-2].minor);
  yymsp[-5].minor.yy520 = yylhsminor.yy520;
        break;
      case 195: /* variables_or_function ::= variable_list SEMICOLON */
#line 1224 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	VarOrFun var;

	var.VarNames = yymsp[-1].minor.yy244;
	var.FuncParams = NULL;
	var.FuncFlags = 0;
	var.FuncName = NAME_None;
	var.FuncBody = NULL;
	var.SourceLoc = yymsp[-1].minor.yy244->SourceLoc;
	yylhsminor.yy520 = var;
}
#line 4487 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy520 = yylhsminor.yy520;
        break;
      case 196: /* variables_or_function ::= error SEMICOLON */
#line 1236 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	VarOrFun bad;
	bad.VarNames = NULL;
	bad.FuncParams = NULL;
	bad.FuncFlags = 0;
	bad.FuncName = NAME_None;
	bad.FuncBody = NULL;
	bad.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
	yymsp[-1].minor.yy520 = bad;
}
#line 4503 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 197: /* variable_name ::= IDENTIFIER */
#line 1253 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VarName,var,yymsp[0].minor.yy0);
	var->Name = ENamedName(yymsp[0].minor.yy0.Int);
	var->ArraySize = NULL;
	yylhsminor.yy244 = var;
}
#line 4513 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy244 = yylhsminor.yy244;
        break;
      case 198: /* variable_name ::= IDENTIFIER array_size */
#line 1260 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VarName,var,yymsp[-1].minor.yy0);
	var->Name = ENamedName(yymsp[-1].minor.yy0.Int);
	var->ArraySize = yymsp[0].minor.yy374;
	yylhsminor.yy244 = var;
}
#line 4524 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[-1].minor.yy244 = yylhsminor.yy244;
        break;
      case 199: /* variable_list ::= variable_list COMMA variable_name */
#line 1269 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-2].minor.yy244, yymsp[0].minor.yy244);
	yymsp[-2].minor.yy244 = yymsp[-2].minor.yy244; /*X-overwrites-A*/
}
#line 4533 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 200: /* decl_flags ::= */
#line 1275 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy127 = NULL; }
#line 4539 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 201: /* decl_flags ::= decl_flags decl_flag */
#line 1277 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	if (yymsp[-1].minor.yy127 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[0].minor.yy0);
		yylhsminor.yy127 = nil_f;
		yylhsminor.yy127->Id = nullptr;
		yylhsminor.yy127->Flags = yymsp[0].minor.yy0.Int;
		yylhsminor.yy127->Version = { 0, 0 };
		yylhsminor.yy127->DeprecationMessage = nullptr;
	}
	else
	{
		yylhsminor.yy127 = yymsp[-1].minor.yy127;
		yylhsminor.yy127->Flags |= yymsp[0].minor.yy0.Int;
	}
}
#line 4559 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[-1].minor.yy127 = yylhsminor.yy127;
        break;
      case 202: /* decl_flags ::= decl_flags ACTION states_opts */
#line 1296 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	if (yymsp[-2].minor.yy127 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-1].minor.yy0.SourceLoc);
		yylhsminor.yy127 = nil_f;
		yylhsminor.yy127->Flags = ZCC_Action;
		yylhsminor.yy127->Id = nullptr;
		yylhsminor.yy127->Version = { 0, 0 };
		yylhsminor.yy127->DeprecationMessage = nullptr;
	}
	else
	{
		yylhsminor.yy127 = yymsp[-2].minor.yy127;
		yylhsminor.yy127->Flags |= ZCC_Action;
	}
	yylhsminor.yy127->Id = yymsp[0].minor.yy533;
}
#line 4581 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[-2].minor.yy127 = yylhsminor.yy127;
        break;
      case 203: /* opt_deprecation_message ::= */
#line 1314 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy0.String = nullptr; yymsp[1].minor.yy0.SourceLoc = stat->sc->GetMessageLine(); }
#line 4587 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 204: /* opt_deprecation_message ::= COMMA STRCONST */
{  yy_destructor(yypParser,50,&yymsp[-1].minor);
#line 1315 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; }
#line 4593 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 205: /* decl_flags ::= decl_flags DEPRECATED LPAREN STRCONST opt_deprecation_message RPAREN */
#line 1318 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	if (yymsp[-5].minor.yy127 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-4].minor.yy0.SourceLoc);
		yylhsminor.yy127 = nil_f;
		yylhsminor.yy127->Flags = ZCC_Deprecated;
		yylhsminor.yy127->Id = nullptr;
		yylhsminor.yy127->Version = { 0, 0 };
	}
	else
	{
		yylhsminor.yy127 = yymsp[-5].minor.yy127;
		yylhsminor.yy127->Flags |= ZCC_Deprecated;
	}
	yylhsminor.yy127->Version = yymsp[-2].minor.yy0.String->GetChars();
	yylhsminor.yy127->DeprecationMessage = yymsp[-1].minor.yy0.String;
}
#line 4615 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
  yymsp[-5].minor.yy127 = yylhsminor.yy127;
        break;
      case 206: /* decl_flags ::= decl_flags VERSION LPAREN STRCONST RPAREN */
#line 1337 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	if (yymsp[-4].minor.yy127 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-3].minor.yy0.SourceLoc);
		yylhsminor.yy127 = nil_f;
		yylhsminor.yy127->Flags = ZCC_Version;
		yylhsminor.yy127->Id = nullptr;
		yylhsminor.yy127->Version = { 0, 0 };
		yylhsminor.yy127->DeprecationMessage = nullptr;
	}
	else
	{
		yylhsminor.yy127 = yymsp[-4].minor.yy127;
		yylhsminor.yy127->Flags |= ZCC_Version;
	}
	yylhsminor.yy127->Version = yymsp[-1].minor.yy0.String->GetChars();
}
#line 4639 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
  yymsp[-4].minor.yy127 = yylhsminor.yy127;
        break;
      case 207: /* decl_flag ::= NATIVE */
#line 1355 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Native; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4647 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 208: /* decl_flag ::= STATIC */
#line 1356 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Static; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4653 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 209: /* decl_flag ::= PRIVATE */
#line 1357 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Private; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4659 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 210: /* decl_flag ::= PROTECTED */
#line 1358 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Protected; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4665 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 211: /* decl_flag ::= LATENT */
#line 1359 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Latent; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4671 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 212: /* decl_flag ::= FINAL */
#line 1360 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Final; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4677 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 213: /* decl_flag ::= META */
#line 1361 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Meta; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4683 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 214: /* decl_flag ::= TRANSIENT */
#line 1362 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Transient; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4689 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 215: /* decl_flag ::= READONLY */
#line 1363 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_ReadOnly; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4695 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 216: /* decl_flag ::= INTERNAL */
#line 1364 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Internal; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4701 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 217: /* decl_flag ::= VIRTUAL */
#line 1365 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Virtual; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4707 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 218: /* decl_flag ::= OVERRIDE */
#line 1366 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Override; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4713 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 219: /* decl_flag ::= ABSTRACT */
#line 1367 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Abstract; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4719 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 220: /* decl_flag ::= VARARG */
#line 1368 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_VarArg; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4725 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 221: /* decl_flag ::= UI */
#line 1369 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UIFlag; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4731 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 222: /* decl_flag ::= PLAY */
#line 1370 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Play; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4737 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 223: /* decl_flag ::= CLEARSCOPE */
#line 1371 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_ClearScope; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4743 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 224: /* decl_flag ::= VIRTUALSCOPE */
#line 1372 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_VirtualScope; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4749 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 225: /* func_const ::= */
#line 1374 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = 0; yymsp[1].minor.yy0.SourceLoc = stat->sc->GetMessageLine(); }
#line 4755 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 226: /* func_const ::= CONST */
#line 1375 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_FuncConst; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4760 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 227: /* opt_func_body ::= SEMICOLON */
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 1377 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy271 = NULL; }
#line 4767 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 228: /* func_params ::= */
#line 1384 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy147 = NULL; }
#line 4773 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 229: /* func_params ::= VOID */
{  yy_destructor(yypParser,117,&yymsp[0].minor);
#line 1385 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy147 = NULL; }
#line 4779 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 230: /* func_params ::= func_param_list COMMA ELLIPSIS */
#line 1389 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,stat->sc->GetMessageLine());
	parm->Type = nullptr;
	parm->Name = NAME_None;
	parm->Flags = 0;
	parm->Default = nullptr;
	yymsp[-2].minor.yy147 = yymsp[-2].minor.yy147; /*X-overwrites-A*/ 
	AppendTreeNodeSibling(yymsp[-2].minor.yy147, parm);
}
#line 4793 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
  yy_destructor(yypParser,135,&yymsp[0].minor);
        break;
      case 231: /* func_param_list ::= func_param_list COMMA func_param */
#line 1400 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy147 = yymsp[-2].minor.yy147; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy147, yymsp[0].minor.yy147); }
#line 4800 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 232: /* func_param ::= func_param_flags type IDENTIFIER */
#line 1403 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,yymsp[-2].minor.yy0.SourceLoc ? yymsp[-2].minor.yy0.SourceLoc : yymsp[-1].minor.yy168->SourceLoc);
	parm->Type = yymsp[-1].minor.yy168;
	parm->Name = yymsp[0].minor.yy0.Name();
	parm->Flags = yymsp[-2].minor.yy0.Int;
	parm->Default = nullptr;
	yylhsminor.yy147 = parm;
}
#line 4813 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[-2].minor.yy147 = yylhsminor.yy147;
        break;
      case 233: /* func_param ::= func_param_flags type IDENTIFIER EQ expr */
#line 1413 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,yymsp[-4].minor.yy0.SourceLoc ? yymsp[-4].minor.yy0.SourceLoc : yymsp[-3].minor.yy168->SourceLoc);
	parm->Type = yymsp[-3].minor.yy168;
	parm->Name = yymsp[-2].minor.yy0.Name();
	parm->Flags = yymsp[-4].minor.yy0.Int;
	parm->Default = yymsp[0].minor.yy374;
	yylhsminor.yy147 = parm;
}
#line 4826 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-4].minor.yy147 = yylhsminor.yy147;
        break;
      case 234: /* func_param ::= func_param_flags type AND IDENTIFIER */
#line 1423 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,yymsp[-3].minor.yy0.SourceLoc ? yymsp[-3].minor.yy0.SourceLoc : yymsp[-2].minor.yy168->SourceLoc);
	parm->Type = yymsp[-2].minor.yy168;
	parm->Name = yymsp[0].minor.yy0.Name();
	parm->Flags = yymsp[-3].minor.yy0.Int | ZCC_Out;
	parm->Default = nullptr;
	yylhsminor.yy147 = parm;
}
#line 4840 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,29,&yymsp[-1].minor);
  yymsp[-3].minor.yy147 = yylhsminor.yy147;
        break;
      case 235: /* func_param ::= func_param_flags type AND IDENTIFIER EQ expr */
#line 1433 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,yymsp[-5].minor.yy0.SourceLoc ? yymsp[-5].minor.yy0.SourceLoc : yymsp[-4].minor.yy168->SourceLoc);
	parm->Type = yymsp[-4].minor.yy168;
	parm->Name = yymsp[-2].minor.yy0.Name();
	parm->Flags = yymsp[-5].minor.yy0.Int | ZCC_Out;
	parm->Default = yymsp[0].minor.yy374;
	yylhsminor.yy147 = parm;
}
#line 4854 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,29,&yymsp[-3].minor);
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-5].minor.yy147 = yylhsminor.yy147;
        break;
      case 236: /* func_param_flags ::= */
#line 1442 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = 0; yymsp[1].minor.yy0.SourceLoc = 0; }
#line 4862 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 237: /* func_param_flags ::= func_param_flags IN */
#line 1443 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_In; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4867 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 238: /* func_param_flags ::= func_param_flags OUT */
#line 1444 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_Out; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4873 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 239: /* func_param_flags ::= func_param_flags OPTIONAL */
#line 1445 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_Optional; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4879 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 240: /* primary ::= IDENTIFIER */
#line 1461 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprID, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_ID;
	expr->Identifier = yymsp[0].minor.yy0.Name();
	expr->Type = NULL;
	yylhsminor.yy374 = expr;
}
#line 4891 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy374 = yylhsminor.yy374;
        break;
      case 241: /* primary ::= SUPER */
#line 1469 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Expression, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_Super;
	expr->Type = NULL;
	yylhsminor.yy374 = expr;
}
#line 4902 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy374 = yylhsminor.yy374;
        break;
      case 242: /* primary ::= constant */
#line 1475 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy374 = yymsp[0].minor.yy47; /*X-overwrites-A*/ }
#line 4908 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 243: /* primary ::= LPAREN expr COMMA expr COMMA expr COMMA expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-8].minor);
#line 1477 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VectorValue, expr, yymsp[-7].minor.yy374);
	expr->Operation = PEX_Vector;
	expr->Type = TypeVector4;
	expr->X = yymsp[-7].minor.yy374;
	expr->Y = yymsp[-5].minor.yy374;
	expr->Z = yymsp[-3].minor.yy374;
	expr->W = yymsp[-1].minor.yy374;
	yymsp[-8].minor.yy374 = expr;
}
#line 4923 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-6].minor);
  yy_destructor(yypParser,50,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
}
        break;
      case 244: /* primary ::= LPAREN expr COMMA expr COMMA expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-6].minor);
#line 1488 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VectorValue, expr, yymsp[-5].minor.yy374);
	expr->Operation = PEX_Vector;
	expr->Type = TypeVector3;
	expr->X = yymsp[-5].minor.yy374;
	expr->Y = yymsp[-3].minor.yy374;
	expr->Z = yymsp[-1].minor.yy374;
	expr->W = nullptr;
	yymsp[-6].minor.yy374 = expr;
}
#line 4943 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
}
        break;
      case 245: /* primary ::= LPAREN expr COMMA expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-4].minor);
#line 1499 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VectorValue, expr, yymsp[-3].minor.yy374);
	expr->Operation = PEX_Vector;
	expr->Type = TypeVector2;
	expr->X = yymsp[-3].minor.yy374;
	expr->Y = yymsp[-1].minor.yy374;
	expr->Z = nullptr;
	expr->W = nullptr;
	yymsp[-4].minor.yy374 = expr;
}
#line 4962 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
}
        break;
      case 246: /* primary ::= LPAREN expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 1510 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[-2].minor.yy374 = yymsp[-1].minor.yy374; /*yymsp[-2].minor.yy374-overwrites-yymsp[-1].minor.yy374*/
}
#line 4973 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,63,&yymsp[0].minor);
}
        break;
      case 247: /* primary ::= primary LPAREN func_expr_list RPAREN */
#line 1515 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprFuncCall, expr, yymsp[-3].minor.yy374);
	expr->Operation = PEX_FuncCall;
	expr->Type = NULL;
	expr->Function = yymsp[-3].minor.yy374;
	expr->Parameters = yymsp[-1].minor.yy370;
	yylhsminor.yy374 = expr;
}
#line 4987 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
  yymsp[-3].minor.yy374 = yylhsminor.yy374;
        break;
      case 248: /* primary ::= LPAREN CLASS LT IDENTIFIER GT RPAREN LPAREN func_expr_list RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-8].minor);
#line 1524 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ClassCast, expr, yymsp[-5].minor.yy0);
	expr->Operation = PEX_ClassCast;
	expr->ClassName = ENamedName(yymsp[-5].minor.yy0.Int);
	expr->Parameters = yymsp[-1].minor.yy370;
	yymsp[-8].minor.yy374 = expr;
}
#line 5002 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,53,&yymsp[-7].minor);
  yy_destructor(yypParser,20,&yymsp[-6].minor);
  yy_destructor(yypParser,21,&yymsp[-4].minor);
  yy_destructor(yypParser,63,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
}
        break;
      case 249: /* primary ::= LPAREN func_ptr_type GT RPAREN LPAREN expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-6].minor);
#line 1533 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FunctionPtrCast, expr, yymsp[-5].minor.yy422);
	expr->Operation = PEX_FunctionPtrCast;
	yymsp[-5].minor.yy422->ArraySize = NULL;
	expr->PtrType = yymsp[-5].minor.yy422;
	expr->Expr = yymsp[-1].minor.yy374;
	yymsp[-6].minor.yy374 = expr;
}
#line 5022 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,21,&yymsp[-4].minor);
  yy_destructor(yypParser,63,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
}
        break;
      case 250: /* primary ::= primary LBRACKET expr RBRACKET */
#line 1543 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprBinary, expr, yymsp[-1].minor.yy374);
	expr->Operation = PEX_ArrayAccess;
	expr->Type = NULL;
	expr->Left = yymsp[-3].minor.yy374;
	expr->Right = yymsp[-1].minor.yy374;
	yylhsminor.yy374 = expr;
}
#line 5039 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-2].minor);
  yy_destructor(yypParser,123,&yymsp[0].minor);
  yymsp[-3].minor.yy374 = yylhsminor.yy374;
        break;
      case 251: /* primary ::= primary DOT IDENTIFIER */
#line 1553 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprMemberAccess, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_MemberAccess;
	expr->Type = NULL;
	expr->Left = yymsp[-2].minor.yy374;
	expr->Right = ENamedName(yymsp[0].minor.yy0.Int);
	yylhsminor.yy374 = expr;
}
#line 5054 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 252: /* primary ::= primary ADDADD */
#line 1562 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[-1].minor.yy374,PEX_PostInc);
	yylhsminor.yy374 = expr1;
}
#line 5064 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,42,&yymsp[0].minor);
  yymsp[-1].minor.yy374 = yylhsminor.yy374;
        break;
      case 253: /* primary ::= primary SUBSUB */
#line 1567 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[-1].minor.yy374,PEX_PostDec);
	yylhsminor.yy374 = expr1;
}
#line 5074 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,43,&yymsp[0].minor);
  yymsp[-1].minor.yy374 = yylhsminor.yy374;
        break;
      case 254: /* unary_expr ::= SUB unary_expr */
{  yy_destructor(yypParser,33,&yymsp[-1].minor);
#line 1583 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	ZCC_ExprConstant *con = static_cast<ZCC_ExprConstant *>(yymsp[0].minor.yy374);
	if (yymsp[0].minor.yy374->Operation == PEX_ConstValue && (con->Type->isInt() || con->Type->isFloat()))
	{ // For constants, manipulate the child node directly, and don't create a new node.
		if (con->Type->isInt())
		{
			con->IntVal = -con->IntVal;
		}
		else
		{
			con->DoubleVal = -con->DoubleVal;
		}
		yymsp[-1].minor.yy374 = yymsp[0].minor.yy374;
	}
	else
	{ // For everything else, create a new node and do the negation later.
		UNARY_EXPR(yymsp[0].minor.yy374,PEX_Negate);
		yymsp[-1].minor.yy374 = expr1;
	}
}
#line 5101 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 255: /* unary_expr ::= ADD unary_expr */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 1604 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	// Even though this is really a no-op, we still need to make a node for
	// it so we can type check that it is being applied to something numeric.
	// But we can do that right now for constant numerals.
	ZCC_ExprConstant *con = static_cast<ZCC_ExprConstant *>(yymsp[0].minor.yy374);
	if (yymsp[0].minor.yy374->Operation != PEX_ConstValue || (!con->Type->isInt() && !con->Type->isFloat()))
	{
		UNARY_EXPR(yymsp[0].minor.yy374,PEX_AntiNegate);
		yymsp[-1].minor.yy374 = expr1;
	}
	else
	{
		yymsp[-1].minor.yy374 = yymsp[0].minor.yy374;
	}
}
#line 5122 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 256: /* unary_expr ::= SUBSUB unary_expr */
{  yy_destructor(yypParser,43,&yymsp[-1].minor);
#line 1620 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy374,PEX_PreDec);
	yymsp[-1].minor.yy374 = expr1;
}
#line 5132 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 257: /* unary_expr ::= ADDADD unary_expr */
{  yy_destructor(yypParser,42,&yymsp[-1].minor);
#line 1625 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy374,PEX_PreInc);
	yymsp[-1].minor.yy374 = expr1;
}
#line 5142 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 258: /* unary_expr ::= TILDE unary_expr */
{  yy_destructor(yypParser,139,&yymsp[-1].minor);
#line 1630 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy374,PEX_BitNot);
	yymsp[-1].minor.yy374 = expr1;
}
#line 5152 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 259: /* unary_expr ::= BANG unary_expr */
{  yy_destructor(yypParser,140,&yymsp[-1].minor);
#line 1635 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy374,PEX_BoolNot);
	yymsp[-1].minor.yy374 = expr1;
}
#line 5162 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 260: /* unary_expr ::= SIZEOF unary_expr */
{  yy_destructor(yypParser,141,&yymsp[-1].minor);
#line 1640 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy374,PEX_SizeOf);
	yymsp[-1].minor.yy374 = expr1;
}
#line 5172 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 261: /* unary_expr ::= ALIGNOF unary_expr */
{  yy_destructor(yypParser,142,&yymsp[-1].minor);
#line 1645 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy374,PEX_AlignOf);
	yymsp[-1].minor.yy374 = expr1;
}
#line 5182 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 262: /* expr ::= expr ADD expr */
#line 1658 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_Add);
	yylhsminor.yy374 = expr2;
}
#line 5191 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,34,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 263: /* expr ::= expr SUB expr */
#line 1663 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_Sub);
	yylhsminor.yy374 = expr2;
}
#line 5201 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,33,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 264: /* expr ::= expr MUL expr */
#line 1668 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_Mul);
	yylhsminor.yy374 = expr2;
}
#line 5211 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,35,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 265: /* expr ::= expr DIV expr */
#line 1673 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_Div);
	yylhsminor.yy374 = expr2;
}
#line 5221 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,36,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 266: /* expr ::= expr MOD expr */
#line 1678 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_Mod);
	yylhsminor.yy374 = expr2;
}
#line 5231 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,37,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 267: /* expr ::= expr POW expr */
#line 1683 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_Pow);
	yylhsminor.yy374 = expr2;
}
#line 5241 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,40,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 268: /* expr ::= expr CROSSPROD expr */
#line 1688 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_CrossProduct);
	yylhsminor.yy374 = expr2;
}
#line 5251 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,38,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 269: /* expr ::= expr DOTPROD expr */
#line 1693 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_DotProduct);
	yylhsminor.yy374 = expr2;
}
#line 5261 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,39,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 270: /* expr ::= expr LSH expr */
#line 1698 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_LeftShift);
	yylhsminor.yy374 = expr2;
}
#line 5271 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,30,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 271: /* expr ::= expr RSH expr */
#line 1703 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_RightShift);
	yylhsminor.yy374 = expr2;
}
#line 5281 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,31,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 272: /* expr ::= expr URSH expr */
#line 1708 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_URightShift);
	yylhsminor.yy374 = expr2;
}
#line 5291 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,32,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 273: /* expr ::= expr DOTDOT expr */
#line 1713 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_Concat);
	yylhsminor.yy374 = expr2;
}
#line 5301 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,26,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 274: /* expr ::= expr LT expr */
#line 1719 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_LT);
	yylhsminor.yy374 = expr2;
}
#line 5311 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 275: /* expr ::= expr GT expr */
#line 1724 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_GT);
	yylhsminor.yy374 = expr2;
}
#line 5321 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,21,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 276: /* expr ::= expr LTEQ expr */
#line 1729 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_LTEQ);
	yylhsminor.yy374 = expr2;
}
#line 5331 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,22,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 277: /* expr ::= expr GTEQ expr */
#line 1734 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_GTEQ);
	yylhsminor.yy374 = expr2;
}
#line 5341 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,23,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 278: /* expr ::= expr LTGTEQ expr */
#line 1739 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_LTGTEQ);
	yylhsminor.yy374 = expr2;
}
#line 5351 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,24,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 279: /* expr ::= expr IS expr */
#line 1744 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_Is);
	yylhsminor.yy374 = expr2;
}
#line 5361 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,25,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 280: /* expr ::= expr EQEQ expr */
#line 1750 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_EQEQ);
	yylhsminor.yy374 = expr2;
}
#line 5371 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,17,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 281: /* expr ::= expr NEQ expr */
#line 1755 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_NEQ);
	yylhsminor.yy374 = expr2;
}
#line 5381 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,18,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 282: /* expr ::= expr APPROXEQ expr */
#line 1760 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_APREQ);
	yylhsminor.yy374 = expr2;
}
#line 5391 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,19,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 283: /* expr ::= expr AND expr */
#line 1766 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_BitAnd);
	yylhsminor.yy374 = expr2;
}
#line 5401 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,29,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 284: /* expr ::= expr XOR expr */
#line 1771 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_BitXor);
	yylhsminor.yy374 = expr2;
}
#line 5411 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,28,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 285: /* expr ::= expr OR expr */
#line 1776 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_BitOr);
	yylhsminor.yy374 = expr2;
}
#line 5421 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,27,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 286: /* expr ::= expr ANDAND expr */
#line 1781 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_BoolAnd);
	yylhsminor.yy374 = expr2;
}
#line 5431 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,16,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 287: /* expr ::= expr OROR expr */
#line 1786 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_BoolOr);
	yylhsminor.yy374 = expr2;
}
#line 5441 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,15,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 288: /* expr ::= expr EQ expr */
#line 1791 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_Assign);
	yylhsminor.yy374 = expr2;
}
#line 5451 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 289: /* expr ::= expr ADDEQ expr */
#line 1796 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_AddAssign);
	yylhsminor.yy374 = expr2;
}
#line 5461 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,5,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 290: /* expr ::= expr SUBEQ expr */
#line 1801 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_SubAssign);
	yylhsminor.yy374 = expr2;
}
#line 5471 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,6,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 291: /* expr ::= expr MULEQ expr */
#line 1806 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_MulAssign);
	yylhsminor.yy374 = expr2;
}
#line 5481 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,2,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 292: /* expr ::= expr DIVEQ expr */
#line 1811 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_DivAssign);
	yylhsminor.yy374 = expr2;
}
#line 5491 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,3,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 293: /* expr ::= expr MODEQ expr */
#line 1816 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_ModAssign);
	yylhsminor.yy374 = expr2;
}
#line 5501 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,4,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 294: /* expr ::= expr LSHEQ expr */
#line 1821 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_LshAssign);
	yylhsminor.yy374 = expr2;
}
#line 5511 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,7,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 295: /* expr ::= expr RSHEQ expr */
#line 1826 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_RshAssign);
	yylhsminor.yy374 = expr2;
}
#line 5521 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,8,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 296: /* expr ::= expr URSHEQ expr */
#line 1831 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_URshAssign);
	yylhsminor.yy374 = expr2;
}
#line 5531 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,12,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 297: /* expr ::= expr ANDEQ expr */
#line 1836 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_AndAssign);
	yylhsminor.yy374 = expr2;
}
#line 5541 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,9,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 298: /* expr ::= expr OREQ expr */
#line 1841 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_OrAssign);
	yylhsminor.yy374 = expr2;
}
#line 5551 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,10,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 299: /* expr ::= expr XOREQ expr */
#line 1846 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_XorAssign);
	yylhsminor.yy374 = expr2;
}
#line 5561 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,11,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 300: /* expr ::= expr SCOPE expr */
#line 1853 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy374,yymsp[0].minor.yy374,PEX_Scope);
	yylhsminor.yy374 = expr2;
}
#line 5571 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-1].minor);
  yymsp[-2].minor.yy374 = yylhsminor.yy374;
        break;
      case 301: /* expr ::= expr QUESTION expr COLON expr */
#line 1861 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprTrinary, expr, yymsp[-4].minor.yy374);
	expr->Operation = PEX_Trinary;
	expr->Type = NULL;
	expr->Test = yymsp[-4].minor.yy374;
	expr->Left = yymsp[-2].minor.yy374;
	expr->Right = yymsp[0].minor.yy374;
	yylhsminor.yy374 = expr;
}
#line 5586 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,13,&yymsp[-3].minor);
  yy_destructor(yypParser,14,&yymsp[-1].minor);
  yymsp[-4].minor.yy374 = yylhsminor.yy374;
        break;
      case 302: /* expr_list ::= expr_list COMMA expr */
#line 1877 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[-2].minor.yy374 = yymsp[-2].minor.yy374;	/*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy374, yymsp[0].minor.yy374);
}
#line 5597 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 303: /* func_expr_list ::= func_expr_list COMMA func_expr_item */
#line 1893 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	// Omitted parameters still need to appear as nodes in the list.
	if (yymsp[-2].minor.yy370 == NULL)
	{
		NEW_AST_NODE(FuncParm,nil_a,yymsp[-1].minor.yy0);
		nil_a->Value = NULL;
		nil_a->Label = NAME_None;
		yymsp[-2].minor.yy370 = nil_a;
	}
	if (yymsp[0].minor.yy370 == NULL)
	{
		NEW_AST_NODE(FuncParm,nil_b,yymsp[-1].minor.yy0);
		nil_b->Value = NULL;
		nil_b->Label = NAME_None;
		yymsp[0].minor.yy370 = nil_b;
	}
	yymsp[-2].minor.yy370 = yymsp[-2].minor.yy370;	/*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy370, yymsp[0].minor.yy370);
}
#line 5621 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 304: /* func_expr_item ::= */
#line 1914 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[1].minor.yy370 = NULL;
}
#line 5628 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 305: /* named_expr ::= IDENTIFIER COLON expr */
#line 1920 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParm, parm, yymsp[-2].minor.yy0);
	parm->Value = yymsp[0].minor.yy374;
	parm->Label = ENamedName(yymsp[-2].minor.yy0.Int);
	yylhsminor.yy370 = parm;
}
#line 5638 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[-1].minor);
  yymsp[-2].minor.yy370 = yylhsminor.yy370;
        break;
      case 306: /* named_expr ::= expr */
#line 1927 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParm, parm, yymsp[0].minor.yy374);
	parm->Value = yymsp[0].minor.yy374;
	parm->Label = NAME_None;
	yylhsminor.yy370 = parm;
}
#line 5650 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy370 = yylhsminor.yy370;
        break;
      case 308: /* string_constant ::= string_constant STRCONST */
#line 1948 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[-1].minor.yy47);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = stat->Strings.Alloc(*(yymsp[-1].minor.yy47->StringVal) + *(yymsp[0].minor.yy0.String));
	yylhsminor.yy47 = strconst;
}
#line 5662 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[-1].minor.yy47 = yylhsminor.yy47;
        break;
      case 309: /* constant ::= INTCONST */
#line 1958 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(intconst, TypeSInt32, yymsp[0].minor.yy0.Int, yymsp[0].minor.yy0);
	yylhsminor.yy47 = intconst;
}
#line 5671 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy47 = yylhsminor.yy47;
        break;
      case 310: /* constant ::= UINTCONST */
#line 1963 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(intconst, TypeUInt32, yymsp[0].minor.yy0.Int, yymsp[0].minor.yy0);
	yylhsminor.yy47 = intconst;
}
#line 5680 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy47 = yylhsminor.yy47;
        break;
      case 311: /* constant ::= FLOATCONST */
#line 1968 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, floatconst, yymsp[0].minor.yy0);
	floatconst->Operation = PEX_ConstValue;
	floatconst->Type = TypeFloat64;
	floatconst->DoubleVal = yymsp[0].minor.yy0.Float;
	yylhsminor.yy47 = floatconst;
}
#line 5692 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy47 = yylhsminor.yy47;
        break;
      case 312: /* constant ::= NAMECONST */
#line 1976 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, floatconst, yymsp[0].minor.yy0);
	floatconst->Operation = PEX_ConstValue;
	floatconst->Type = TypeName;
	floatconst->IntVal = yymsp[0].minor.yy0.Int;
	yylhsminor.yy47 = floatconst;
}
#line 5704 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy47 = yylhsminor.yy47;
        break;
      case 313: /* constant ::= FALSE */
#line 1984 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(boolconst, TypeBool, false, yymsp[0].minor.yy0);
	yylhsminor.yy47 = boolconst;
}
#line 5713 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy47 = yylhsminor.yy47;
        break;
      case 314: /* constant ::= TRUE */
#line 1989 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(boolconst, TypeBool, true, yymsp[0].minor.yy0);
	yylhsminor.yy47 = boolconst;
}
#line 5722 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy47 = yylhsminor.yy47;
        break;
      case 315: /* constant ::= NULLPTR */
#line 1994 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, nullptrconst, yymsp[0].minor.yy0);
	nullptrconst->Operation = PEX_ConstValue;
	nullptrconst->Type = TypeNullPtr;
	nullptrconst->StringVal = nullptr;
	yylhsminor.yy47 = nullptrconst;
}
#line 5734 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy47 = yylhsminor.yy47;
        break;
      case 317: /* statement ::= labeled_statement */
#line 2008 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy523 = yymsp[0].minor.yy274; /*X-overwrites-A*/ }
#line 5740 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 318: /* statement ::= compound_statement */
#line 2009 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy523 = yymsp[0].minor.yy271; /*X-overwrites-A*/ }
#line 5745 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 319: /* statement ::= expression_statement SEMICOLON */
#line 2010 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy523 = yymsp[-1].minor.yy135; /*X-overwrites-A*/ }
#line 5750 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 320: /* statement ::= assign_statement SEMICOLON */
#line 2018 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy523 = yymsp[-1].minor.yy128; /*X-overwrites-A*/ }
#line 5756 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 321: /* statement ::= assign_decl_statement SEMICOLON */
#line 2019 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy523 = yymsp[-1].minor.yy459; /*X-overwrites-A*/ }
#line 5762 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 322: /* statement ::= local_var SEMICOLON */
#line 2020 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy523 = yymsp[-1].minor.yy362; /*X-overwrites-A*/ }
#line 5768 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 324: /* statement ::= staticarray_statement */
#line 2022 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy523 = yymsp[0].minor.yy546; /*X-overwrites-A*/ }
#line 5774 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 325: /* staticarray_statement ::= STATICCONST type IDENTIFIER LBRACKET RBRACKET EQ LBRACE expr_list RBRACE SEMICOLON */
{  yy_destructor(yypParser,149,&yymsp[-9].minor);
#line 2029 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StaticArrayStatement, stmt, yymsp[-8].minor.yy168);
	stmt->Type = yymsp[-8].minor.yy168;
	stmt->Id = ENamedName(yymsp[-7].minor.yy0.Int);
	stmt->Values = yymsp[-2].minor.yy374;
	yymsp[-9].minor.yy546 = stmt;
}
#line 5786 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-6].minor);
  yy_destructor(yypParser,123,&yymsp[-5].minor);
  yy_destructor(yypParser,1,&yymsp[-4].minor);
  yy_destructor(yypParser,68,&yymsp[-3].minor);
  yy_destructor(yypParser,69,&yymsp[-1].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
}
        break;
      case 326: /* staticarray_statement ::= STATICCONST type LBRACKET RBRACKET IDENTIFIER EQ LBRACE expr_list RBRACE SEMICOLON */
{  yy_destructor(yypParser,149,&yymsp[-9].minor);
#line 2038 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StaticArrayStatement, stmt, yymsp[-8].minor.yy168);
	stmt->Type = yymsp[-8].minor.yy168;
	stmt->Id = ENamedName(yymsp[-5].minor.yy0.Int);
	stmt->Values = yymsp[-2].minor.yy374;
	yymsp[-9].minor.yy546 = stmt;
}
#line 5805 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-7].minor);
  yy_destructor(yypParser,123,&yymsp[-6].minor);
  yy_destructor(yypParser,1,&yymsp[-4].minor);
  yy_destructor(yypParser,68,&yymsp[-3].minor);
  yy_destructor(yypParser,69,&yymsp[-1].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
}
        break;
      case 327: /* jump_statement ::= CONTINUE SEMICOLON */
#line 2051 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ContinueStmt, stmt, yymsp[-1].minor.yy0);
	yylhsminor.yy523 = stmt;
}
#line 5820 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy523 = yylhsminor.yy523;
        break;
      case 328: /* jump_statement ::= BREAK SEMICOLON */
#line 2056 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BreakStmt, stmt, yymsp[-1].minor.yy0);
	yylhsminor.yy523 = stmt;
}
#line 5830 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy523 = yylhsminor.yy523;
        break;
      case 329: /* jump_statement ::= RETURN SEMICOLON */
#line 2061 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ReturnStmt, stmt, yymsp[-1].minor.yy0);
	stmt->Values = NULL;
	yylhsminor.yy523 = stmt;
}
#line 5841 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy523 = yylhsminor.yy523;
        break;
      case 330: /* jump_statement ::= RETURN expr_list SEMICOLON */
#line 2067 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ReturnStmt, stmt, yymsp[-2].minor.yy0);
	stmt->Values = yymsp[-1].minor.yy374;
	yylhsminor.yy523 = stmt;
}
#line 5852 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-2].minor.yy523 = yylhsminor.yy523;
        break;
      case 331: /* compound_statement ::= LBRACE RBRACE */
#line 2079 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-1].minor.yy0);
	stmt->Content = NULL;
	yylhsminor.yy271 = stmt;
}
#line 5863 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,69,&yymsp[0].minor);
  yymsp[-1].minor.yy271 = yylhsminor.yy271;
        break;
      case 332: /* compound_statement ::= LBRACE statement_list RBRACE */
#line 2085 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Content = yymsp[-1].minor.yy523;
	yylhsminor.yy271 = stmt;
}
#line 5874 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,69,&yymsp[0].minor);
  yymsp[-2].minor.yy271 = yylhsminor.yy271;
        break;
      case 333: /* compound_statement ::= LBRACE error RBRACE */
#line 2091 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Content = NULL;
	yylhsminor.yy271 = stmt;
}
#line 5885 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,69,&yymsp[0].minor);
  yymsp[-2].minor.yy271 = yylhsminor.yy271;
        break;
      case 336: /* expression_statement ::= expr */
#line 2111 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExpressionStmt, stmt, yymsp[0].minor.yy374);
	stmt->Expression = yymsp[0].minor.yy374;
	yylhsminor.yy135 = stmt;
}
#line 5896 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy135 = yylhsminor.yy135;
        break;
      case 337: /* iteration_statement ::= while_or_until LPAREN expr RPAREN statement */
#line 2123 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-4].minor.yy0);
	if (yymsp[-4].minor.yy0.Int == ZCC_UNTIL)
	{ // Negate the loop condition
		UNARY_EXPR(yymsp[-2].minor.yy374,PEX_BoolNot);
		iter->LoopCondition = expr1;
	}
	else
	{
		iter->LoopCondition = yymsp[-2].minor.yy374;
	}
	iter->LoopStatement = yymsp[0].minor.yy523;
	iter->LoopBumper = NULL;
	iter->CheckAt = ZCC_IterationStmt::Start;
	yylhsminor.yy523 = iter;
}
#line 5917 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,63,&yymsp[-1].minor);
  yymsp[-4].minor.yy523 = yylhsminor.yy523;
        break;
      case 338: /* iteration_statement ::= DO statement while_or_until LPAREN expr RPAREN */
#line 2141 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-5].minor.yy0);
	if (yymsp[-3].minor.yy0.Int == ZCC_UNTIL)
	{ // Negate the loop condition
		UNARY_EXPR(yymsp[-1].minor.yy374,PEX_BoolNot);
		iter->LoopCondition = expr1;
	}
	else
	{
		iter->LoopCondition = yymsp[-1].minor.yy374;
	}
	iter->LoopStatement = yymsp[-4].minor.yy523;
	iter->LoopBumper = NULL;
	iter->CheckAt = ZCC_IterationStmt::End;
	yylhsminor.yy523 = iter;
}
#line 5940 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,63,&yymsp[0].minor);
  yymsp[-5].minor.yy523 = yylhsminor.yy523;
        break;
      case 339: /* iteration_statement ::= FOR LPAREN for_init SEMICOLON opt_expr SEMICOLON for_bump RPAREN statement */
#line 2159 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-8].minor.yy0);
	iter->LoopCondition = yymsp[-4].minor.yy374;
	iter->LoopStatement = yymsp[0].minor.yy523;
	iter->LoopBumper = yymsp[-2].minor.yy523;
	iter->CheckAt = ZCC_IterationStmt::Start;
	// The initialization expression appears outside the loop
	// for_init may be NULL if there is no initialization.
	SAFE_APPEND(yymsp[-6].minor.yy523, iter);
	// And the whole thing gets wrapped inside a compound statement in case the loop
	// initializer defined any variables.
	NEW_AST_NODE(CompoundStmt, wrap, yymsp[-8].minor.yy0);
	wrap->Content = yymsp[-6].minor.yy523;
	yylhsminor.yy523 = wrap;
}
#line 5962 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-7].minor);
  yy_destructor(yypParser,49,&yymsp[-5].minor);
  yy_destructor(yypParser,49,&yymsp[-3].minor);
  yy_destructor(yypParser,63,&yymsp[-1].minor);
  yymsp[-8].minor.yy523 = yylhsminor.yy523;
        break;
      case 340: /* array_iteration_statement ::= FOREACH LPAREN variable_name COLON expr RPAREN statement */
#line 2178 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ArrayIterationStmt, iter, yymsp[-6].minor.yy0);
	iter->ItName = yymsp[-4].minor.yy244;
	iter->ItArray = yymsp[-2].minor.yy374;
	iter->LoopStatement = yymsp[0].minor.yy523;
	yylhsminor.yy523 = iter;
}
#line 5978 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-5].minor);
  yy_destructor(yypParser,14,&yymsp[-3].minor);
  yy_destructor(yypParser,63,&yymsp[-1].minor);
  yymsp[-6].minor.yy523 = yylhsminor.yy523;
        break;
      case 341: /* two_arg_iteration_statement ::= FOREACH LPAREN variable_name COMMA variable_name COLON expr RPAREN statement */
#line 2189 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(TwoArgIterationStmt, iter, yymsp[-8].minor.yy0);
	iter->ItKey = yymsp[-6].minor.yy244;
	iter->ItValue = yymsp[-4].minor.yy244;
	iter->ItMap = yymsp[-2].minor.yy374;
	iter->LoopStatement = yymsp[0].minor.yy523;
	yylhsminor.yy523 = iter;
}
#line 5994 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-7].minor);
  yy_destructor(yypParser,50,&yymsp[-5].minor);
  yy_destructor(yypParser,14,&yymsp[-3].minor);
  yy_destructor(yypParser,63,&yymsp[-1].minor);
  yymsp[-8].minor.yy523 = yylhsminor.yy523;
        break;
      case 342: /* three_arg_iteration_statement ::= FOREACH LPAREN variable_name COMMA variable_name COMMA variable_name COLON expr RPAREN statement */
#line 2201 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ThreeArgIterationStmt, iter, yymsp[-10].minor.yy0);
	iter->ItVar = yymsp[-8].minor.yy244;
	iter->ItPos = yymsp[-6].minor.yy244;
	iter->ItFlags = yymsp[-4].minor.yy244;
	iter->ItBlock = yymsp[-2].minor.yy374;
	iter->LoopStatement = yymsp[0].minor.yy523;
	yylhsminor.yy523 = iter;
}
#line 6012 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-9].minor);
  yy_destructor(yypParser,50,&yymsp[-7].minor);
  yy_destructor(yypParser,50,&yymsp[-5].minor);
  yy_destructor(yypParser,14,&yymsp[-3].minor);
  yy_destructor(yypParser,63,&yymsp[-1].minor);
  yymsp[-10].minor.yy523 = yylhsminor.yy523;
        break;
      case 343: /* typed_iteration_statement ::= FOREACH LPAREN variable_name variable_name COLON expr RPAREN statement */
#line 2214 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(TypedIterationStmt, iter, yymsp[-7].minor.yy0);
	iter->ItType = yymsp[-5].minor.yy244;
	iter->ItVar = yymsp[-4].minor.yy244;
	iter->ItExpr = yymsp[-2].minor.yy374;
	iter->LoopStatement = yymsp[0].minor.yy523;
	yylhsminor.yy523 = iter;
}
#line 6030 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-6].minor);
  yy_destructor(yypParser,14,&yymsp[-3].minor);
  yy_destructor(yypParser,63,&yymsp[-1].minor);
  yymsp[-7].minor.yy523 = yylhsminor.yy523;
        break;
      case 344: /* while_or_until ::= WHILE */
#line 2224 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	yylhsminor.yy0.Int = ZCC_WHILE;
	yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
}
#line 6042 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 345: /* while_or_until ::= UNTIL */
#line 2229 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	yylhsminor.yy0.Int = ZCC_UNTIL;
	yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
}
#line 6051 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 346: /* for_init ::= local_var */
#line 2235 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy523 = yymsp[0].minor.yy362 /*X-overwrites-A*/; }
#line 6057 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 347: /* for_init ::= for_bump */
#line 2236 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy523 = yymsp[0].minor.yy523 /*X-overwrites-A*/; }
#line 6062 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 348: /* for_bump ::= */
#line 2239 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy523 = NULL; }
#line 6067 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 349: /* for_bump ::= expression_statement */
#line 2240 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy523 = yymsp[0].minor.yy135; /*X-overwrites-A*/ }
#line 6072 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 350: /* for_bump ::= for_bump COMMA expression_statement */
#line 2241 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy523 = yymsp[-2].minor.yy523; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy523, yymsp[0].minor.yy135); }
#line 6077 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 351: /* selection_statement ::= if_front */
#line 2255 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[0].minor.yy523 = yymsp[0].minor.yy257; /*X-overwrites-A*/
}
#line 6085 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
        break;
      case 352: /* selection_statement ::= if_front ELSE statement */
#line 2259 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[-2].minor.yy257->FalsePath = yymsp[0].minor.yy523;
	yymsp[-2].minor.yy523 = yymsp[-2].minor.yy257; /*X-overwrites-A*/
}
#line 6093 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,159,&yymsp[-1].minor);
        break;
      case 353: /* if_front ::= IF LPAREN expr RPAREN statement */
#line 2265 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(IfStmt,stmt,yymsp[-4].minor.yy0);
	stmt->Condition = yymsp[-2].minor.yy374;
	stmt->TruePath = yymsp[0].minor.yy523;
	stmt->FalsePath = NULL;
	yylhsminor.yy257 = stmt;
}
#line 6105 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,63,&yymsp[-1].minor);
  yymsp[-4].minor.yy257 = yylhsminor.yy257;
        break;
      case 354: /* selection_statement ::= SWITCH LPAREN expr RPAREN statement */
#line 2276 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(SwitchStmt,stmt,yymsp[-4].minor.yy0);
	stmt->Condition = yymsp[-2].minor.yy374;
	stmt->Content = yymsp[0].minor.yy523;
	yylhsminor.yy523 = stmt;
}
#line 6118 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,63,&yymsp[-1].minor);
  yymsp[-4].minor.yy523 = yylhsminor.yy523;
        break;
      case 355: /* labeled_statement ::= CASE expr COLON */
#line 2288 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CaseStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Condition = yymsp[-1].minor.yy374;
	yylhsminor.yy274 = stmt;
}
#line 6130 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-2].minor.yy274 = yylhsminor.yy274;
        break;
      case 356: /* labeled_statement ::= DEFAULT COLON */
#line 2294 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CaseStmt,stmt,yymsp[-1].minor.yy0);
	stmt->Condition = NULL;
	yylhsminor.yy274 = stmt;
}
#line 6141 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-1].minor.yy274 = yylhsminor.yy274;
        break;
      case 357: /* assign_statement ::= LBRACKET expr_list RBRACKET EQ expr */
{  yy_destructor(yypParser,46,&yymsp[-4].minor);
#line 2307 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(AssignStmt,stmt,yymsp[-3].minor.yy374);
	stmt->AssignOp = ZCC_EQ;
	stmt->Dests = yymsp[-3].minor.yy374;
	stmt->Sources = yymsp[0].minor.yy374;
	yymsp[-4].minor.yy128 = stmt;
}
#line 6155 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,123,&yymsp[-2].minor);
  yy_destructor(yypParser,1,&yymsp[-1].minor);
}
        break;
      case 358: /* assign_decl_statement ::= LET LBRACKET identifier_list RBRACKET EQ expr */
{  yy_destructor(yypParser,110,&yymsp[-5].minor);
#line 2318 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(AssignDeclStmt,stmt,yymsp[-3].minor.yy533);
	stmt->AssignOp = ZCC_EQ;
	stmt->Dests = yymsp[-3].minor.yy533;
	stmt->Sources = yymsp[0].minor.yy374;
	yymsp[-5].minor.yy459 = stmt;
}
#line 6170 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-4].minor);
  yy_destructor(yypParser,123,&yymsp[-2].minor);
  yy_destructor(yypParser,1,&yymsp[-1].minor);
}
        break;
      case 359: /* local_var ::= type variable_list_with_init */
#line 2331 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(LocalVarStmt,vardef,yymsp[-1].minor.yy168);
	vardef->Type = yymsp[-1].minor.yy168;
	vardef->Vars = yymsp[0].minor.yy27;
	yylhsminor.yy362 = vardef;
}
#line 6184 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[-1].minor.yy362 = yylhsminor.yy362;
        break;
      case 360: /* var_init ::= IDENTIFIER */
#line 2340 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[0].minor.yy0);
	var->Name = ENamedName(yymsp[0].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = NULL;
	var->InitIsArray = false;
	yylhsminor.yy27 = var;
}
#line 6197 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[0].minor.yy27 = yylhsminor.yy27;
        break;
      case 361: /* var_init ::= IDENTIFIER array_size */
#line 2350 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VarInit,var,yymsp[-1].minor.yy0);
	var->Name = ENamedName(yymsp[-1].minor.yy0.Int);
	var->ArraySize = yymsp[0].minor.yy374;
	var->Init = NULL;
	var->InitIsArray = false;
	yylhsminor.yy27 = var;
}
#line 6210 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yymsp[-1].minor.yy27 = yylhsminor.yy27;
        break;
      case 362: /* var_init ::= IDENTIFIER EQ expr */
#line 2360 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-2].minor.yy0);
	var->Name = ENamedName(yymsp[-2].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = yymsp[0].minor.yy374;
	var->InitIsArray = false;
	yylhsminor.yy27 = var;
}
#line 6223 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy27 = yylhsminor.yy27;
        break;
      case 363: /* var_init ::= IDENTIFIER EQ LBRACE expr_list RBRACE */
#line 2370 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-4].minor.yy0);
	var->Name = ENamedName(yymsp[-4].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = yymsp[-1].minor.yy374;
	var->InitIsArray = true;
	yylhsminor.yy27 = var;
}
#line 6237 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,68,&yymsp[-2].minor);
  yy_destructor(yypParser,69,&yymsp[0].minor);
  yymsp[-4].minor.yy27 = yylhsminor.yy27;
        break;
      case 364: /* var_init ::= IDENTIFIER array_size EQ LBRACE expr_list RBRACE */
#line 2380 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-5].minor.yy0);
	var->Name = ENamedName(yymsp[-5].minor.yy0.Int);
	var->ArraySize = yymsp[-4].minor.yy374;
	var->Init = yymsp[-1].minor.yy374;
	var->InitIsArray = true;
	yylhsminor.yy27 = var;
}
#line 6253 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,68,&yymsp[-2].minor);
  yy_destructor(yypParser,69,&yymsp[0].minor);
  yymsp[-5].minor.yy27 = yylhsminor.yy27;
        break;
      case 365: /* var_init ::= IDENTIFIER EQ LBRACE error RBRACE */
{  yy_destructor(yypParser,54,&yymsp[-4].minor);
#line 2390 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	yymsp[-4].minor.yy27 = NULL;
}
#line 6265 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,68,&yymsp[-2].minor);
  yy_destructor(yypParser,69,&yymsp[0].minor);
}
        break;
      case 366: /* variable_list_with_init ::= variable_list_with_init COMMA var_init */
#line 2398 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-2].minor.yy27, yymsp[0].minor.yy27);
	yymsp[-2].minor.yy27 = yymsp[-2].minor.yy27; /*X-overwrites-A*/
}
#line 6277 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 367: /* translation_unit ::= translation_unit EOF */
#line 179 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
}
#line 6284 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,48,&yymsp[0].minor);
        break;
      case 369: /* opt_semicolon ::= SEMICOLON */
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 192 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
}
#line 6292 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 371: /* opt_comma ::= COMMA */
{  yy_destructor(yypParser,50,&yymsp[0].minor);
#line 195 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
}
#line 6300 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
}
        break;
      case 377: /* state_flow ::= state_flow_type scanner_mode SEMICOLON */
#line 672 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
}
#line 6307 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 389: /* primary ::= LPAREN error RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 1513 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
{
}
#line 6315 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
  yy_destructor(yypParser,63,&yymsp[0].minor);
}
        break;
      default:
      /* (368) opt_semicolon ::= */ yytestcase(yyruleno==368);
      /* (370) opt_comma ::= */ yytestcase(yyruleno==370);
      /* (372) opt_expr ::= expr */ yytestcase(yyruleno==372);
      /* (373) opt_struct_body ::= struct_body */ yytestcase(yyruleno==373);
      /* (374) struct_body ::= struct_member */ yytestcase(yyruleno==374);
      /* (375) enum_list ::= enumerator */ yytestcase(yyruleno==375);
      /* (376) opt_enum_list ::= enum_list opt_comma */ yytestcase(yyruleno==376);
      /* (378) type_name1 ::= int_type */ yytestcase(yyruleno==378);
      /* (379) func_ptr_params ::= func_ptr_param_list */ yytestcase(yyruleno==379);
      /* (380) func_ptr_param_list ::= func_ptr_param */ yytestcase(yyruleno==380);
      /* (381) type_or_array ::= type */ yytestcase(yyruleno==381);
      /* (382) type_list ::= type_or_array */ yytestcase(yyruleno==382);
      /* (383) type_list_or_void ::= type_list */ yytestcase(yyruleno==383);
      /* (384) array_size ::= array_size_expr */ yytestcase(yyruleno==384);
      /* (385) variable_list ::= variable_name */ yytestcase(yyruleno==385);
      /* (386) opt_func_body ::= function_body */ yytestcase(yyruleno==386);
      /* (387) func_params ::= func_param_list */ yytestcase(yyruleno==387);
      /* (388) func_param_list ::= func_param */ yytestcase(yyruleno==388);
      /* (390) unary_expr ::= primary */ yytestcase(yyruleno==390);
      /* (391) expr ::= unary_expr */ yytestcase(yyruleno==391);
      /* (392) expr_list ::= expr */ yytestcase(yyruleno==392);
      /* (393) func_expr_list ::= func_expr_item */ yytestcase(yyruleno==393);
      /* (394) func_expr_item ::= named_expr */ yytestcase(yyruleno==394);
      /* (395) constant ::= string_constant */ yytestcase(yyruleno==395);
      /* (396) function_body ::= compound_statement */ yytestcase(yyruleno==396);
      /* (397) statement ::= selection_statement */ yytestcase(yyruleno==397);
      /* (398) statement ::= iteration_statement */ yytestcase(yyruleno==398);
      /* (399) statement ::= array_iteration_statement */ yytestcase(yyruleno==399);
      /* (400) statement ::= two_arg_iteration_statement */ yytestcase(yyruleno==400);
      /* (401) statement ::= three_arg_iteration_statement */ yytestcase(yyruleno==401);
      /* (402) statement ::= typed_iteration_statement */ yytestcase(yyruleno==402);
      /* (403) statement ::= jump_statement */ yytestcase(yyruleno==403);
      /* (404) variable_list_with_init ::= var_init */ yytestcase(yyruleno==404);
       break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact <= YY_MAX_SHIFTREDUCE ){
    if( yyact>YY_MAX_SHIFT ){
      yyact += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
    }
    yymsp -= yysize-1;
    yypParser->yytos = yymsp;
    yymsp->stateno = (YYACTIONTYPE)yyact;
    yymsp->major = (YYCODETYPE)yygoto;
    yyTraceShift(yypParser, yyact);
  }else{
    assert( yyact == YY_ACCEPT_ACTION );
    yypParser->yytos -= yysize;
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  ZCCParseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
    fflush(yyTraceFILE);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
#line 149 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
 /**failed = true;*/ 
#line 6396 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
/************ End %parse_failure code *****************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  ZCCParseTOKENTYPE yyminor         /* The minor type of the error token */
){
  ZCCParseARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 122 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"

	FString unexpected, expecting;

	int i;
	int stateno = yypParser->yytos->stateno;

	unexpected << "Unexpected " << ZCCTokenName(yymajor);

	// Determine all the terminals that the parser would have accepted at this point
	// (see yy_find_shift_action). This list can get quite long. Is it worthwhile to
	// print it when not debugging the grammar, or would that be too confusing to
	// the average user?
	if (stateno < YY_SHIFT_MAX && (i = yy_shift_ofst[stateno])!=YY_SHIFT_USE_DFLT)
	{
		for (int j = 1; j < YYERRORSYMBOL; ++j)
		{
			int k = i + j;
			if (k >= 0 && k < YY_ACTTAB_COUNT && yy_lookahead[k] == j)
			{
				expecting << (expecting.IsEmpty() ? "Expecting " : " or ") << ZCCTokenName(j);
			}
		}
	}
	stat->sc->ScriptMessage("%s\n%s\n", unexpected.GetChars(), expecting.GetChars());
	FScriptPosition::ErrorCounter++;
#line 6439 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
/************ End %syntax_error code ******************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  ZCCParseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
    fflush(yyTraceFILE);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
#if 0
  assert( yypParser->yytos==yypParser->yystack );
#else
  while (yypParser->yytos>yypParser->yystack) yy_pop_parser_stack(yypParser);
#endif
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
#line 148 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/src/common/scripting/frontend/zcc-parse.lemon"
 DPrintf(DMSG_SPAMMY, "Input accepted\n"); 
#line 6470 "/builddir/build/BUILD/gzdoom-4.14.2-build/gzdoom-g4.14.2/builddir/src/zcc-parse.c"
/*********** End %parse_accept code *******************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "ZCCParseAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void ZCCParse(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  ZCCParseTOKENTYPE yyminor       /* The value for the token */
  ZCCParseARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  ZCCParseARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput '%s'\n",yyTracePrompt,yyTokenName[yymajor]);
    fflush(yyTraceFILE);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact <= YY_MAX_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
        fflush(yyTraceFILE);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
          fflush(yyTraceFILE);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack );
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
    fflush(yyTraceFILE);
  }
#endif
  return;
}
